(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    357959,      12331]*)
(*NotebookOutlinePosition[    358841,      12362]*)
(*  CellTagsIndexPosition[    358797,      12358]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Cam Design", "Title",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Description", "Section",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Cams are used in many kinds of mechanical devices. Their basic purpose is to \
convert rotary motion into linear motion that has a particular displacement \
as a function of time.  An important application is to car engines: cams are \
used to control the opening and closing of valves in engine cylinders. \
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Displacement Diagrams", "Section",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Parabolic Motion", "Subsection",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
One of the simplest kinds of cam has a displacement function that consists of \
two parabolic sections. \
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Here is the equation for the first half of the motion. ",
  StyleBox["theta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the cam rotation angle. ",
  StyleBox["y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the displacement. This defines ",
  StyleBox["y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as a function of theta."
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["y[theta_] = a theta^2 + b theta + c", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(c + b\ theta + a\ theta\^2\)], "Output"]
}, Closed]],

Cell["\<\
Here are the conditions that the first parts of the cam motion must \
satisfy.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["eqns1 = {y[0]==0, y'[0]==0, y[beta/2]==L/2}", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(beta\)\" is similar to \
existing symbol \"\!\(Beta\)\"."\)], "Message"],

Cell[BoxData[
    \({c == 0, b == 0, \(b\ beta\)\/2 + \(a\ beta\^2\)\/4 + c == L\/2}\)], 
  "Output"]
}, Closed]],

Cell["We can solve these equations for the parameters a, b,and c.", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ans1 = Solve[eqns1, {a, b, c}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{a \[Rule] \(2\ L\)\/beta\^2, b \[Rule] 0, c \[Rule] 0}}\)], "Output"]
}, Closed]],

Cell["\<\
The second part of the cam motion must match the slope of the first part of \
the motion at 
theta = beta/2.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
eqns2 = {First[y'[beta/2] /. ans1] == y'[beta/2],
\t\t\t\ty[beta]==L, y'[beta]==0}\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({\(2\ L\)\/beta == b + a\ beta, b\ beta + a\ beta\^2 + c == L, 
      b + 2\ a\ beta == 0}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["ans2 = Solve[eqns2, {a, b, c}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{c \[Rule] \(-L\), a \[Rule] \(-\(\(2\ L\)\/beta\^2\)\), 
        b \[Rule] \(4\ L\)\/beta}}\)], "Output"]
}, Closed]],

Cell["\<\
Now we can plot the cam displacement, choosing beta = 2Pi, L = 1.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["y1[theta_] = First[y[theta]/.ans1] /. {beta->2Pi, L->1} ;", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["y2[theta_] = First[y[theta]/.ans2] /. {beta->2Pi, L->1} ;", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Plot[If[theta < Pi, y1[theta], y2[theta]], {theta, 0, 2Pi}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.588604 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01473 L
.02846 .01474 L
.03053 .01477 L
.03279 .01482 L
.03527 .01489 L
.0379 .01497 L
.04262 .01517 L
.04749 .01544 L
.05205 .01575 L
.06244 .01665 L
.07305 .01786 L
.08274 .01922 L
.10458 .02318 L
.12357 .02763 L
.14429 .03355 L
.18493 .04841 L
.22406 .06676 L
.26565 .09062 L
.30571 .11786 L
.34426 .14799 L
.38527 .18428 L
.42475 .22336 L
.46273 .26475 L
.50315 .3129 L
.54206 .35871 L
.58342 .4031 L
.62326 .44166 L
.66159 .47487 L
.70238 .50601 L
.74164 .53192 L
.77939 .55305 L
.8196 .57149 L
.85828 .58528 L
.87793 .59079 L
.89942 .59567 L
.90935 .59752 L
.91995 .59921 L
.92989 .60054 L
.93905 .60153 L
.94822 .6023 L
.95295 .60262 L
.95815 .6029 L
.96268 .60308 L
.96691 .60321 L
.96925 .60326 L
.97139 .60329 L
.97257 .6033 L
Mistroke
.97385 .60331 L
.97506 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W00011@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3oooooooooZ?l00?ooZ?l005[o1@0go`D0>?l303co
0`0go`@0>_l301[o001Lo`030?oo03Oo00D0oooo000go`050?ooo`00??l00`3oo`0eo`030?oo00;o
00<0ool0=_l01@3oool001Wo001Lo`030?oo03So00<0ool0??l00`3oo`0jo`030?oo03[o00<0ool0
=_l01@3oool001Wo001Lo`030?oo03Wo00<0ool0>ol00`3oo`0fo`H0>ol00`3oo`0fo`050?ooo`00
6Ol005co00<0ool0>_l00`3oo`0ho`80>_l0103oo`0lo`030?oo03Ko100Jo`00G?l00`3oo`0jo`03
0?oo03[o00<0ool0=ol0103oo`0ho`@0>Ol00`3oo`0Ko`00G?l00`3oo`0ko`030?oo03Wo00<0ool0
>?l00`3o000ho`030?oo03[o00<0ool06ol005[o0`0io`050?ooo`00=ol01@3oool003[o00<0o`00
>?l00`3oo`0ko`030?oo01[o001Lo`030?oo03So0`0io`<0??l203So1@0jo`<06Ol00?ooZ?l00?oo
Z?l0023o00<0ool0oon5o`008?l00`3oo`3oohGo000Po`030?oo0?ooQOl0023o00<0ool0oon5o`00
8?l00`3oo`3oohGo000Po`030?oo0?ooQOl001Koo`2A007o000Po`030?oo00Wo2@03o`030?oo00Wo
00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02Ol00`3o
o`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo
00<0ool02_l00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3o
o`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo007o
000Po`030?oo01;o1`0Po`030?oo03[o00<0ool0>Ol00`3oo`0jo`030?oo03Wo00<0ool0>_l00`3o
o`0Io`008?l00`3oo`0Io`H0oomVo`008?l00`3oo`0Oo`@0oomRo`008?l00`3oo`0So`@0oomNo`00
8?l00`3oo`0Wo`@0oomJo`008?l00`3oo`0[o`@0oomFo`008?l00`3oo`0_o`80oomDo`008?l00`3o
o`0ao`<0oomAo`008?l00`3oo`0do`<0oom>o`008?l00`3oo`0go`80oom<o`008?l203[o0`3oodWo
000Po`030?oo03co0P3oodOo000Po`030?oo03ko0P3oodGo000Po`030?oo043o0P3ood?o000Po`03
0?oo04;o0P3ood7o000Po`030?oo04Co0P3oocoo000Po`030?oo04Ko0P3oocgo000Po`030?oo04So
0P3ooc_o000Po`030?oo04[o0P3oocWo000Po`030?oo04co0P3oocOo000Po`030?oo04ko0P3oocGo
000Po`80DOl20?oo<ol0023o00<0ool0D_l20?oo<Ol0023o00<0ool0E?l00`3oo`3oobko000Po`03
0?oo05Go0P3oobko000Po`030?oo05Oo0P3oobco000Po`030?oo05Wo0P3oob[o000Po`030?oo05_o
0P3oobSo000Po`030?oo05go00<0ool0oolUo`008?l00`3oo`1No`80oolUo`008?l00`3oo`1Po`03
0?oo0?oo8_l0023o00<0ool0HOl20?oo8_l0023o00<0ool0Hol00`3oo`3ooaoo000Po`80IOl00`3o
o`3ooako000Po`030?oo06Go0P3ooako000Po`030?oo06Oo00<0ool0oolKo`008?l00`3oo`1Xo`80
oolKo`008?l00`3oo`1Zo`030?oo0?oo6?l0023o00<0ool0Jol20?oo6?l0023o00<0ool0KOl00`3o
o`3ooaGo000Po`030?oo06ko00<0ool0oolDo`001Ol400Go0P04o`D01ol00`3oo`1_o`80oolDo`00
1?l00`3oo`02o`030?oo00;o0P04o`050?ooo`001ol00`3oo`1ao`030?oo0?oo4Ol000Co00<0ool0
0_l00`3oo`09o`030?oo00So00<0ool0L_l00`3oo`3ooa3o0004o`030?oo00;o00<0ool02_l00`3o
o`07o`030?oo07?o0P3ooa3o0004o`030?oo00;o00<0ool02ol00`3oo`06o`<0MOl00`3oo`3oo`go
0004o`030?oo00;o00<0ool02ol00`3oo`06o`030?oo07Ko00<0ool0ool<o`001?l00`3oo`02o`03
0?oo00co00<0ool01Ol00`3oo`1go`80ool<o`001?l00`3oo`02o`030?oo00So00D0oooo0007o`03
0?oo07Wo00<0ool0ool9o`001Ol400co0`08o`030?oo07[o00<0ool0ool8o`008?l00`3oo`1ko`80
ool8o`008?l00`3oo`1mo`030?oo0?oo1Ol0023o00<0ool0O_l00`3oo`3oo`Co000Po`030?oo07oo
00<0ool0ool3o`008?l00`3oo`20o`030?oo0?oo0_l0023o00<0ool0POl00`3oo`3oo`7o000Po`03
0?oo08;o00<0ool0ool0023o0P24o`030?oo0?ko000Po`030?oo08Co00<0ool0oOl0023o00<0ool0
QOl20?go000Po`030?oo08Oo00<0ool0n_l0023o00<0ool0R?l00`3oo`3io`008?l00`3oo`29o`03
0?oo0?So000Po`030?oo08[o00<0ool0mol0023o00<0ool0Rol00`3oo`3fo`008?l00`3oo`2<o`03
0?oo0?Go000Po`030?oo08go00<0ool0m?l0023o00<0ool0S_l00`3oo`3co`008?l2093o00<0ool0
l_l0023o00<0ool0T?l00`3oo`3ao`008?l00`3oo`2Ao`030?oo0?3o000Po`030?oo09;o00<0ool0
kol0023o00<0ool0Tol00`3oo`3^o`008?l00`3oo`2Do`030?oo0>go000Po`030?oo09Go0P3]o`00
8?l00`3oo`2Go`030?oo0>[o000Po`030?oo09So00<0ool0jOl0023o00<0ool0VOl00`3oo`3Xo`00
8?l00`3oo`2Jo`030?oo0>Oo000Po`030?oo09_o00<0ool0i_l0023o0P2Mo`030?oo0>Go000Po`03
0?oo09go00<0ool0i?l0023o00<0ool0W_l00`3oo`3So`008?l00`3oo`2Oo`030?oo0>;o000Po`03
0?oo0:3o00<0ool0hOl0023o00<0ool0XOl00`3oo`3Po`008?l00`3oo`2Qo`030?oo0>3o000Po`03
0?oo0:;o00<0ool0gol000Go1005o`801ol300Ko00<0ool0Xol00`3oo`3No`001?l00`3oo`02o`03
0?oo00;o0P08o`030?oo00Go00<0ool0Y?l00`3oo`3Mo`001?l00`3oo`02o`030?oo00co00<0ool0
1Ol00`3oo`2Uo`030?oo0=co0004o`030?oo00;o00<0ool02?l600Ko00<0ool0Y_l00`3oo`3Ko`00
1?l00`3oo`02o`030?oo00Wo00@0ool01ol30:Oo00<0ool0f_l000Co00<0ool00_l00`3oo`09o`04
0?oo00Oo00<0ool0Z?l00`3oo`3Io`001?l00`3oo`02o`030?oo00[o00<0o`001ol00`3oo`2Xo`03
0?oo0=Wo0004o`030?oo00;o00<0ool02_l00`3o0007o`030?oo0:Wo00<0ool0f?l000Go100>o`80
1ol00`3oo`2Zo`030?oo0=Oo000Po`030?oo0:_o00<0ool0e_l0023o00<0ool0[?l00`3oo`3Eo`00
8?l00`3oo`2]o`030?oo0=Co000Po`030?oo0:ko00<0ool0dol0023o00<0ool0[ol00`3oo`3Bo`00
8?l00`3oo`2_o`030?oo0=;o000Po`030?oo0;3o00<0ool0dOl0023o0P2bo`030?oo0=3o000Po`03
0?oo0;;o00<0ool0col0023o00<0ool0/ol00`3oo`3>o`008?l00`3oo`2do`030?oo0<go000Po`03
0?oo0;Co00<0ool0cOl0023o00<0ool0]Ol00`3oo`3<o`008?l00`3oo`2fo`030?oo0<_o000Po`03
0?oo0;Oo00<0ool0b_l0023o00<0ool0^?l00`3oo`39o`008?l00`3oo`2io`030?oo0<So000Po`03
0?oo0;Wo00<0ool0b?l0023o0P2ko`030?oo0<Oo000Po`030?oo0;_o00<0ool0a_l0023o00<0ool0
_?l00`3oo`35o`008?l00`3oo`2mo`030?oo0<Co000Po`030?oo0;ko00<0ool0`ol0023o00<0ool0
_ol00`3oo`32o`008?l00`3oo`30o`030?oo0<7o000Po`030?oo0<3o00<0ool0`Ol0023o00<0ool0
`Ol00`3oo`30o`008?l00`3oo`32o`030?oo0;oo000Po`030?oo0<?o00<0ool0__l0023o00<0ool0
a?l00`3oo`2mo`008?l20<Ko00<0ool0_?l0023o00<0ool0a_l00`3oo`2ko`008?l00`3oo`37o`03
0?oo0;[o000Po`030?oo0<So00<0ool0^Ol0023o00<0ool0b?l00`3oo`2io`008?l00`3oo`39o`03
0?oo0;So000Po`030?oo0<[o00<0ool0]ol0023o00<0ool0bol00`3oo`2fo`001Ol400Go0P06o`<0
1ol00`3oo`3<o`030?oo0;Go0004o`030?oo00;o00<0ool00_l200Go00D0oooo0006o`030?oo0<go
00<0ool0]?l000Co00<0ool00_l00`3oo`09o`050?ooo`001_l00`3oo`3>o`030?oo0;?o0004o`03
0?oo00;o00<0ool02Ol01@3oool000Ko00<0ool0col00`3oo`2bo`001?l00`3oo`02o`030?oo00Wo
1007o`<0d?l00`3oo`2ao`001?l00`3oo`02o`030?oo00Wo00<0ool02?l00`3oo`3@o`030?oo0;7o
0004o`030?oo00;o00<0ool02Ol00`3oo`08o`030?oo0=7o00<0ool0/?l000Co00<0ool00_l00`3o
o`0:o`030?oo00Oo00<0ool0d_l00`3oo`2_o`001Ol400ko0`06o`030?oo0=?o00<0ool0[_l0023o
00<0ool0e?l00`3oo`2]o`008?l00`3oo`3Eo`030?oo0:co000Po`030?oo0=Ko00<0ool0Zol0023o
00<0ool0eol00`3oo`2Zo`008?l00`3oo`3Ho`030?oo0:Wo000Po`030?oo0=So00<0ool0ZOl0023o
00<0ool0fOl00`3oo`2Xo`008?l20=_o00<0ool0Yol0023o00<0ool0fol00`3oo`2Vo`008?l00`3o
o`3Lo`030?oo0:Go000Po`030?oo0=go00<0ool0Y?l0023o00<0ool0g_l00`3oo`2So`008?l00`3o
o`3Oo`030?oo0:;o000Po`030?oo0>3o00<0ool0XOl0023o00<0ool0hOl00`3oo`2Po`008?l00`3o
o`3Ro`030?oo09oo000Po`030?oo0>?o00<0ool0W_l0023o00<0ool0i?l209ko000Po`80iol00`3o
o`2Ko`008?l00`3oo`3Wo`030?oo09[o000Po`030?oo0>So00<0ool0VOl0023o00<0ool0jOl00`3o
o`2Ho`008?l00`3oo`3Zo`030?oo09Oo000Po`030?oo0>_o00<0ool0U_l0023o00<0ool0k?l00`3o
o`2Eo`008?l00`3oo`3]o`030?oo09Co000Po`030?oo0>ko00<0ool0Tol0023o00<0ool0kol00`3o
o`2Bo`008?l00`3oo`3`o`030?oo097o000Po`030?oo0?7o00<0ool0T?l0023o0P3co`030?oo08oo
000Po`030?oo0??o0P2?o`008?l00`3oo`3eo`030?oo08co000Po`030?oo0?Ko00<0ool0Rol0023o
00<0ool0mol00`3oo`2:o`008?l00`3oo`3ho`030?oo08Wo000Po`030?oo0?Wo00<0ool0R?l0023o
00<0ool0n_l00`3oo`27o`001Ol400Go0P05o`<02?l00`3oo`3ko`030?oo08Ko0004o`030?oo00;o
00<0ool00_l200Co00D0oooo0007o`030?oo0?co00<0ool0QOl000Co00<0ool00_l00`3oo`08o`05
0?ooo`001ol00`3oo`3mo`80QOl000Co00<0ool00_l00`3oo`08o`050?ooo`001ol00`3oo`3oo`03
0?oo08;o0004o`030?oo00;o00<0ool02Ol300So0`3oo`7o00<0ool0POl000Co00<0ool00_l00`3o
o`08o`050?ooo`001ol00`3oo`3oo`;o0P21o`001?l00`3oo`02o`030?oo00So00D0oooo0007o`03
0?oo0?oo1?l00`3oo`1no`001?l00`3oo`02o`030?oo00So00D0oooo0007o`030?oo0?oo1Ol00`3o
o`1mo`001Ol400co0`08o`030?oo0?oo1_l207go000Po`030?oo0?oo2?l00`3oo`1jo`008?l00`3o
o`3oo`Wo00<0ool0NOl0023o00<0ool0ool:o`80NOl0023o00<0ool0ool<o`030?oo07Ko000Po`03
0?oo0?oo3Ol207Ko000Po`030?oo0?oo3ol00`3oo`1co`008?l00`3oo`3ooa3o0P1co`008?l20?oo
4ol2077o000Po`030?oo0?oo5?l00`3oo`1^o`008?l00`3oo`3ooaGo0P1^o`008?l00`3oo`3ooaOo
00<0ool0Jol0023o00<0ool0oolHo`80Jol0023o00<0ool0oolJo`80JOl0023o00<0ool0oolLo`03
0?oo06Ko000Po`030?oo0?oo7Ol206Ko000Po`030?oo0?oo7ol206Co000Po`030?oo0?oo8Ol00`3o
o`1Qo`008?l00`3oo`3oob;o0P1Qo`008?l20?oo9Ol205oo000Po`030?oo0?oo9_l00`3oo`1Lo`00
8?l00`3oo`3oobOo0P1Lo`008?l00`3oo`3oobWo0P1Jo`008?l00`3oo`3oob_o0P1Ho`008?l00`3o
o`3oobgo0P1Fo`008?l00`3oo`3ooboo0P1Do`008?l00`3oo`3ooc7o0P1Bo`008?l00`3oo`3ooc?o
0`1?o`008?l00`3oo`3oocKo0P1=o`008?l00`3oo`3oocSo0P1;o`008?l00`3oo`3ooc[o0`18o`00
8?l20?oo?_l204Ko000Po`030?oo0?oo?ol304?o000Po`030?oo0?oo@_l3043o000Po`030?oo0?oo
AOl203ko000Po`030?oo0?ooAol303_o000Po`030?oo0?ooB_l303So000Po`030?oo0?ooCOl403Co
000Po`030?oo0?ooDOl4033o000Eo`D01_l00`3oo`3ooeGo100/o`005ol00`3oo`06o`030?oo0?oo
FOl802Co000Go`030?oo00Ko00<0ool0oomQo`@08?l001Oo00<0ool01_l00`3oo`3oofGo300Do`00
5ol00`3oo`06o`<0oomao`X02_l001Oo00<0ool01_l00`3oo`3oohGo000Go`030?oo00Ko00<0ool0
oon5o`005Ol300So00<0ool0oon5o`005ol00`3oo`06o`030?oo0?ooQOl0023o00<0ool0oon5o`00
8?l00`3oo`3oohGo0000\
\>"],
  ImageRangeCache->{{{0, 422}, {260, 0}} -> {-0.534553, -0.0787381, 
  0.0248115, 0.00638941}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Higher Derivatives", "Subsection",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "As the cam rotates, the angle theta is given by some function of ",
  StyleBox["t",
    FontWeight->"Bold"],
  ". Taking derivatives shows how the displacement varies with time."
}], "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Clear[y]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Velocity:", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["D[y[theta[t]], t]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["theta", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
        SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", \(theta[t]\), "]"}]}]], "Output"]
}, Closed]],

Cell["Acceleration:", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["D[y[theta[t]], {t, 2}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", \(theta[t]\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["theta", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
        SuperscriptBox[
          RowBox[{
            SuperscriptBox["theta", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
        RowBox[{
          SuperscriptBox["y", "\[DoublePrime]",
            MultilineFunction->None], "[", \(theta[t]\), "]"}]}]}]], "Output"]
}, Closed]],

Cell["Jerk:", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["D[y[theta[t]], {t, 3}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{
      RowBox[{"3", " ", 
        RowBox[{
          SuperscriptBox["theta", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["theta", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["y", "\[DoublePrime]",
            MultilineFunction->None], "[", \(theta[t]\), "]"}]}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", \(theta[t]\), "]"}], " ", 
        RowBox[{
          SuperscriptBox["theta", 
            TagBox[\((3)\),
              Derivative],
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
        SuperscriptBox[
          RowBox[{
            SuperscriptBox["theta", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((3)\),
              Derivative],
            MultilineFunction->None], "[", \(theta[t]\), "]"}]}]}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polynomial Cams", "Subsection",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Clear[y]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["y[theta_] = Sum[c[i] (theta/beta)^i, {i, 0, 5}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(c[0] + \(theta\ c[1]\)\/beta + \(theta\^2\ c[2]\)\/beta\^2 + 
      \(theta\^3\ c[3]\)\/beta\^3 + \(theta\^4\ c[4]\)\/beta\^4 + 
      \(theta\^5\ c[5]\)\/beta\^5\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
eqns = {y[0]==0, y'[0]==0, y''[0]==0, y[beta]==L, y'[beta]==0,
\t\t\t\ty''[beta]==0}\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({c[0] == 0, c[1]\/beta == 0, \(2\ c[2]\)\/beta\^2 == 0, 
      c[0] + c[1] + c[2] + c[3] + c[4] + c[5] == L, 
      c[1]\/beta + \(2\ c[2]\)\/beta + \(3\ c[3]\)\/beta + 
          \(4\ c[4]\)\/beta + \(5\ c[5]\)\/beta == 0, 
      \(2\ c[2]\)\/beta\^2 + \(6\ c[3]\)\/beta\^2 + \(12\ c[4]\)\/beta\^2 + 
          \(20\ c[5]\)\/beta\^2 == 0}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solve[eqns, Array[c, 6, 0]]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{c[0] \[Rule] 0, c[3] \[Rule] 10\ L, c[4] \[Rule] \(-15\)\ L, 
        c[5] \[Rule] 6\ L, c[1] \[Rule] 0, c[2] \[Rule] 0}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["First[y[theta] /. %]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(10\ L\ theta\^3\)\/beta\^3 - \(15\ L\ theta\^4\)\/beta\^4 + 
      \(6\ L\ theta\^5\)\/beta\^5\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Harmonic Cams", "Subsection",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Here are the equations for the displacement of a modified harmonic cam.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["beta=Pi;", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(beta\)\" is similar to \
existing symbol \"\!\(Beta\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ydisp = 1/2 (       (1 - Cos[  Pi theta/beta]) - 
\t\t\t\t1/4 (1 - Cos[ 2Pi theta/beta]))\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/2\ \((1 - Cos[theta] + 1\/4\ \((\(-1\) + Cos[2\ theta])\))\)\)], 
  "Output"]
}, Open  ]],

Cell["\<\

Here is a picture of the cam.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["CamPlot[2, ydisp, theta]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.5 .75 m
.50194 .74999 L
.5037 .74997 L
.50574 .74993 L
.50766 .74988 L
.51109 .74975 L
.5148 .74956 L
.51889 .74929 L
.52323 .74892 L
.531 .74809 L
.54651 .74572 L
.56354 .74208 L
.58061 .7374 L
.59881 .73133 L
.6311 .71809 L
.69188 .6853 L
.71847 .66717 L
.7399 .64955 L
.75695 .63153 L
.76468 .62088 L
.77048 .61073 L
.77303 .60523 L
.77536 .59925 L
.77706 .59392 L
.77857 .58802 L
.77928 .58461 L
.77982 .58145 L
.78029 .57818 L
.78064 .5751 L
.78095 .57145 L
.78107 .56949 L
.78112 .56848 L
.78116 .56739 L
.78122 .56555 L
.78124 .56381 L
.78125 .5628 L
.78125 .56172 L
.78124 .5608 L
.78122 .55979 L
.78117 .55784 L
.7811 .55604 L
.781 .55404 L
.78087 .55189 L
.78057 .54824 L
.78015 .54415 L
.7791 .53638 L
.77781 .52885 L
.77386 .51108 L
.76801 .49055 L
.73212 .39981 L
Mistroke
.68165 .30115 L
.62424 .21213 L
.59283 .17491 L
.57511 .15806 L
.55871 .14538 L
.5418 .13541 L
.53289 .13146 L
.52834 .1298 L
.52347 .1283 L
.51917 .1272 L
.51526 .1264 L
.51132 .12577 L
.50955 .12555 L
.5076 .12535 L
.50549 .12518 L
.50434 .12511 L
.50326 .12506 L
.50133 .12501 L
.49925 .125 L
.49815 .12502 L
.49695 .12506 L
.49569 .12511 L
.49452 .12518 L
.49243 .12534 L
.49019 .12558 L
.48591 .12619 L
.48138 .12708 L
.47327 .12928 L
.46455 .1325 L
.45498 .13706 L
.4379 .14777 L
.42202 .16057 L
.3893 .19499 L
.36022 .23374 L
.30245 .33007 L
.25729 .42363 L
.24016 .4665 L
.23295 .48753 L
.22675 .50873 L
.22446 .51801 L
.22246 .52743 L
.22098 .53583 L
.21994 .54337 L
.21955 .54692 L
.21926 .55022 L
.21912 .55202 L
.219 .55395 L
.21891 .55569 L
.21884 .55729 L
.21879 .55905 L
Mistroke
.21876 .56098 L
.21875 .56283 L
.21876 .56386 L
.21877 .5648 L
.21881 .56646 L
.21887 .56826 L
.21896 .56994 L
.21905 .57148 L
.21936 .57509 L
.21973 .57834 L
.22024 .58185 L
.22089 .58549 L
.22226 .59144 L
.22413 .59775 L
.22861 .60887 L
.23395 .6187 L
.24993 .63946 L
.2687 .65708 L
.31956 .69228 L
.37726 .72181 L
.40883 .73401 L
.42523 .73911 L
.44302 .74361 L
.45831 .74655 L
.46502 .74757 L
.47237 .74848 L
.47934 .74915 L
.48583 .7496 L
.48942 .74978 L
.49268 .74989 L
.49449 .74994 L
.49645 .74997 L
.4983 .74999 L
.5 .75 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`@0dol00<ko0`000ol0000=0<oo003=oaP0bol00<co
7@37o`00bOlP0<Oo0035obL0a?l00<7o;033o`00`Ol_0<3o0031oc00_ol00;oo<`2no`00__lA00[o
00@0o`000_lE0;co002loa403?l00`3oo`0:oa00^_l00;_o400>o`030?oo00co402ho`00^Ol?017o
00<0ool03_l@0;Ko002io`d04ol00`3oo`0Ao`h0]Ol00;So300Eo`<04_l>0;Co002go``05_l00`3o
o`0Do`d0/ol00;Go3@0Go`030?oo01Go3@2bo`00]?l<01Wo00<0ool05ol<0;7o002co``06_l00`3o
o`0Ho``0/?l00;?o2`0Ko`030?oo01Wo3@2^o`00/_l;01co00<0ool06_l=0:go002ao`/07Ol00`3o
o`0Ko``0[Ol00;3o2`0No`030?oo01co302/o`00[ol;01oo00<0ool07Ol<0:_o002^o`/08?l301ko
302Zo`00[Ol;027o00<0ool07ol;0:[o002/o`/08_l00`3oo`0Po`/0ZOl00:_o2`0So`030?oo027o
2`2Xo`00ZOl<02Co00<0ool08_l;0:Oo002Yo`/09Ol00`3oo`0So`/0Y_l00:So2`0Vo`030?oo02Co
2P2Vo`00Yol;02Oo00<0ool09Ol:0:Go002Vo`/0:?l00`3oo`0Vo`X0Y?l00:Go2`0Yo`030?oo02Oo
2P2So`00YOl:02[o00<0ool0:?l:0:;o002To`X0:ol302So2P2Ro`00Y?l902co00<0ool0:Ol:0:7o
002So`X0;?l00`3oo`0Zo`X0X?l00:;o2P0]o`030?oo02_o2P2Oo`00X_l902ko00<0ool0;?l909oo
002Qo`T0;ol00`3oo`0/o`X0W_l00:3o2P0_o`030?oo02go2P2Mo`00X?l9033o00<0ool0;_l909go
002Oo`T0<Ol00`3oo`0_o`P0WOl009ko2P0ao`030?oo02oo2@2Lo`00WOl:03;o0`0`o`T0Vol009go
2@0co`030?oo037o202Ko`00W?l:03?o00<0ool0<Ol909[o002Ko`X0=?l00`3oo`0bo`P0V_l009_o
2@0eo`030?oo03?o202Io`00V_l903Ko00<0ool0<ol909So002Jo`T0=_l00`3oo`0do`P0V?l009Wo
2@0[o`D01ol00`3oo`0do`T0Uol009Wo200/o`050?ooo`001ol00`3oo`0eo`T0U_l009So2@0]o`03
0?oo00So00<0ool0=_l809Ko002Go`T0;ol00`3oo`07o`030?oo03Ko2@2Eo`00Uol802Ko1P05o`03
0?oo00Ko100fo`T0U?l009Ko2@0ao`030?oo00Ko00<0ool0>?l809Co002Eo`T0<ol00`3oo`05o`03
0?oo03So2@2Co`00UOl8033o00D0oooo0007o`030?oo03Wo2@2Bo`00U?l9037o0`08o`030?oo03[o
202Bo`00U?l803go00<0ool0>_l9097o002Co`P0?_l00`3oo`0ko`T0T?l009;o2@0no`030?oo03co
202@o`00T_l803oo00<0ool0??l908oo002Ao`T0?ol00`3oo`0mo`T0S_l0097o2010o`<0?_l808ko
002@o`P0@Ol00`3oo`0no`T0SOl008oo2@11o`030?oo03oo202=o`00Sol804;o00<0ool0@?l808co
002>o`T0@_l00`3oo`10o`T0Rol008ko2013o`030?oo047o202;o`00SOl804Co00<0ool0@Ol908[o
002<o`T0A?l00`3oo`12o`T0ROl008co2015o`030?oo04?o2029o`00Rol904Go00<0ool0@ol908So
002;o`P0A_l304Co2@27o`00R_l804Oo00<0ool0AOl808Oo0029o`T0Aol00`3oo`15o`T0Q_l008Wo
2018o`030?oo04Ko2026o`00R?l904So00<0ool0Aol708Ko0027o`T0BOl00`3oo`17o`P0QOl008Oo
201:o`030?oo04So1`25o`00Q_l904[o00<0ool0B?l808Co0026o`P0Bol00`3oo`19o`L0Q?l008Go
201<o`030?oo04Wo2023o`00Q?l904co00<0ool0B_l708?o0024o`P0COl304[o2022o`00Pol904go
00<0ool0Bol708;o0023o`P0C_l00`3oo`1;o`P0POl008;o2@1>o`030?oo04co1`21o`00P_l804oo
00<0ool0C?l8083o0021o`T0Col00`3oo`1=o`L0P?l0087o201@o`030?oo04go201oo`00P?l9053o
00<0ool0C_l707oo0020o`P0DOl00`3oo`1>o`P0O_l007oo2@1Ao`030?oo04oo201mo`00Ool805;o
0`1?o`P0OOl007ko2@1Bo`030?oo053o201lo`00O_l805?o00<0ool0DOl707co001mo`T0Dol00`3o
o`1Ao`P0Nol007go201Do`030?oo05;o1`1ko`00O?l905Co00<0ool0D_l807[o001lo`P0EOl00`3o
o`1Co`L0N_l007_o2@1:o`D01_l00`3oo`1Co`P0NOl007_o201=o`030?oo00Ko00<0ool0E?l707Wo
001jo`T0COl00`3oo`06o`030?oo05Co201ho`00N_l804ko00<0ool01_l00`3oo`1Eo`L0N?l007[o
2013o`H01Ol00`3oo`06o`@0E?l807Oo001io`P0Col00`3oo`06o`030?oo05Ko1`1go`00NOl804oo
00<0ool01_l00`3oo`1Fo`P0M_l007So2@1=o`<02?l00`3oo`1Go`L0M_l007So201@o`030?oo00Ko
00<0ool0Eol807Go001go`T0FOl00`3oo`1Ho`L0MOl007Oo201Jo`030?oo05So201do`00M_l905[o
00<0ool0FOl807?o001fo`P0Fol00`3oo`1Io`P0Lol007Go2@1Ko`030?oo05Wo2@1bo`00MOl805co
0`1Jo`P0L_l007Co2@1Lo`030?oo05[o201bo`00M?l805go00<0ool0Fol8077o001co`T0GOl00`3o
o`1Ko`P0LOl007?o201No`030?oo05_o2@1`o`00L_l905ko00<0ool0G?l8073o001bo`P0Gol00`3o
o`1Lo`P0L?l0077o2@1Oo`030?oo05go201_o`00LOl8063o00<0ool0GOl806oo001`o`T0H?l00`3o
o`1Mo`T0K_l0073o201Qo`030?oo05ko201^o`00Kol9067o0`1No`P0K_l006oo201Ro`030?oo05oo
201]o`00Kol806;o00<0ool0Gol806go001^o`T0H_l00`3oo`1Oo`T0K?l006ko201So`030?oo063o
201/o`00K_l806?o00<0ool0H?l806co001]o`P0I?l00`3oo`1Qo`P0Jol006go201To`030?oo067o
201[o`00K?l906Co00<0ool0HOl906[o001/o`P0IOl00`3oo`1Ro`P0J_l006co201Uo`<0H_l806[o
001[o`P0I_l00`3oo`1So`P0JOl006_o201Vo`030?oo06?o201Yo`00J_l906Ko00<0ool0Hol906So
000=o`<0;ol302So3@0`o`D0;Ol00`3oo`0_o`D0;ol902co0`0co`<00ol000ko00<0ool0;Ol01@3o
ool002Oo2@03o`030?oo033o00<0ool0;Ol00`3oo`0ao`030?oo02oo2@0[o`050?ooo`00<ol00`3o
o`02o`003_l00`3oo`0ao`030?oo02Co2002o`030?oo03?o00<0ool0;Ol00`3oo`0ao`030?oo033o
2@0^o`030?oo037o00<0ool00_l000[o1P0bo`030?oo02Co2003o`030?oo03;o00<0ool0;Ol00`3o
o`0ao`030?oo037o200^o`030?oo02go1P03o`000_l600?o00@0ool09ol600Co0P0Vo`T01?l00`3o
o`0Vo`H01Ol00`3oo`0]o`030?oo037o00<0ool0<Ol902_o0P0ao`040?oo00Co000;o`040?oo03?o
00<0ool08ol800Go00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0<_l802go00<0ool0;_l0103o
o`04o`003?l00`3o000co`030?oo02?o2006o`030?oo033o00<0ool0;Ol00`3oo`0ao`030?oo03;o
200]o`030?oo02oo00<0o`001?l000co00<0o`00;ol01@3oool002Go2002o`050?ooo`00<?l302oo
0`0_o`<0<Ol0103oool802So00D0oooo000ao`030?l000Co000=o`80<?l302Go2004o`<0<ol00`3o
o`0]o`030?oo037o00<0ool0<?l;02Wo0`0co`801?l006Oo201Zo`030?oo06Oo2@1To`00Iol806[o
00<0ool0J?l806Co001Vo`P0Jol00`3oo`1Xo`P0I?l006Ko201[o`030?oo06Wo201So`00I_l806_o
00<0ool0JOl806?o001Uo`P0K?l00`3oo`1Yo`T0H_l006Go201/o`030?oo06[o201Ro`00IOl806co
00<0ool0J_l806;o0009ool0X`05o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01Ol800Go00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00;o2008o`030?oo00Oo00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1Ol800Go00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00;o2008o`03
0?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`03o`002Ol00`3oo`0ao`030?oo02?o2@05o`030?oo037o00<0ool0<Ol00`3oo`0ao`03
0?oo03;o00<0ool00_l802Oo00<0ool0<Ol00`3oo`03o`00Hol806ko00<0ool0Jol9063o001So`P0
K_l00`3oo`1/o`P0H?l006;o2@1^o`030?oo06co201Po`00H_l906ko00<0ool0K?l905oo001Qo`T0
Kol00`3oo`1/o`T0Gol0067o2@1_o`030?oo06co2@1Oo`00HOl906oo0`1/o`T0Gol0067o2@1_o`03
0?oo06go201Oo`00HOl906oo00<0ool0KOl905ko001Po`X0Kol00`3oo`1]o`T0G_l0063o2@1`o`03
0?oo06ko201No`00H?l9073o00<0ool0K_l805ko001Po`T0L?l00`3oo`1^o`P0G_l0063o2@1`o`03
0?oo06ko2@1Mo`00H?l9073o00<0ool0KOl:05go001Po`T0L?l00`3oo`1^o`T0GOl005oo2@1ao`03
0?oo06ko2@1Mo`00Gol9077o0`1^o`T0GOl0063o201ao`030?oo06ko2@1Mo`00H?l8077o00<0ool0
K_l905go001Po`P0LOl00`3oo`1^o`X0G?l0063o201ao`030?oo06oo201Mo`00H?l8077o00<0ool0
Kol805go001Po`P0LOl00`3oo`1_o`P0GOl0063o201ao`030?oo06ko2@1Mo`00H?l8077o00<0ool0
K_l:05co001Po`P0LOl00`3oo`1]o``0Fol0063o201ao`<0K?l<05co001Oo`T0LOl00`3oo`1]o`X0
GOl0063o2@1`o`030?oo06ko2@1Mo`00H?l9073o00<0ool0K_l905go001Po`T0L?l00`3oo`1^o`T0
GOl0063o2@1`o`030?oo06ko2@1Mo`00H?l9073o00<0ool0K_l805ko001Po`X0Kol00`3oo`1]o`T0
G_l0067o201`o`030?oo06go2@1No`00HOl906oo00<0ool0K?l:05ko001Qo`T0Kol00`3oo`1/o`X0
G_l0067o2P1^o`<0Jol9063o001So`P0K_l00`3oo`1[o`T0H?l006?o2@1]o`030?oo06_o201Qo`00
I?l806go00<0ool0J_l9067o001To`T0K?l00`3oo`1Zo`P0H_l006Go201/o`030?oo06Wo2@1Ro`00
IOl906_o00<0ool0JOl806?o001To`/0Gol500Ko00<0ool0J?l906?o001Uo`/0H?l00`3oo`06o`03
0?oo06So201To`00I_l;05oo00<0ool01_l00`3oo`1Wo`T0I?l006Oo2P1Oo`030?oo00Ko101Vo`P0
IOl006Oo2`1No`030?oo00Ko00<0ool0I_l906Go001Xo`/0GOl00`3oo`06o`030?oo06Go2@1Vo`00
J_l:05co00<0ool01_l00`3oo`1To`/0IOl006_o2P1Io`<02?l00`3oo`1Ro``0I_l006_o2`1Jo`03
0?oo00Ko00<0ool0HOl<06Oo001[o``0H_l00`3oo`1Po``0J?l006co301Qo`030?oo05oo301Yo`00
KOl<063o00<0ool0G_l<06[o001^o``0Gol00`3oo`1Mo``0Jol006oo301No`030?oo05co2`1]o`00
L?l<05go0`1Ko`/0K_l0077o301Lo`030?oo05Wo301_o`00L_l<05_o00<0ool0F?l<073o001co``0
F_l00`3oo`1Go``0LOl007Co3@1Ho`030?oo05Ko301bo`00MOl=05Oo00<0ool0EOl<07?o001fo`h0
EOl00`3oo`1Co`d0M?l007Oo3P1Do`030?oo05;o301fo`00N?l?05;o00<0ool0D?l=07Oo001ko`d0
DOl00`3oo`1>o`h0N?l007go3@1?o`<0COl>07Wo001no`d0C_l00`3oo`1;o`l0N_l0083o3@1<o`03
0?oo04[o3`1ko`00POl=04_o00<0ool0B?l>07ko0023o`d0BOl00`3oo`16o`h0P?l008Co3@18o`03
0?oo04Go3P21o`00Q_l=04Ko00<0ool0@ol?08;o0027o`h0A?l00`3oo`11o`l0Q?l008Wo3P12o`03
0?oo03oo3`26o`00R_l>047o00<0ool0?_l>08So002<o`h0?ol303co3P2:o`00SOl?03go00<0ool0
>_l?08_o002@o`h0>ol00`3oo`0ho`l0SOl009;o3P0io`030?oo03Ko3`2?o`00U?l=03So00<0ool0
=?l?097o002Eo`h0=_l00`3oo`0boa00T_l009Oo3P0do`030?oo033o402Do`00VOl>03;o00<0ool0
;_l@09Ko002Ko`l0;ol00`3oo`0[oa40V?l009go400/o`030?oo02Wo4@2Jo`00W_lA02[o00<0ool0
9olB09_o002Poa809ol302?o502Mo`00XOlD02Co00<0ool07olF09oo002SoaH08?l00`3oo`0JoaT0
XOl00:Go5`0Mo`030?oo01Wo602So`00Z?lI01So00<0ool05_lH0:Ko002[oa/00_l200oo00<0ool0
4OlK0:So002]ob802_l00`3oo`0<oah0Z_l00;3oE02/o`00/om;0;;o002fodD0]Ol00;Wo?`2ho`00
_Olh0;_o0030oc40_ol00<Co:P32o`00b_lP0<Ko003>o`<02?l00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3o
o`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`03
0?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\

The next cell group contains a movie of the cam rotating.To see the movie, \
first select
the cell and click it to start the animation.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["SpinCam[2, ydisp, theta, 15]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.166667,
  AnimationCycleOffset->0.0625,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.60168 .72839 m
.62923 .71403 L
.65651 .69531 L
.70847 .64591 L
.74778 .59549 L
.76567 .56722 L
.77865 .54208 L
.7837 .52981 L
.78593 .52341 L
.78796 .51667 L
.78942 .51081 L
.7907 .50438 L
.79114 .50157 L
.79154 .49854 L
.79183 .49569 L
.79203 .49308 L
.79212 .49149 L
.79218 .48998 L
.79222 .48863 L
.79224 .48717 L
.79223 .48557 L
.79222 .48476 L
.7922 .48388 L
.79215 .48231 L
.79207 .48085 L
.79197 .47937 L
.79186 .47797 L
.79159 .47534 L
.79122 .47251 L
.79072 .46941 L
.78933 .46281 L
.78734 .45573 L
.78239 .44278 L
.7761 .43025 L
.76752 .41628 L
.74723 .38959 L
.68081 .32253 L
.59654 .25304 L
.50821 .19321 L
.46399 .17014 L
.44038 .16062 L
.41986 .15442 L
.41025 .15232 L
.4051 .15143 L
.40036 .15078 L
.39638 .15035 L
.39435 .15018 L
.39216 .15004 L
.38978 .14992 L
.38754 .14985 L
Mistroke
.38538 .14983 L
.3834 .14984 L
.38107 .14991 L
.37976 .14996 L
.37857 .15003 L
.3764 .15019 L
.37412 .1504 L
.37022 .15089 L
.36602 .15161 L
.36162 .15258 L
.35701 .15385 L
.34897 .15677 L
.3411 .16059 L
.33416 .16486 L
.31964 .17712 L
.30817 .19084 L
.29734 .20822 L
.28865 .2263 L
.28044 .24801 L
.26835 .29226 L
.26329 .3175 L
.25867 .34618 L
.25477 .37695 L
.25193 .40587 L
.25077 .42029 L
.2497 .43583 L
.24892 .44943 L
.24824 .46368 L
.24777 .47638 L
.24758 .48304 L
.2474 .49013 L
.24728 .49658 L
.2472 .50241 L
.24717 .50521 L
.24715 .50823 L
.24713 .51107 L
.24713 .51369 L
.24713 .51673 L
.24713 .51991 L
.24715 .52261 L
.24717 .52555 L
.24721 .52871 L
.24725 .53206 L
.24737 .53804 L
.24752 .54401 L
.24769 .54957 L
.24811 .55978 L
.24877 .5716 L
.24953 .58213 L
.25054 .5932 L
Mistroke
.25183 .60459 L
.25462 .6232 L
.25789 .63914 L
.26266 .65626 L
.26792 .6702 L
.27407 .68258 L
.28061 .69275 L
.28872 .70256 L
.29847 .71161 L
.30894 .71909 L
.32142 .72599 L
.33428 .73154 L
.34697 .73591 L
.37389 .74277 L
.39026 .74581 L
.40613 .74816 L
.42326 .7501 L
.43184 .75087 L
.43984 .75145 L
.44714 .75189 L
.45493 .75223 L
.45897 .75237 L
.46278 .75246 L
.46496 .75251 L
.46695 .75254 L
.46915 .75256 L
.47025 .75257 L
.47146 .75258 L
.47372 .75258 L
.47581 .75257 L
.4769 .75257 L
.4781 .75255 L
.47936 .75254 L
.48053 .75252 L
.48465 .75244 L
.48697 .75238 L
.48908 .75231 L
.49301 .75215 L
.49728 .75194 L
.50504 .75144 L
.51399 .75066 L
.52345 .74959 L
.54028 .74702 L
.55602 .74374 L
.57265 .73923 L
.60168 .72839 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00:?o0P0;o`809ol00`3o
o`3Do`00W_lH02?o00<0ool0e?l009[o7P0Qo`030?oo0=Co002Job<07?l00`3oo`3Do`00UolY01Wo
0`3Do`00U?la01Co00<0ool0e?l009;o<`0Do`030?oo0=Co002BocD04_l00`3oo`3Do`00T?lj00oo
00<0ool0e?l008oo5P0>oaT03Ol00`3oo`3Do`00SOl@01go5@0:o`030?oo0=Co002<o`l08_lC00Wo
00<0ool0e?l008_o3@0Woa<01ol00`3oo`3Do`00R_l=02_o4P05o`030?oo0=Co0029o``0;olB00?o
0`3Do`00R?l<03;o4P000ol0o`3Eo`00Qol<03Ko4@3Fo`00Qol;03Wo4@3Do`00Q_l;03co4@3Bo`00
Q_l:03oo4@3@o`00QOl:04;o4@3>o`00Q?l:04Go3`3>o`00Pol:04So3P3=o`00Pol904_o3P3;o`00
Pol904go3@3:o`00P_l904ko3`38o`00P_l804oo00<0ool03@37o`00POl904oo00<0ool00_l=0<Go
0021o`P0D?l00`3oo`03o`d0a?l0083o2@1@o`030?oo00Go3@32o`00P?l8057o00<0ool01_l=0<7o
001oo`T0DOl00`3oo`08o`d0_ol007oo201Bo`030?oo00Wo3@2no`00O_l905;o00<0ool02ol<0;go
001no`P0Dol00`3oo`0<o`d0^ol007go2@1Co`<03_l<0;[o001mo`P0E?l00`3oo`0?o`d0^?l007co
2@1Do`030?oo017o302go`00O?l805Go00<0ool04_l=0;Go001lo`P0EOl00`3oo`0Co`d0]?l007co
201Eo`030?oo01Go3@2bo`00Nol805Ko00<0ool05_l=0;7o001ko`P0B_l500Oo00<0ool06?l>0:ko
001ko`P0B_l01@3oool000Oo00<0ool06Ol>0:go001jo`P0C?l00`3oo`08o`030?oo01_o3P2[o`00
N_l804go00<0ool01ol00`3oo`0Lo`h0Z_l007[o2013o`H01Ol00`3oo`06o`@07Ol=0:Wo001io`P0
Col00`3oo`06o`030?oo01oo3@2Xo`00NOl8053o00<0ool01Ol00`3oo`0Qo``0Yol007Wo201<o`05
0?ooo`001ol00`3oo`0Ro`d0YOl007Wo201=o`<02?l00`3oo`0To``0Y?l007Wo1`1Io`030?oo02Go
302So`00N?l805Wo00<0ool09_l<0:;o001ho`P0FOl00`3oo`0Wo``0XOl007So1`1Jo`030?oo02So
3@2Oo`00Mol805[o00<0ool0:_l<09ko001go`P0F_l302_o302Mo`00Mol705_o00<0ool0;?l<09co
001fo`P0Fol00`3oo`0]o``0Vol007Ko201Ko`030?oo02ko3@2Io`00M_l805_o00<0ool0<?l<09So
001fo`P0Fol00`3oo`0ao``0Uol007Go201Lo`030?oo03;o302Fo`00MOl805co00<0ool0<ol<09Go
001eo`P0G?l00`3oo`0do`d0Tol007Co201Mo`030?oo03Ko302Bo`00M?l805go0`0go``0TOl007Co
201Mo`030?oo03So302@o`00M?l705ko00<0ool0>Ol<08oo001do`L0G_l00`3oo`0jo`d0SOl007?o
201No`030?oo03co302<o`00Lol805ko00<0ool0?Ol<08_o001co`L0Gol00`3oo`0no``0R_l007;o
201Oo`030?oo03oo3029o`00L_l805oo00<0ool0@?l=08Oo001bo`L0H?l00`3oo`12o``0Q_l0077o
201Po`030?oo04?o3025o`00LOl8063o0`14o`/0QOl007;o1`1Po`030?oo04Go2`24o`00L_l7063o
00<0ool0A_l;08?o001ao`P0H?l00`3oo`17o`/0P_l0077o1`1Qo`030?oo04So2`21o`00L?l8067o
00<0ool0BOl;083o001`o`P0HOl00`3oo`1:o`/0Ool0073o201Qo`030?oo04_o2`1no`00L?l8067o
00<0ool0C?l;07go001`o`P0HOl00`3oo`1=o`/0O?l0073o201Qo`<0C_l;07_o001`o`P0HOl00`3o
o`1?o`/0N_l0073o201Qo`030?oo053o2`1io`00L?l8067o00<0ool0DOl;07So001`o`P0HOl00`3o
o`1Bo`/0Mol006oo2@1Qo`030?oo05?o2`1fo`00Kol806;o00<0ool0E?l;07Go001_o`P0Eol500Ko
00<0ool0EOl;07Co001_o`P0FOl00`3oo`06o`030?oo05Ko2`1co`00Kol805Wo00<0ool01_l00`3o
o`1Go`/0L_l006oo201Io`030?oo00Ko00<0ool0F?l;077o001_o`P0C_l600Go00<0ool01_l405So
2`1`o`00Kol805Wo00<0ool01_l00`3oo`1Jo`/0Kol006oo201Io`030?oo00Ko00<0ool0Fol;06ko
001_o`P0Eol300So00<0ool0G?l;06go001_o`P0FOl00`3oo`06o`030?oo05go2`1/o`00Kol806;o
00<0ool0G_l;06_o001_o`P0H_l00`3oo`1Oo`/0J_l006ko2@1Ro`030?oo063o2P1Zo`00K_l806?o
00<0ool0HOl:06Wo001^o`P0Hol00`3oo`1Qo`/0J?l006ko201So`<0H_l:06So001^o`P0Hol00`3o
o`1So`X0Iol006ko201So`030?oo06Co2P1Vo`00K_l806?o00<0ool0IOl:06Go001^o`P0Hol00`3o
o`1Vo`X0I?l006ko201So`030?oo06Ko2`1So`00KOl906?o00<0ool0Iol:06?o001]o`P0I?l00`3o
o`1Xo`X0H_l006go201To`030?oo06Wo2P1Qo`00KOl806Co00<0ool0J_l9067o001]o`P0I?l00`3o
o`1[o`T0H?l006go201To`<0Jol9063o001]o`P0I?l00`3oo`1/o`T0Gol006go201To`030?oo06go
201Oo`00KOl806Co00<0ool0KOl905ko001]o`P0I?l00`3oo`1^o`P0G_l006go201To`030?oo06ko
201No`00KOl806Co00<0ool0Kol805go001/o`T0I?l00`3oo`1_o`P0GOl006co2@1To`030?oo06oo
2@1Lo`00K?l806Go00<0ool0L?l805co001/o`P0IOl3073o201Lo`00K?l806Go00<0ool0L?l805co
001/o`P0IOl00`3oo`1ao`P0Fol006co201Uo`030?oo077o201Ko`003Ol302oo0`0Zo`/0<?l502go
00<0ool0;ol502oo1@0:o`L07ol303?o0`03o`003_l00`3oo`0]o`050?ooo`00:Ol800;o00<0ool0
<?l00`3oo`0]o`030?oo037o00<0ool0;ol01@3oool000[o2@0Lo`050?ooo`00<ol00`3oo`02o`00
3_l00`3oo`0ao`030?oo02Oo200eo`030?oo02go00<0ool0<Ol00`3oo`0`o`030?oo00_o2@0Po`03
0?oo037o00<0ool00_l000[o1P0bo`030?oo02Oo2@0do`030?oo02go00<0ool0<Ol00`3oo`0ao`03
0?oo00_o200Po`030?oo02go1P03o`000_l600?o00@0ool09ol600Co0P0Xo`X000?o0?l09ol600Go
00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0ool02_l801ko0P0ao`040?oo00Co000;o`040?oo03?o
00<0ool09ol80003o`3o03;o00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0ool02_l8023o00<0ool0
;_l0103oo`04o`003?l00`3o000co`030?oo02Oo2002o`030?oo033o00<0ool0;Ol00`3oo`0ao`03
0?oo03?o00<0ool02Ol901oo00<0ool0;ol00`3o0004o`003?l00`3o000_o`050?ooo`00:Ol800;o
00<0ool0;_l302oo0`0_o`<0<Ol01@3oool000_o2@0Ko`050?ooo`00<Ol00`3o0004o`003Ol2033o
0`0Zo`X0<ol00`3oo`0]o`030?oo037o00<0ool0<?l300co200Mo`<0<ol200Co001/o`P0IOl00`3o
o`1co`P0FOl006co201Uo`030?oo07?o201Io`00K?l806Go00<0ool0Lol805Wo001/o`P0IOl00`3o
o`1co`P0FOl006co201Uo`030?oo07?o201Io`00K?l806Go00<0ool0Lol805Wo001/o`P0IOl00`3o
o`1co`P0FOl006co201Uo`030?oo07?o2@1Ho`002Ooo0:<01Ol000Wo00<0ool01ol00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool0
0ol800Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00T02Ol00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o
0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`07o`030?oo00?o2007o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`0900Wo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`0ao`030?oo02co200ao`030?oo037o00<0ool0
<Ol00`3oo`0bo`030?oo00[o200Oo`030?oo037o00<0ool00ol006co201Uo`030?oo077o2P1Io`00
K?l806Go00<0ool0LOl:05Wo001/o`P0IOl00`3oo`1ao`X0FOl006co201Uo`030?oo077o201Ko`00
K?l806Go00<0ool0L?l:05[o001/o`P0IOl00`3oo`1`o`X0F_l006co201Uo`<0LOl805_o001/o`P0
IOl00`3oo`1`o`T0Fol006co201Uo`030?oo073o2@1Ko`00K?l806Go00<0ool0Kol:05_o001/o`P0
IOl00`3oo`1_o`X0Fol006co201Uo`030?oo06oo201Mo`00K?l806Go00<0ool0Kol805go001/o`P0
IOl00`3oo`1^o`T0GOl006co201Uo`030?oo06ko201No`00K?l806Go00<0ool0KOl905ko001/o`P0
IOl00`3oo`1]o`P0Gol006co201Uo`<0K?l905oo001/o`P0IOl00`3oo`1[o`T0H?l006co201Uo`03
0?oo06_o201Qo`00K?l806Go00<0ool0J_l9067o001/o`P0IOl00`3oo`1Zo`P0H_l006co201Uo`03
0?oo06Wo201So`00K?l806Go00<0ool0J?l906?o001/o`P0IOl00`3oo`1Xo`P0I?l006co201Uo`03
0?oo06Oo2@1To`00K?l806Go00<0ool0Iol806Go001/o`T0I?l306Ko2@1Uo`00K?l906Co00<0ool0
I_l806Ko001/o`T0I?l00`3oo`1Uo`P0Iol006co2@1To`030?oo06Co2@1Wo`00KOl906?o00<0ool0
I?l806So001]o`T0Hol00`3oo`1So`T0J?l006go2@1So`030?oo06;o2@1Yo`00KOl806Co00<0ool0
H_l806[o001]o`P0I?l00`3oo`1Qo`X0JOl006go201To`030?oo063o2P1Zo`00KOl806Co00<0ool0
H?l906_o001]o`P0I?l305oo2P1[o`00KOl906?o00<0ool0G_l:06co001^o`P0Hol00`3oo`1Mo`X0
KOl006ko201So`030?oo05co2P1^o`00K_l806?o00<0ool0G?l:06ko001^o`T0H_l00`3oo`1Ko`X0
Kol006ko2@1Ro`030?oo05[o2P1`o`00K_l905Oo1@06o`030?oo05Wo2P1ao`00K_l905Wo00<0ool0
1_l00`3oo`1Ho`X0L_l006oo201Io`030?oo00Ko00<0ool0F?l:07;o001_o`T0F?l00`3oo`06o`@0
E_l:07?o001_o`T0F?l00`3oo`06o`030?oo05Ko2P1do`00Kol905So00<0ool01_l00`3oo`1Eo`X0
MOl006oo2@1Ho`030?oo00Ko00<0ool0EOl907Ko001_o`T0E_l300So00<0ool0Dol;07Ko001`o`P0
F?l00`3oo`06o`030?oo05;o2`1go`00L?l8067o00<0ool0DOl;07So001`o`T0H?l00`3oo`1@o`/0
NOl0077o201Po`030?oo04oo301io`00LOl8063o00<0ool0C_l<07[o001ao`P0H?l00`3oo`1=o``0
Nol0077o201Po`<0C?l<07co001bo`P0Gol00`3oo`1;o``0OOl007;o201Oo`030?oo04[o3@1mo`00
L_l805oo00<0ool0BOl=07ko001co`P0G_l00`3oo`18o``0P?l007?o201No`030?oo04Oo3021o`00
M?l705ko00<0ool0A_l<08;o001co`T0GOl00`3oo`15o``0Pol007Co2@1Lo`030?oo04Co3024o`00
M?l905co00<0ool0@ol<08Go001eo`T0Fol304;o3026o`00MOl:05[o00<0ool0@Ol<08Oo001fo`T0
F_l00`3oo`10o``0R?l007Oo2@1Io`030?oo03oo3029o`00Mol905Wo00<0ool0?_l<08[o001ho`T0
F?l00`3oo`0mo``0Rol007Wo2@1Go`030?oo03co302<o`00NOl905Oo00<0ool0>ol<08go001jo`T0
E_l00`3oo`0jo``0S_l007[o2@1Fo`030?oo03So3@2?o`00Nol905Go0`0fo`h0T?l007co2P1Co`03
0?oo03Go3P2Ao`00O?l<057o00<0ool0<ol?09;o001ko`h0D?l00`3oo`0bo`l0Tol007co3`1>o`03
0?oo033o402Do`00O_l>04go00<0ool0;_l>09So001oo`h0C?l00`3oo`0/o`h0V_l0083o3`1:o`03
0?oo02_o3P2Ko`00P_l?04So00<0ool0:?l@09co0023oa40AOl00`3oo`0Voa00W_l008Co4015o`03
0?oo02Co402Po`00Q_lC043o0`0Qoa40X_l008So5@0lo`030?oo01oo4@2To`00R_lG03So00<0ool0
7?lC0:Go002<oaT0=?l00`3oo`0Joa<0Yol008ko700_o`030?oo01Go5P2Yo`00T?lK02ko00<0ool0
3_lK0:_o002@ob001_l3023o00<0ool01olP0:go002CobX04?l500Oo00<0ool00olQ0;3o002Kof<0
/_l009ooG02eo`00X_mG0;Oo002Uoe00^ol00:OoB`2no`00Z_m30<?o002^ocP0b_l00;Wo:P3=o`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go
00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0
e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`04
0?oo0=ko003?o`030?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.68579 .66728 m
.70511 .64297 L
.72242 .61477 L
.73697 .58396 L
.7498 .54851 L
.75875 .51643 L
.7659 .48254 L
.76844 .46646 L
.76951 .45816 L
.77042 .44951 L
.77103 .44209 L
.77128 .43792 L
.77147 .43407 L
.77154 .43227 L
.77159 .43057 L
.77162 .42905 L
.77165 .4274 L
.77167 .42562 L
.77167 .42463 L
.77167 .42373 L
.77166 .42199 L
.77164 .42036 L
.7716 .41876 L
.77155 .41704 L
.77142 .41397 L
.77131 .41211 L
.77119 .41036 L
.77093 .4071 L
.7702 .40062 L
.76967 .39703 L
.76911 .39375 L
.76652 .38269 L
.76483 .3773 L
.76264 .37149 L
.75712 .3602 L
.75069 .35033 L
.742 .33998 L
.73091 .32957 L
.70488 .31137 L
.67405 .29531 L
.58879 .26297 L
.53716 .24766 L
.47777 .23284 L
.44955 .2269 L
.41987 .22153 L
.3926 .21756 L
.38092 .2162 L
.36841 .21499 L
.36193 .21447 L
.35599 .21408 L
Mistroke
.35002 .21376 L
.34447 .21353 L
.34141 .21344 L
.33982 .2134 L
.33814 .21337 L
.33518 .21332 L
.33249 .21331 L
.3294 .21331 L
.32654 .21334 L
.32343 .2134 L
.3217 .21345 L
.32013 .2135 L
.31474 .21373 L
.30984 .21403 L
.30456 .21446 L
.29906 .21503 L
.29011 .21624 L
.28065 .21798 L
.27114 .22027 L
.2617 .22322 L
.24633 .22988 L
.23861 .23439 L
.23201 .2391 L
.22545 .2448 L
.21909 .25165 L
.21367 .25896 L
.20933 .26627 L
.20581 .27361 L
.20257 .28222 L
.2002 .29042 L
.19844 .29848 L
.19705 .30739 L
.19647 .31256 L
.19625 .31504 L
.19607 .31739 L
.19591 .31985 L
.1958 .32214 L
.19569 .3247 L
.19562 .3275 L
.19558 .33006 L
.19557 .33289 L
.19558 .33433 L
.1956 .33587 L
.19566 .33868 L
.19574 .34133 L
.19586 .34424 L
.19616 .34957 L
.19655 .35485 L
.197 .35978 L
.19831 .3713 L
Mistroke
.20021 .38432 L
.20537 .41155 L
.2186 .46329 L
.23684 .51993 L
.27877 .62476 L
.30049 .66926 L
.32053 .70409 L
.33988 .73127 L
.3608 .75307 L
.37202 .76161 L
.37803 .76536 L
.38449 .76878 L
.39024 .77134 L
.39667 .7737 L
.40219 .77534 L
.40829 .77677 L
.41165 .7774 L
.41478 .77789 L
.41775 .77828 L
.42105 .77862 L
.42403 .77885 L
.42685 .77901 L
.42842 .77908 L
.42986 .77912 L
.43145 .77915 L
.43313 .77917 L
.43487 .77917 L
.43646 .77915 L
.43734 .77913 L
.4383 .77911 L
.44005 .77905 L
.4417 .77898 L
.44345 .77889 L
.44661 .77868 L
.45382 .77802 L
.46192 .777 L
.47669 .77449 L
.49058 .77148 L
.52288 .76253 L
.55556 .75107 L
.58566 .73827 L
.61614 .72249 L
.64203 .70598 L
.68579 .66728 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l008co0P0;o`80?_l00`3o
o`3Do`00Q_lL03Oo00<0ool0e?l007ko:003o`<0;Ol00`3oo`3Do`00N_lg02So00<0ool0e?l007Go
@`0Qo`030?oo0=Co001aod`07?l00`3oo`3Do`00LOmC01Go00<0ool0e?l006ooFP0@o`030?oo0=Co
001]of802_l00`3oo`3Do`00J_lT00_o>`05o`<0e?l006So7P0Noc800ol00`3oo`3Do`00IolB03Oo
:P3Fo`00I_lA03go:03Do`00IOl@04Oo903@o`00I?l>04ko8`3=o`00Hol=05So8038o`00H_l<05ko
7`35o`00HOl<063o00D0oooo0002oa/0`Ol0063o301Ro`030?oo00Ko6`2no`00Gol<06Co00<0ool0
1olL0;_o001No``0Fol600Go00<0ool01_l40003o`0001P0^?l005oo2P1Wo`030?oo00Ko00<0ool0
1OlL0;?o001No`X0JOl00`3oo`05o`030?oo00So6`2ao`00G_l906Ko00D0oooo0007o`030?oo00co
6`2]o`00GOl906So0`08o`030?oo017o602[o`00G?l907Co00<0ool05?lG0:Wo001Lo`P0MOl00`3o
o`0GoaL0Y_l005_o2@1eo`030?oo01[o5P2To`00F_l907Ko00<0ool07OlF0:7o001Jo`P0Mol00`3o
o`0QoaD0W_l005Wo2@1go`<09?lD09co001Jo`P0Mol00`3oo`0Woa@0VOl005[o201go`030?oo02Wo
502Go`00FOl807So00<0ool0;?lD09Co001Io`P0N?l00`3oo`0^oa@0T_l005So2@1ho`030?oo037o
5@2>o`00F?l907So00<0ool0=?lD08co001Go`T0NOl00`3oo`0foaD0ROl005Oo2@1io`030?oo03Wo
4`28o`00Eol907Wo00<0ool0>olD08Go001Go`P0N_l303ko4`23o`00Eol807[o00<0ool0@?lC087o
001Go`P0N_l00`3oo`13oa80Ool005Oo201jo`030?oo04Go4`1lo`00E_l907[o00<0ool0AolA07co
001Fo`X0NOl00`3oo`19oa00Nol005Go301ho`030?oo04co3P1jo`00E?l<07Wo00<0ool0C_l>07So
001Eo`X0N_l00`3oo`1@o`l0MOl005Ko2@1jo`030?oo05;o3P1do`00E_l907[o00<0ool0Dol>07?o
001Fo`P0Nol305Go3@1bo`00E_l807_o00<0ool0E_l>073o001Fo`P0Nol00`3oo`1Ho`d0Kol005Ko
201ko`030?oo05Wo301_o`00E_l807_o00<0ool0F_l<06ko001Fo`P0Nol00`3oo`1Ko``0KOl005Ko
201ko`030?oo05co301/o`00E_l807_o00<0ool0GOl;06co001Eo`T0Nol00`3oo`1No`/0Jol005Ko
2@1jo`030?oo05oo2`1Zo`00E_l907[o0`1Po`/0JOl005Ko2@1jo`030?oo067o2P1Yo`00E_l907[o
00<0ool0H_l:06So001Fo`T0N_l00`3oo`1So`T0J?l005Ko2P1io`030?oo06Co2@1Wo`00Eol807[o
00<0ool0I?l906Oo001Fo`T0N_l00`3oo`1Uo`T0I_l005Ko2@1_o`D01_l00`3oo`1Uo`T0I_l005Ko
2@1ao`030?oo00Ko00<0ool0I_l806Ko001Go`P0LOl00`3oo`06o`030?oo06Oo201Uo`00Eol8077o
00<0ool01_l00`3oo`1Wo`P0IOl005Oo201Vo`H01Ol00`3oo`06o`@0Iol806Co001Go`T0L?l00`3o
o`06o`030?oo06So201To`00Eol9073o00<0ool01_l00`3oo`1Yo`P0Hol005Oo2@1^o`<02?l00`3o
o`1Yo`P0Hol005So201`o`030?oo00Ko00<0ool0JOl806?o001Ho`T0N?l00`3oo`1Zo`P0H_l005So
2@1ho`030?oo06[o201Ro`00F?l907So00<0ool0J_l806;o001Io`P0N?l00`3oo`1Zo`P0H_l005Wo
201ho`030?oo06[o201Ro`00FOl807So0`1Zo`P0H_l005Wo201ho`030?oo06[o201Ro`00FOl907Oo
00<0ool0J_l9067o001Io`T0Mol00`3oo`1Zo`T0HOl005[o201go`030?oo06[o2@1Qo`00F_l807Oo
00<0ool0J_l9067o001Jo`T0M_l00`3oo`1Zo`T0HOl005_o201fo`030?oo06[o2@1Qo`00Fol807Ko
00<0ool0J_l9067o001Ko`P0M_l00`3oo`1Zo`T0HOl005_o201fo`030?oo06_o201Qo`00G?l707Ko
0`1[o`P0HOl005co201eo`030?oo06_o201Qo`00G?l807Go00<0ool0Jol8067o001Mo`L0MOl00`3o
o`1[o`T0H?l005go201do`030?oo06[o2P1Po`00GOl807Co00<0ool0J_l9067o001No`L0M?l00`3o
o`1Zo`T0HOl005ko1`1do`030?oo06[o2@1Qo`00G_l807?o00<0ool0JOl:067o001No`P0Lol00`3o
o`1Yo`X0HOl005oo1`1co`<0J_l806;o001Oo`P0L_l00`3oo`1Zo`T0HOl005oo201bo`030?oo06[o
2@1Qo`00Gol807;o00<0ool0J_l806;o000=o`<0;ol301go2@0:o`D0<?l502go00<0ool0;ol502oo
1@02o`P09_l303?o0`03o`003_l00`3oo`0]o`050?ooo`007Ol800[o00D0oooo000bo`030?oo02go
00<0ool0<Ol00`3oo`0_o`050?ooo`000_l802Go00D0oooo000co`030?oo00;o000>o`030?oo037o
00<0ool06ol800_o00<0ool0<ol00`3oo`0]o`030?oo037o00<0ool0<?l00`3oo`02o`T0:Ol00`3o
o`0ao`030?oo00;o000:o`H0<_l00`3oo`0Ko`P03?l00`3oo`0bo`030?oo02go00<0ool0<Ol00`3o
o`0ao`040?ooo`T0:Ol00`3oo`0]o`H00ol000;o1P03o`040?oo02Oo1P04o`807ol80003o`0000@0
1Ol00`3oo`0Vo`H01Ol00`3oo`0]o`030?oo037o00<0ool0<_l00`3oo`0902Oo0P0ao`040?oo00Co
000;o`040?oo03?o00<0ool07?l800co00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0<_l00`3o
000802[o00<0ool0;_l0103oo`04o`003?l00`3o000co`030?oo01co200=o`030?oo033o00<0ool0
;Ol00`3oo`0ao`030?oo03?o2P0Zo`030?oo02oo00<0o`001?l000co00<0o`00;ol01@3oool001oo
1`09o`050?ooo`00<?l302oo0`0_o`<0<Ol0103oool:02Ko00D0oooo000ao`030?l000Co000=o`80
<?l3023o2009o`<0<ol00`3oo`0]o`030?oo037o00<0ool0<?l30003o`0000H0:?l303?o0P04o`00
H_l806oo00<0ool0J?l806Co001So`L0Kol00`3oo`1Xo`P0I?l006?o201^o`030?oo06Oo2@1To`00
Hol806ko00<0ool0Iol806Go001To`L0K_l00`3oo`1Wo`P0IOl006Co1`1^o`030?oo06Oo201Uo`00
I?l806go00<0ool0Iol806Go001To`P0KOl00`3oo`1Wo`L0I_l000Woo`2S00Go0009o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`06o`P01?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So2002o`030?oo00So
00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00?o0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`06o`P01?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So2002o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo037o00<0ool09_l700Co
00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0<_l802co00<0ool0<Ol00`3oo`03o`00I_l806_o
00<0ool0I_l706Oo001Vo`P0Jol00`3oo`1Uo`P0Iol006Ko201[o`030?oo06Go201Wo`00I_l906[o
00<0ool0IOl806Oo001Wo`P0J_l00`3oo`1Uo`P0Iol006Oo201Zo`030?oo06Go201Wo`00J?l806Wo
0`1To`P0J?l006So201Yo`030?oo06Co201Xo`00J?l906So00<0ool0I?l706Wo001Yo`P0J?l00`3o
o`1To`L0JOl006Wo2@1Wo`030?oo06Co1`1Yo`00J_l806Oo00<0ool0I?l706Wo001Zo`P0Iol00`3o
o`1So`P0JOl006_o201Vo`030?oo06?o201Yo`00Jol806Ko00<0ool0Hol806Wo001[o`T0IOl00`3o
o`1Ro`T0JOl006co201Uo`030?oo06;o201Zo`00K?l806Go0`1Ro`P0J_l006go201To`030?oo067o
2@1Zo`00KOl806Co00<0ool0HOl806_o001]o`T0Hol00`3oo`1Po`T0Jol006ko201So`030?oo063o
201/o`00K_l806?o00<0ool0H?l806co001_o`P0H_l00`3oo`1Oo`P0KOl006oo201Ro`030?oo05oo
201]o`00Kol9067o00<0ool0G_l906go001`o`P0HOl00`3oo`1No`P0K_l0073o2@1Po`<0GOl906ko
001ao`P0H?l00`3oo`1Mo`P0Kol0077o201Po`030?oo05go201_o`00L_l805oo00<0ool0G?l906oo
001bo`P0Gol00`3oo`1Lo`P0L?l007;o2@1No`030?oo05_o2@1`o`00Lol805ko00<0ool0Fol8077o
001co`P0G_l00`3oo`1Jo`T0LOl007Co201Mo`030?oo05[o201bo`00M?l805go00<0ool0F_l807;o
001do`T0G?l00`3oo`1Io`P0Lol007Go201Lo`<0FOl807?o001eo`P0G?l00`3oo`1Ho`T0Lol007Ko
201Ko`030?oo05So201do`00M_l805_o00<0ool0Eol907Co001fo`T0F_l00`3oo`1Go`P0MOl007Oo
201Jo`030?oo05Ko2@1eo`00Mol905Wo00<0ool0E_l807Ko001ho`P0C_l500Ko00<0ool0EOl907Ko
001ho`P0D?l00`3oo`06o`030?oo05Go201go`00N?l904oo00<0ool01_l00`3oo`1Do`T0Mol007Wo
201?o`030?oo00Ko101Co`P0N?l007Wo2@1>o`030?oo00Ko00<0ool0Dol807Wo001jo`P0C_l00`3o
o`06o`030?oo05;o2@1io`00N_l904go00<0ool01_l00`3oo`1Bo`P0N_l007_o201;o`<02?l00`3o
o`1Ao`T0N_l007_o2@1<o`030?oo00Ko00<0ool0D?l907_o001lo`P0EOl00`3oo`1@o`P0O?l007co
2@1Do`030?oo04oo2P1ko`00OOl805Co00<0ool0C_l:07co001mo`P0E?l00`3oo`1>o`T0OOl007ko
201Co`030?oo04go2P1mo`00O_l805?o0`1<o`X0O_l007ko2@1Bo`030?oo04_o2P1oo`00Ool805;o
00<0ool0Bol9083o001oo`T0DOl00`3oo`1:o`X0P?l0083o201Ao`030?oo04Wo2P21o`00P?l9053o
00<0ool0B?l:08;o0021o`P0D?l00`3oo`17o`X0Pol0087o2@1?o`030?oo04Go3023o`00P_l804oo
00<0ool0A?l<08Co0022o`T0C_l00`3oo`13o``0QOl008?o2@1=o`<0@_l<08Ko0023o`T0COl00`3o
o`11o`d0Q_l008Co2@1<o`030?oo043o3@27o`00QOl804co00<0ool0?ol;08[o0026o`P0Bol00`3o
o`0no`/0Rol008Ko201;o`030?oo03go2`2<o`00Qol804[o00<0ool0??l;08go0027o`T0BOl00`3o
o`0ko`/0S_l008So2019o`030?oo03Wo302?o`00R?l904So00<0ool0>?l<093o0029o`P0B?l303Oo
302Ao`00ROl904Oo00<0ool0=_l<09;o002:o`P0Aol00`3oo`0do`d0Tol008[o2@16o`030?oo03?o
3@2Do`00Rol904Go00<0ool0<Ol=09Ko002<o`P0AOl00`3oo`0_o`h0Uol008co2@14o`030?oo02ko
3P2Ho`00SOl904?o00<0ool0;?l?09Wo002>o`P0@ol00`3oo`0Zoa00V_l008ko2@12o`030?oo02So
3`2Mo`00Sol9047o00<0ool09Ol@09oo002@o`T0@?l302?o402Qo`00T?l:03oo00<0ool08OlB0:7o
002Ao`X0?_l00`3oo`0Ooa80Xol0093o300mo`030?oo01co4`2Uo`00TOl<03co00<0ool06olB0:Oo
002Bo``0>ol00`3oo`0Hoa<0ZOl009?o300jo`030?oo01Ko4P2/o`00U?l<02go1@07o`030?oo01Co
4P2^o`00UOl<02co00D0oooo0007o`030?oo01;o4P2`o`00U_l<02co00<0ool02?l00`3oo`0?oa<0
/_l009Oo3P0Zo`030?oo00Oo100<oa<0]?l009So3P0Zo`030?oo00Ko00<0ool02_lD0;Ko002Io`h0
:Ol00`3oo`06o`030?oo00So4`2io`00V_l>02Wo00<0ool01Ol00`3oo`05oa@0^ol009_o3P0To`05
0?ooo`001ol00`3oo`02oaD0_Ol009co3`0So`<01?l20003o`0001L0_ol009go4@0Soad0`_l009ko
4P0@o`803_lL0<Co002Qoa803?l400So7P37o`00XOm60<Wo002Sod40c?l00:Co>`3Ao`00YOl20003
o`000300e_l00:[o;003o`030?oo0=Co002]obL01Ol00`3oo`3Do`00[olR00So00<0ool0e?l00:oo
7P0<o`030?oo0=Co002go`d05Ol00`3oo`3Do`00_ol201So00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00<ko0`08o`030?oo0=Co003=o`050?ooo`00
1ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<oo0P08o`@0
dol00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`050?ooo`001ol00`3o
o`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00d?l300Ko00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`H01_l00`3oo`3Do`00c_l0103o
o`07o`@0dol00<ko00@0ool0g_l00<oo00<0o`00g_l00<oo00<0o`00g_l00=3o0P3No`00oonao`00
oonao`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.73776 .57725 m
.74192 .56304 L
.74552 .54718 L
.74697 .53907 L
.74825 .53032 L
.7492 .522 L
.74987 .51438 L
.75016 .50998 L
.75041 .50529 L
.75057 .50128 L
.75064 .499 L
.75069 .49686 L
.75071 .49568 L
.75073 .49439 L
.75074 .49317 L
.75075 .49204 L
.75076 .48991 L
.75075 .48871 L
.75075 .48763 L
.75074 .48635 L
.75072 .48517 L
.7507 .48387 L
.75068 .48251 L
.75063 .4802 L
.75055 .47767 L
.75037 .47311 L
.75017 .46894 L
.74955 .45958 L
.74879 .45091 L
.74793 .44271 L
.74578 .42636 L
.74296 .4092 L
.73665 .37933 L
.72841 .34968 L
.71912 .32431 L
.71339 .31186 L
.70669 .29975 L
.69265 .28088 L
.68416 .2726 L
.67398 .26488 L
.6632 .25867 L
.65231 .25392 L
.6458 .25165 L
.63853 .24953 L
.62446 .24642 L
.61605 .24507 L
.6078 .24405 L
.59831 .24319 L
.59278 .24282 L
.58761 .24256 L
Mistroke
.58509 .24245 L
.58269 .24237 L
.58048 .24231 L
.57814 .24225 L
.57555 .24221 L
.57315 .24218 L
.57054 .24216 L
.56904 .24216 L
.56764 .24216 L
.56513 .24217 L
.56274 .24219 L
.56057 .24222 L
.5582 .24226 L
.55281 .24239 L
.54774 .24255 L
.53683 .24304 L
.52441 .24379 L
.49812 .24597 L
.47195 .24881 L
.44711 .25205 L
.38923 .26146 L
.33627 .27255 L
.28091 .28754 L
.23366 .30479 L
.21043 .31585 L
.19178 .32683 L
.17663 .33797 L
.16325 .35068 L
.15739 .35771 L
.15187 .36574 L
.14799 .37275 L
.14456 .38066 L
.14311 .38489 L
.14196 .38888 L
.14107 .39268 L
.14028 .39693 L
.14 .39878 L
.13975 .40079 L
.13957 .40254 L
.13941 .40446 L
.13928 .40653 L
.13919 .40872 L
.13916 .41076 L
.13917 .41268 L
.13922 .41496 L
.13927 .41625 L
.13934 .41745 L
.13949 .41965 L
.1397 .42201 L
.1402 .42613 L
Mistroke
.14092 .43072 L
.14317 .44107 L
.14607 .45101 L
.15403 .47139 L
.16409 .49145 L
.1887 .53044 L
.25581 .61246 L
.3358 .69238 L
.40705 .75116 L
.44128 .77297 L
.45582 .78026 L
.47046 .78611 L
.47679 .7881 L
.48344 .78983 L
.4872 .79063 L
.4906 .79123 L
.49402 .79173 L
.49716 .79209 L
.49998 .79233 L
.5014 .79242 L
.50296 .7925 L
.50451 .79255 L
.50538 .79256 L
.50618 .79257 L
.50765 .79257 L
.50918 .79255 L
.51053 .79251 L
.51196 .79245 L
.51331 .79237 L
.51453 .79228 L
.51752 .79201 L
.52033 .79166 L
.52602 .79072 L
.53223 .78932 L
.54472 .78539 L
.55626 .7805 L
.56707 .77494 L
.61483 .7415 L
.66501 .69413 L
.68804 .6673 L
.70701 .64091 L
.72253 .61402 L
.73545 .58405 L
.73776 .57725 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`0Po`80/_l00=Wo00<0ool04ol200[o102ao`00fOl00`3oo`0?oaH00_l30:[o003DocT0Xol00<[o
B02No`00_omH09Wo002noe/0Uol00;WoHP2Eo`00/om[09;o002^og40TOl00:OoBP09obP0S_l00:Ko
=`0Po`801olL08ko002Qoc801_l00`3oo`0doa@0S?l009co:00:o`<02?l00`3oo`0ioa80ROl009Ko
:@0Jo`030?oo03co4028o`00T?lZ01oo00<0ool0?_l?08Oo002>obH09Ol00`3oo`10o`h0Q_l008[o
9@0Zo`030?oo047o3`24o`00Q_lR037o00<0ool0@ol=08Co0022ob40=_l304Co3@23o`00O_lP03_o
00<0ool0A_l<08;o001iob00@?l00`3oo`17o``0POl007Wo6`15o`030?oo04So3020o`00MolI04Wo
00<0ool0BOl;083o001doaP0COl00`3oo`1:o`/0Ool0077o5`1Ao`030?oo04_o2`1no`00K_lF05Go
00<0ool0C?l;07go001ZoaL0F?l00`3oo`1=o`X0OOl006So5P1Ko`030?oo04ko2P1lo`00IOlF05ko
0`1?o`X0Nol006Co5@1Po`030?oo053o2P1jo`00H_lD06?o00<0ool0DOl807_o001Poa<0I_l00`3o
o`1Ao`P0Nol005ko4P1Yo`030?oo05;o201jo`00FolB06co00<0ool0D_l807[o001Koa00K_l00`3o
o`1Bo`T0NOl005Wo401`o`030?oo05?o201io`00F?l?07;o00<0ool0Dol907So001Fo`l0M?l00`3o
o`1Do`P0N?l005Go3P1fo`030?oo05Co2@1go`00DOlA07Oo0`1Eo`P0Mol0053o401io`030?oo05Go
201go`00Col@07[o00<0ool0E_l807Ko001?o`l0Nol00`3oo`1Fo`P0M_l004go3`1mo`030?oo05Ko
2@1eo`00COl=07oo00<0ool0Eol807Go001<o``0POl00`3oo`1Go`T0M?l004_o3022o`030?oo05So
201do`00B_l;08Co00<0ool0F?l907?o0019o`/0QOl00`3oo`1Io`P0Lol004So2`26o`<0FOl807?o
0017o``0Q_l00`3oo`1Io`T0L_l004Ko3027o`030?oo05[o201bo`00AOl<08So00<0ool0F_l807;o
0014o``0ROl00`3oo`1Jo`P0L_l004Go2P2:o`030?oo05_o1`1bo`00A?l:08_o00<0ool0Fol707;o
0013o`X0POl500Ko00<0ool0Fol707;o0013o`T0Q?l00`3oo`06o`030?oo05_o1`1bo`00@_l908Go
00<0ool01_l00`3oo`1Ko`P0LOl004;o2026o`030?oo00Ko00<0ool0Fol9073o0011o`T0Nol600Go
00<0ool01_l405_o201`o`00@?l:08Ko00<0ool01_l00`3oo`1Lo`P0L?l0043o2@27o`030?oo00Ko
00<0ool0G?l8073o0010o`T0QOl300So00<0ool0G?l906oo000oo`T0R?l00`3oo`06o`030?oo05co
2@1_o`00?ol:093o00<0ool0GOl806oo000no``0Sol00`3oo`1Mo`P0Kol003go302@o`030?oo05ko
201^o`00?_l:097o00<0ool0G_l806ko000oo`T0TOl00`3oo`1Oo`L0K_l003oo2@2Ao`<0Gol706ko
000oo`P0T_l00`3oo`1No`T0KOl003oo202Bo`030?oo05ko2@1]o`00?ol809;o00<0ool0G_l906go
000oo`P0T_l00`3oo`1Oo`P0KOl003oo202Bo`030?oo05oo2@1/o`00?ol809;o00<0ool0Gol906co
000oo`P0T_l00`3oo`1Oo`T0K?l003oo202Bo`030?oo05oo2@1/o`00?ol809;o00<0ool0Gol906co
000oo`P0T_l00`3oo`1Oo`T0K?l003oo202Bo`<0H?l806co000oo`P0T_l00`3oo`1Po`T0Jol003oo
202Bo`030?oo063o2@1[o`00?ol9097o00<0ool0H?l906_o000oo`T0TOl00`3oo`1Qo`P0Jol003oo
2@2Ao`030?oo067o201[o`00?ol9097o00<0ool0HOl806_o0011o`P0T?l00`3oo`1Qo`P0Jol0047o
202@o`030?oo067o2@1Zo`00@?l9093o00<0ool0HOl906[o0011o`L0TOl3067o2@1Zo`00@Ol8093o
00<0ool0HOl806_o0012o`L0T?l00`3oo`1Qo`P0Jol004;o202?o`030?oo067o201[o`003Ol302oo
2`0Xo`D0<?l502go00<0ool0;ol502go200_o`<0<ol300?o000>o`030?oo02go00@0oooo2@0Wo`05
0?ooo`00<_l00`3oo`0]o`030?oo037o00<0ool0;Ol902go00D0oooo000co`030?oo00;o000>o`03
0?oo037o00<0o`001P0Xo`030?oo03?o00<0ool0;Ol00`3oo`0ao`030?oo02go2@0ao`030?oo037o
00<0ool00_l000[o1P0bo`030?l000L0:?l00`3oo`0bo`030?oo02go00<0ool0<Ol00`3oo`0]o`T0
<Ol00`3oo`0]o`H00ol000;o1P03o`040?oo02Oo1P04o`800ol701ko1P05o`030?oo02Ko1P05o`03
0?oo02go00<0ool0<Ol00`3oo`0]o`T0;ol2037o00@0ool01?l000_o00@0ool0<ol00`3oo`0802So
00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0;_l9033o00<0ool0;_l0103oo`04o`003?l00`3o
000co`040?ooo`L0:Ol00`3oo`0`o`030?oo02go00<0ool0<Ol00`3oo`0^o`T0<?l00`3oo`0_o`03
0?l000Co000<o`030?l002oo00D0oooo0003o`P09?l01@3oool0033o0`0_o`<0;ol3033o2@0/o`05
0?ooo`00<Ol00`3o0004o`003Ol2033o0`05o`L09Ol303?o00<0ool0;Ol00`3oo`0ao`030?oo02ko
200^o`<0<ol200Co0017o`P0R_l00`3oo`1Ro`P0J_l004So1`2:o`030?oo06;o201Zo`00B?l808Wo
00<0ool0H_l806[o0018o`P0ROl00`3oo`1Ro`P0J_l004Wo2028o`030?oo06;o201Zo`00BOl908Oo
00<0ool0H_l806[o001:o`P0Qol00`3oo`1Ro`P0J_l004[o2@26o`030?oo06;o201Zo`002Ooo0:<0
1Ol000Wo00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
0_l800So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1?l800Ko00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool00_l900Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool01?l800Ko00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool0
<Ol00`3oo`0=o`P07?l00`3oo`0ao`030?oo037o00<0ool0<Ol00`3oo`0^o`T0;ol00`3oo`0ao`03
0?oo00?o001=o`T0Pol00`3oo`1Ro`T0JOl004ko2@22o`030?oo06;o201Zo`00Col808;o00<0ool0
HOl906[o001?o`T0POl00`3oo`1Qo`T0J_l0053o2021o`030?oo067o2@1Zo`00DOl8083o00<0ool0
HOl906[o001Ao`T0Ool3067o2@1Zo`00D_l807oo00<0ool0H?l:06[o001Ao`X0O_l00`3oo`1Po`T0
Jol005;o2P1mo`030?oo063o2@1[o`00Dol:07co00<0ool0H?l906_o001Co`/0Nol00`3oo`1Po`T0
Jol005Co2P1ko`030?oo063o2@1[o`00EOl:07[o00<0ool0H?l906_o001Fo`X0NOl00`3oo`1Oo`X0
Jol005Oo2P1ho`030?oo05oo2@1/o`00F?l:07Oo00<0ool0H?l806co001Ho`/0M_l3063o201/o`00
FOl:07Ko00<0ool0H?l806co001Jo`X0MOl00`3oo`1Oo`T0K?l005_o2P1do`030?oo05oo2@1/o`00
G?l:07?o00<0ool0G_l806ko001Mo`X0L_l00`3oo`1No`P0K_l005go2`1ao`030?oo05ko1`1_o`00
G_l:077o00<0ool0GOl806oo001Oo`X0L?l00`3oo`1Mo`T0K_l0063o2P1_o`030?oo05ko201^o`00
HOl:06ko0`1No`L0Kol006;o2P1]o`030?oo05go201_o`00H_l;06co00<0ool0GOl806oo001So`X0
K?l00`3oo`1Lo`T0Kol006Co2P1[o`030?oo05co201`o`00IOl:06[o00<0ool0Fol9073o001Vo`X0
JOl00`3oo`1Ko`P0LOl006Oo2P1Xo`030?oo05[o2@1ao`00Iol;06Oo00<0ool0F_l807;o001Xo`X0
Iol00`3oo`1Jo`P0L_l006Wo2P1Vo`030?oo05Wo201co`00J_l:06Go0`1Io`P0Lol006_o2P1To`03
0?oo05So2@1co`00K?l:06?o00<0ool0F?l807Co001/o`/0H_l00`3oo`1Go`T0M?l006go2`1Qo`03
0?oo05Oo201eo`00K_l;063o00<0ool0E_l907Go001_o`/0Gol00`3oo`1Fo`P0M_l0073o2`1Co`D0
1_l00`3oo`1Eo`T0M_l0077o2`1Do`030?oo00Ko00<0ool0EOl807Oo001ao``0Dol00`3oo`06o`03
0?oo05Co2@1go`00L_l<05;o00<0ool01_l405;o2@1ho`00M?l;057o00<0ool01_l00`3oo`1Co`P0
NOl007Go2`1@o`030?oo00Ko00<0ool0D_l907Wo001fo`/0Col00`3oo`06o`030?oo05;o201jo`00
Mol;04co0`08o`030?oo057o201ko`00N?l;04go00<0ool01_l00`3oo`1@o`T0Nol007Wo2`1Eo`03
0?oo053o2@1ko`00N_l;05Co00<0ool0Col907co001ko`/0Dol00`3oo`1>o`X0O?l007co2`1Bo`03
0?oo04ko2@1mo`00OOl;057o00<0ool0COl907ko001no`/0D?l304co2P1no`00Ool;04oo00<0ool0
C?l907oo0020o`/0C_l00`3oo`1;o`T0P?l0087o2`1=o`030?oo04[o2P20o`00P_l;04co00<0ool0
B_l9087o0023o`/0Bol00`3oo`19o`T0P_l008Co2`1:o`030?oo04So2P22o`00QOl;04Wo00<0ool0
Aol;08;o0026o`/0B?l00`3oo`16o`/0Pol008Oo2`17o`030?oo04Go2`24o`00R?l;04Ko0`14o`/0
QOl008Wo2`15o`030?oo04?o2`26o`00R_l<04?o00<0ool0@_l<08Ko002;o``0@_l00`3oo`11o`/0
R?l008co3011o`030?oo043o2`29o`00SOl<043o00<0ool0?ol;08[o002>o`d0?_l00`3oo`0no`/0
Rol008oo3@0mo`030?oo03go2`2<o`00T?l=03co00<0ool0??l<08co002Ao`d0>ol00`3oo`0ko``0
SOl009;o3@0jo`<0>_l<08ko002Co`d0>Ol00`3oo`0io``0Sol009Co3@0ho`030?oo03So302@o`00
Uol;03Oo00<0ool0=ol<097o002Ho``0=Ol00`3oo`0fo``0T_l009Wo300do`030?oo03Go302Co`00
V_l<03?o00<0ool0<ol=09Co002Ko``0<_l00`3oo`0bo`d0UOl009co300ao`030?oo037o3@2Fo`00
WOl<033o00<0ool0<?l=09Oo002Oo`/0;ol00`3oo`0_o`d0V?l00:3o300]o`<0;_l=09Wo002Qo``0
;?l00`3oo`0]o``0Vol00:;o300[o`030?oo02co302Lo`00Xol<02[o00<0ool0:ol<09go002To``0
:Ol00`3oo`0Zo``0W_l00:Go300Xo`030?oo02Wo302Oo`00Yol;02Oo00<0ool0:?l<0:3o002Xo`/0
6_l500Oo00<0ool09ol<0:7o002Yo``06?l01@3oool000Oo00<0ool09_l<0:;o002Zo``06?l00`3o
o`08o`030?oo02Co3@2So`00Zol<01So00<0ool01ol402;o3@2To`00[?l=01Oo00<0ool01_l00`3o
o`0Qo`h0YOl00:go3@0Fo`030?oo00Ko00<0ool08?l>0:Ko002^o`h05Ol00`3oo`05o`030?oo01ko
3@2Yo`00/?l>00oo00D0oooo0007o`030?oo01go3@2Zo`00/Ol>00oo0`08o`030?oo01_o3@2/o`00
/_l?01So00<0ool06_l=0:go002eo`h05_l00`3oo`0Io``0[ol00;Ko3`0Do`030?oo01Oo3@2`o`00
^?l?01;o00<0ool05Ol=0;;o002jo`l04?l00`3oo`0Co`h0/ol00;_o4@0=o`<04?l?0;Go002loa@0
0ol200Co00<0ool03_l@0;Ko002noaP00ol00`3oo`08o`8000?o00004@2fo`00`?lH0003o`3o00Go
602ho`00`_ld0;[o0034oc00_?l00<Ko;02no`00b_lU0<7o003<ob40`ol00<ko7@35o`00c_lM0<Go
003AoaD0b_l00=Co0P03o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go00D0oooo0007o`030?oo0=Co003Ao`03
0?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00col200So103Co`00dOl00`3oo`05o`03
0?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<go00D0oooo0007o`030?oo0=Co003>o`<02?l00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003@o`<01_l00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co
003Ao`030?oo00Go00<0ool0e?l00<go1P06o`030?oo0=Co003>o`040?oo00Oo103Co`00c_l0103o
o`3No`00col00`3o003No`00col00`3o003No`00d?l20=ko003ook7o003ook7o0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.74863 .47387 m
.74771 .46626 L
.74665 .45919 L
.74349 .44324 L
.73944 .42783 L
.73412 .41151 L
.71951 .37707 L
.70319 .34682 L
.66552 .29145 L
.62636 .2482 L
.6053 .23159 L
.5943 .22504 L
.58793 .22193 L
.58175 .21939 L
.57605 .21745 L
.56968 .21572 L
.56683 .2151 L
.56375 .21452 L
.56082 .21406 L
.5581 .21372 L
.55461 .21338 L
.55274 .21325 L
.55179 .2132 L
.55076 .21315 L
.54902 .21309 L
.54739 .21305 L
.54638 .21305 L
.54542 .21305 L
.54456 .21305 L
.54362 .21307 L
.54199 .21311 L
.54018 .21319 L
.53827 .21329 L
.53646 .21342 L
.53319 .21371 L
.52962 .21412 L
.52228 .21524 L
.51524 .21664 L
.49843 .22106 L
.48091 .22703 L
.46091 .23517 L
.37358 .28112 L
.28017 .34235 L
.1978 .40929 L
.16445 .4447 L
.15097 .46266 L
.13957 .48176 L
.13529 .49086 L
.13201 .49943 L
.1297 .50707 L
Mistroke
.12867 .51141 L
.12791 .51533 L
.12731 .51932 L
.1271 .52114 L
.12691 .52306 L
.12676 .52511 L
.12667 .52699 L
.12661 .52901 L
.1266 .53015 L
.1266 .53122 L
.12664 .53311 L
.12671 .5349 L
.12682 .5365 L
.12696 .53824 L
.12741 .54212 L
.12799 .54568 L
.12882 .54962 L
.12974 .55321 L
.13241 .56122 L
.13541 .56821 L
.13924 .57548 L
.14954 .59066 L
.16404 .60683 L
.19833 .63517 L
.24395 .66362 L
.34971 .71344 L
.40411 .7342 L
.45182 .75011 L
.4972 .76274 L
.51752 .76731 L
.53492 .77048 L
.54303 .77168 L
.55155 .7727 L
.55609 .77314 L
.56021 .77347 L
.56408 .77371 L
.56619 .77381 L
.56811 .77389 L
.57004 .77394 L
.57205 .77399 L
.57405 .77401 L
.57517 .77401 L
.57621 .774 L
.57808 .77398 L
.57977 .77394 L
.5817 .77388 L
.58351 .7738 L
.58753 .77354 L
.59116 .77322 L
.59505 .77276 L
Mistroke
.59908 .77217 L
.60568 .7709 L
.61148 .76944 L
.62375 .76515 L
.63425 .75994 L
.64355 .75391 L
.66231 .73694 L
.67795 .71719 L
.7075 .66491 L
.72166 .63212 L
.73318 .59967 L
.73791 .5836 L
.74219 .5665 L
.74544 .55041 L
.74768 .53573 L
.7486 .52774 L
.74926 .52019 L
.74954 .51606 L
.74974 .51224 L
.74983 .51007 L
.74989 .50804 L
.74995 .50593 L
.74997 .50481 L
.74999 .5036 L
.75 .50172 L
.75001 .49997 L
.75 .49806 L
.74997 .49601 L
.74993 .49386 L
.74987 .49183 L
.74971 .48805 L
.74952 .4845 L
.74929 .48123 L
.74863 .47387 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<02_l200Wo0P2mo`00fOl00`3o
o`09o`@01ol40;co003Io`030?oo00Oo4`2jo`00fOl00`3oo`03oa/0]_l00=Wo00<0ool00_lM0;Go
003IobD0/_l00=Go;02_o`00dOlb0:go003<ocX0Z_l00<co>P2Zo`00b_lP00Go6@2Xo`00aolJ00Co
0P0;o`801?lA0:Oo0034oaT07OlA0:Go0034oaH08ol>0:Go0032oa801Ol00`3oo`0So`h0Xol00<3o
4P07o`030?oo02Co3`2Qo`00_ol@00[o00<0ool09_l>0:3o002moaD01ol00`3oo`0Wo`h0Wol00;_o
3`03o`050?ooo`001ol00`3oo`0Yo`d0W_l00;Wo3`06o`030?oo00So00<0ool0:_l>09co002go`l0
2Ol00`3oo`07o`030?oo02co302Lo`00]Ol?0003o`0000@01Ol00`3oo`06o`@0;?l;09co002do`l0
3Ol00`3oo`06o`030?oo02ko2`2Ko`00/_l?013o00<0ool01Ol00`3oo`0`o`X0V_l00;3o3`0>o`05
0?ooo`001ol00`3oo`0ao`X0VOl00:ko3`0Ao`<02?l00`3oo`0bo`X0V?l00:co3`0No`030?oo03;o
2`2Go`00Z_l?023o00<0ool0<ol;09Ko002Yo`l08Ol00`3oo`0do`/0UOl00:Oo3`0So`030?oo03Go
2`2Do`00Y?l@02Go00<0ool0=_l;09?o002Roa009ol303Oo2`2Bo`00XOl?02Wo00<0ool0>?l;097o
002Oo`l0:ol00`3oo`0io`X0TOl009ko3`0/o`030?oo03[o2P2@o`00W?l?02ko00<0ool0>ol:08oo
002Jo`l0<?l00`3oo`0lo`X0S_l009Wo3P0bo`030?oo03go2P2=o`00Uol>03Co00<0ool0?Ol;08co
002Fo`d0=_l00`3oo`0no`T0SOl009Co3P0go`030?oo03oo2@2<o`00Tol=03Wo0`10o`T0Rol0097o
3@0ko`030?oo043o2@2;o`00T?l=03co00<0ool0@Ol908[o002>o`d0?_l00`3oo`12o`T0ROl008co
3P0oo`030?oo04?o2029o`00Rol=047o00<0ool0@ol908So0029o`h0@_l00`3oo`14o`T0Qol008So
3@14o`030?oo04Go2027o`00Q_l>04Go00<0ool0AOl908Ko0025o`d0Aol00`3oo`16o`T0QOl008?o
3@19o`030?oo04Oo2025o`00P_l=04[o0`17o`T0Q?l0083o3@1<o`030?oo04So2@23o`00OOl?04go
00<0ool0BOl808?o001lo`h0Col00`3oo`19o`T0P_l007[o3`1@o`030?oo04[o2P20o`00NOl>05;o
00<0ool0Bol9083o001ho`h0Dol00`3oo`1;o`X0Ool007Oo3@1Eo`030?oo04co2@1oo`00M_l<05Oo
00<0ool0COl907ko001do`d0F?l00`3oo`1>o`P0O_l007?o301Jo`<0C_l907go001bo``0Fol00`3o
o`1?o`P0OOl0077o301Lo`030?oo053o201lo`00L?l<05go00<0ool0D?l907_o001^o`d0G_l00`3o
o`1Ao`P0Nol006go301Po`030?oo057o2@1jo`00K?l<067o00<0ool0D_l807[o001[o``0Eol500Ko
00<0ool0Dol807Wo001Zo``0F_l00`3oo`06o`030?oo05?o201io`00J?l=05_o00<0ool01_l00`3o
o`1Do`P0N?l006Oo301Mo`030?oo00Ko00<0ool0E?l807So001Vo``0Dol600Go00<0ool01_l405?o
2@1go`00IOl<05oo00<0ool01_l00`3oo`1Eo`P0Mol006Co301Po`030?oo00Ko00<0ool0EOl907Ko
001Ro`d0Gol300So00<0ool0E_l807Ko001Qo``0Hol00`3oo`06o`030?oo05Ko201fo`00H?l<06go
00<0ool0Eol807Go001Oo``0K_l00`3oo`1Go`P0MOl005ko301_o`030?oo05Oo2@1do`00G?l=073o
00<0ool0F?l807Co001Ko``0L_l00`3oo`1Ho`T0Lol005[o301co`<0FOl807?o001Io``0M?l00`3o
o`1Io`P0Lol005So301eo`030?oo05[o201bo`00E_l=07Ko00<0ool0F_l807;o001Eo``0N?l00`3o
o`1Jo`T0LOl005Go2`1io`030?oo05_o201ao`00E?l;07[o00<0ool0Fol9073o001Co`/0Nol00`3o
o`1Lo`P0L?l005;o2`1lo`030?oo05co201`o`00DOl;07go00<0ool0G?l8073o001@o`/0O_l00`3o
o`1Lo`P0L?l004oo2`1oo`<0GOl806oo001>o`/0P?l00`3oo`1Mo`P0Kol004go2`21o`030?oo05go
201_o`00Bol<08;o00<0ool0G_l806ko001;o`/0Pol00`3oo`1No`P0K_l004[o2`24o`030?oo05ko
201^o`00BOl;08Go00<0ool0G_l906go0018o`/0Q_l00`3oo`1Oo`P0KOl004Oo2`27o`030?oo05oo
201]o`00B?l908So00<0ool0Gol906co0017o`T0ROl305oo2@1/o`00A_l908[o00<0ool0Gol906co
0016o`T0R_l00`3oo`1Oo`T0K?l004Go2@2;o`030?oo063o201/o`003Ol302oo0`02o`X09?l5033o
1@0]o`030?oo02oo1@0/o`T0;ol303?o0`03o`003_l00`3oo`0]o`060?ooo`3o2@0Uo`050?ooo`00
<_l00`3oo`0]o`030?oo037o00<0ool0;?l902ko00D0oooo000co`030?oo00;o000>o`030?oo037o
2P0Wo`030?oo03?o00<0ool0;Ol00`3oo`0ao`030?oo02go200bo`030?oo037o00<0ool00_l000[o
1P0bo`X0:?l00`3oo`0bo`030?oo02go00<0ool0<Ol00`3oo`0]o`P0<_l00`3oo`0]o`H00ol000;o
1P03o`040?oo02Oo1P04o`/07ol600Go00<0ool09_l600Go00<0ool0;Ol00`3oo`0ao`030?oo02go
200`o`80<Ol0103oo`04o`002ol0103oo`0bo`T0:ol00`3oo`0ao`030?oo02go00<0ool0<Ol00`3o
o`0]o`T0<Ol00`3oo`0^o`040?oo00Co000<o`030?l0037o2P0/o`030?oo033o00<0ool0;Ol00`3o
o`0ao`030?oo02go2@0ao`030?oo02oo00<0o`001?l000co00<0o`00;ol00`3o000802Wo00D0oooo
000`o`<0;ol302oo0`0_o`P0;_l01@3oool0037o00<0o`001?l000go0P0`o`T0:ol303?o00<0ool0
;Ol00`3oo`0ao`030?oo02go200_o`<0<ol200Co000oo`P0T_l00`3oo`1Qo`T0J_l003ko2@2Bo`03
0?oo063o2P1Zo`00?_l809?o00<0ool0Gol<06Wo000mo`T0Tol00`3oo`1Po``0J?l003go202Do`03
0?oo067o2P1Yo`00??l909Co00<0ool0HOl906[o000lo`T0U?l00`3oo`1Qo`T0J_l003go202Do`03
0?oo06;o201Zo`002Ooo0:<01Ol000Wo00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`07o`P00ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool01?l800Ko00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool01ol00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`05o`X00ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01?l800Ko00<0ool02?l00`3o
o`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool00ol000Wo00<0ool0;_l:02go00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0;_l902oo
00<0ool0<Ol00`3oo`03o`00>_l909Ko00<0ool0HOl:06Wo000jo`P0Uol00`3oo`1Qo`T0J_l003Wo
2@2Go`030?oo067o2@1Zo`00>Ol909Oo00<0ool0HOl906[o000io`X0U_l00`3oo`1Po`X0J_l003So
302Eo`030?oo063o2P1Zo`00=ol<09Ko0`1Qo`P0Jol003So2P2Go`030?oo067o201[o`00>Ol909Oo
00<0ool0HOl806_o000io`T0Uol00`3oo`1Qo`P0Jol003So2P2Go`030?oo067o201[o`00=ol<09Ko
00<0ool0HOl806_o000ho``0UOl00`3oo`1Qo`P0Jol003Wo2P2Fo`030?oo067o201[o`00>Ol909Oo
00<0ool0HOl806_o000io`X0U_l00`3oo`1Qo`P0Jol003Wo2P2Fo`030?oo067o1`1/o`00>?l<09Go
0`1Po`P0K?l003Wo302Do`030?oo063o201/o`00>_l:09Go00<0ool0H?l706go000jo`X0UOl00`3o
o`1Oo`P0KOl003[o2P2Eo`030?oo05oo201]o`00??l809Go00<0ool0Gol806go000mo`P0U?l00`3o
o`1No`T0KOl003go202Do`030?oo05ko201^o`00?_l709Co00<0ool0G_l806ko000no`P0Tol00`3o
o`1Mo`T0K_l003ko2@2Bo`<0GOl906ko000oo`P0T_l00`3oo`1Mo`T0K_l003oo2@2Ao`030?oo05go
2@1^o`00@?l9093o00<0ool0GOl806oo0011o`T0Sol00`3oo`1Mo`P0Kol0047o2@2?o`030?oo05co
2@1_o`00@Ol:08ko00<0ool0G?l8073o0012o`X0SOl00`3oo`1Lo`P0L?l004?o2P2<o`030?oo05co
201`o`00A?l:08_o00<0ool0G?l8073o0014o`/0R_l00`3oo`1Ko`T0L?l004Go2`29o`<0Fol8077o
0016o`/0R?l00`3oo`1Ko`P0LOl004Oo2`27o`030?oo05[o201bo`00Aol=08Go00<0ool0F_l807;o
0018o`d0Q?l00`3oo`1Io`T0L_l004Wo3@23o`030?oo05Wo201co`00B_l>087o00<0ool0FOl807?o
001;o`h0MOl500Ko00<0ool0F?l807Co001<o`h0M_l00`3oo`06o`030?oo05So201do`00Col=07Co
00<0ool01_l00`3oo`1Go`T0M?l0053o3@1co`030?oo00Ko101Fo`P0MOl0057o3@1bo`030?oo00Ko
00<0ool0Eol807Go001Co`d0L?l00`3oo`06o`030?oo05Ko2@1eo`00E?l=06oo00<0ool01_l00`3o
o`1Fo`P0M_l005Go3@1/o`<02?l00`3oo`1Eo`T0M_l005Ko3@1]o`030?oo00Ko00<0ool0EOl807Oo
001Go`h0M?l00`3oo`1Eo`P0Mol005Wo3@1co`030?oo05Co201ho`00F_l>077o00<0ool0E?l807So
001Lo`d0L?l00`3oo`1Co`T0N?l005ko3@1^o`030?oo05?o201io`00Gol=06go0`1Bo`T0NOl0067o
3@1[o`030?oo05;o201jo`00H_l>06Wo00<0ool0D_l807[o001To`h0Iol00`3oo`1Ao`P0Nol006Go
3`1Uo`030?oo057o201ko`00Iol?06?o00<0ool0D?l907_o001Xoa00HOl00`3oo`1@o`P0O?l006Wo
4P1No`030?oo04oo2@1lo`00JolB05co00<0ool0Col807go001]oa80F_l00`3oo`1>o`T0OOl006oo
4P1Ho`<0COl907ko001aoa80E_l00`3oo`1=o`P0Ool007?o4P1Do`030?oo04co2@1oo`00MOlC057o
00<0ool0C?l8083o001hoa80Col00`3oo`1;o`P0POl007[o4P1=o`030?oo04_o2021o`00O?lB04_o
00<0ool0B_l808;o001noa80BOl00`3oo`1:o`P0P_l0083o4P17o`030?oo04Wo2023o`00P_lC04Co
00<0ool0BOl808?o0025oa80@_l304So2024o`00QolB043o00<0ool0Aol908Co0029oa80?_l00`3o
o`17o`P0QOl008_o4P0lo`030?oo04Ko2@25o`00SOlC03Wo00<0ool0A_l808Ko002?oa<0=ol00`3o
o`15o`P0Qol009;o4P0eo`030?oo04Co2@27o`00U?lC03;o00<0ool0@ol;08Ko002Foa<0<?l00`3o
o`12o`/0Qol009So500]o`030?oo04;o2P28o`00V_lD02_o00<0ool0@Ol:08Wo002Moa<0:Ol3043o
2P2:o`00WolD02Ko00<0ool0?ol;08[o002QoaD08ol00`3oo`0no`X0S?l00:Co5@0Po`030?oo03go
2`2<o`00Y_lG01co00<0ool0??l;08go002YoaL06Ol00`3oo`0ko``0SOl00:_o6@0Eo`030?oo03[o
302>o`00[OlJ00Ko1@07o`030?oo03Wo302?o`00/?lJ00?o00D0oooo0007o`030?oo03So302@o`00
]?lI0003o`3o00Wo00<0ool0=ol<097o002goaT02Ol403Go302Bo`00^olH00Ko00<0ool0=?l=09?o
002noaP00ol00`3oo`0bo`d0UOl00<7o6@0co`h0UOl00<Co7@0Xoa40U_l00<So7P02o`<06OlD09So
003;ob@05?lD09Wo003>odP0V_l00=7o@`2Lo`00e?ln09ko003GocX0Wol00=Wo0`000ol0000_0:;o
003Io`030?oo00Co:02Xo`00fOl00`3oo`08ob<0ZOl00=Wo00<0ool03olL0:Wo003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0
e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`03
0?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko
0`08o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go
00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o
003>o`040?oo0=ko003?o`030?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.71651 .375 m
.69935 .34911 L
.67788 .32394 L
.62332 .27742 L
.56907 .2436 L
.53908 .22876 L
.51272 .21848 L
.49999 .21474 L
.4934 .21319 L
.48648 .21188 L
.4805 .21103 L
.47712 .21068 L
.4755 .21054 L
.47397 .21043 L
.47259 .21036 L
.47109 .21029 L
.46973 .21024 L
.46847 .21022 L
.46698 .21021 L
.46562 .21021 L
.46406 .21024 L
.4626 .21029 L
.46115 .21036 L
.45961 .21046 L
.45683 .21069 L
.45353 .21107 L
.45053 .21151 L
.44401 .21281 L
.43784 .21446 L
.42696 .21843 L
.41502 .22432 L
.38989 .24178 L
.36177 .26837 L
.3069 .33557 L
.24568 .42751 L
.19442 .52304 L
.17566 .57046 L
.16915 .59297 L
.16645 .60523 L
.16542 .61102 L
.16463 .61628 L
.16403 .62116 L
.16354 .62644 L
.16335 .62914 L
.16322 .63164 L
.16317 .63302 L
.16313 .63427 L
.16311 .6357 L
.16309 .63705 L
.1631 .63931 L
Mistroke
.16315 .64169 L
.16323 .64392 L
.16334 .64592 L
.16351 .64825 L
.16375 .65075 L
.1643 .6552 L
.16495 .6591 L
.16582 .66329 L
.16808 .67144 L
.1708 .67864 L
.17388 .68504 L
.17813 .69215 L
.18356 .69941 L
.19555 .71134 L
.20979 .72144 L
.22509 .72948 L
.24382 .73684 L
.26327 .74254 L
.28647 .74754 L
.30027 .74982 L
.31332 .75159 L
.32578 .75297 L
.33938 .75419 L
.35246 .75511 L
.3645 .75576 L
.37146 .75605 L
.37886 .75631 L
.38274 .75642 L
.38702 .75652 L
.39096 .7566 L
.39456 .75666 L
.39822 .7567 L
.4017 .75673 L
.40537 .75676 L
.40745 .75676 L
.40938 .75677 L
.41257 .75676 L
.4161 .75675 L
.41979 .75673 L
.42326 .75669 L
.42661 .75665 L
.4302 .75659 L
.43665 .75647 L
.44432 .75627 L
.45127 .75606 L
.46634 .75546 L
.48044 .75475 L
.50491 .75316 L
.53066 .75099 L
.58018 .7451 L
Mistroke
.60294 .74141 L
.62607 .73677 L
.6616 .72696 L
.67856 .72043 L
.69223 .71374 L
.70332 .70692 L
.71364 .69892 L
.72329 .68924 L
.73082 .67936 L
.73728 .66827 L
.74296 .65523 L
.74723 .64195 L
.75033 .62894 L
.75276 .61511 L
.75446 .6016 L
.75522 .5936 L
.75577 .58618 L
.75602 .58202 L
.75625 .57747 L
.75642 .57344 L
.75656 .56908 L
.75662 .56707 L
.75667 .56495 L
.7567 .56298 L
.75673 .56115 L
.75675 .55941 L
.75676 .55756 L
.75677 .5555 L
.75677 .55362 L
.75677 .55255 L
.75676 .55141 L
.75675 .54936 L
.75674 .54822 L
.75672 .54715 L
.75668 .54472 L
.75659 .54064 L
.75646 .53624 L
.75629 .53169 L
.75606 .52671 L
.75551 .51762 L
.75481 .50876 L
.75403 .50053 L
.75178 .4825 L
.74897 .46568 L
.7417 .43497 L
.73673 .41932 L
.73055 .40327 L
.71702 .37589 L
.71651 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co0035o`804_l00`3oo`3Do`00a?l400Ko0P09o`<0e?l00<;o
4`04o`030?oo0=Co002noa`0e_l00;_o903Ao`00]_l]0<go002fobd0cOl00;Ko;`3;o`00]?ld0<So
002cocL0a_l00;7o6007oa`0a?l00;3o4004o`804_lG0<7o002^o`h07Ol00`3oo`0D0<3o002Zoa00
7ol00`3oo`04oa80__l00:Wo3`0Qo`030?oo00Ko4P2lo`00Z?l?02;o00<0ool02OlA0;[o002Wo`h0
9?l00`3oo`0;oa40^?l00:Ko3P0Uo`030?oo00go4P2eo`00YOl=01_o1@07o`030?oo00oo402eo`00
Y?l<01go00D0oooo0007o`030?oo017o402co`00Xol<01oo00<0ool02?l00`3oo`0Co`l0/_l00:;o
300Qo`030?oo00Oo00<0ool05Ol?0;3o002Qo``06?l600Go00<0ool01_l401Ko3`2^o`00X?l<02Co
00<0ool01_l00`3oo`0Io`h0[Ol009oo300Vo`030?oo00Go00<0ool06ol>0:_o002No``08ol01@3o
ool000Oo00<0ool07Ol=0:[o002Mo``09Ol300So00<0ool07_l>0:So002Lo``0<Ol00`3oo`0Po`h0
Y_l009_o300bo`030?oo02;o3`2So`00V_l<03?o00<0ool08ol?0:;o002Jo`/0=?l00`3oo`0Uo`l0
X?l009Wo2`0eo`030?oo02Ko3`2Oo`00VOl:03Ko0`0Xo`h0W_l009So2P0go`030?oo02[o3@2Mo`00
Uol:03So00<0ool0:ol=09co002Fo`X0>Ol00`3oo`0]o`d0V_l009Go2P0jo`030?oo02ko3@2Io`00
U?l;03[o00<0ool0<?l<09So002Do`X0>ol00`3oo`0ao``0Uol009?o2P0lo`030?oo03;o302Fo`00
T_l:03go00<0ool0<ol=09Co002Ao`X0?_l00`3oo`0eo``0Tol0093o2P0oo`<0=_l<09;o002?o`/0
?ol00`3oo`0go``0TOl008oo2P10o`030?oo03So302@o`00S_l:047o00<0ool0>Ol=08ko002=o`X0
@_l00`3oo`0ko``0SOl008co2P13o`030?oo03co3P2:o`00Rol:04Co00<0ool0?Ol=08[o002:o`/0
A?l00`3oo`0no`d0ROl008[o2P15o`030?oo03oo3@28o`00ROl:04Ko00<0ool0@Ol<08Oo0028o`X0
Aol00`3oo`12o``0Q_l008Oo2P18o`<0@ol;08Ko0026o`X0BOl00`3oo`14o`X0Q_l008Go2`19o`03
0?oo04Go2P25o`00QOl:04[o00<0ool0A_l:08Co0024o`X0Bol00`3oo`17o`T0Q?l008?o2P1<o`03
0?oo04So2P22o`00Pol904go00<0ool0B?l:08;o0023o`P0C_l00`3oo`19o`X0POl008;o2@1>o`03
0?oo04[o2P20o`00POl904oo00<0ool0B_l:083o0021o`P0D?l304_o2P1oo`00P?l9053o00<0ool0
C?l:07ko001oo`T0DOl00`3oo`1<o`X0O_l007oo201Bo`030?oo04go2P1mo`00O_l905;o00<0ool0
C_l:07co001mo`T0Dol00`3oo`1>o`X0O?l007go201Do`030?oo053o2@1ko`00O?l904Wo1@06o`03
0?oo053o2P1jo`00Nol904co00<0ool01_l00`3oo`1Ao`T0N_l007_o201=o`030?oo00Ko00<0ool0
D_l907Wo001jo`T0COl00`3oo`06o`030?oo05;o2P1ho`00NOl904?o1P05o`030?oo00Ko101Bo`T0
N?l007Wo201?o`030?oo00Ko00<0ool0E?l907Oo001ho`T0Col00`3oo`06o`030?oo05Co2@1go`00
Mol904ko0`08o`030?oo05Go201go`00Mol8057o00<0ool01_l00`3oo`1Fo`P0M_l007Ko2@1Jo`03
0?oo05Ko201fo`00MOl905_o00<0ool0Eol807Go001eo`P0G?l00`3oo`1Ho`L0MOl007Co2@1Lo`03
0?oo05So201do`00Lol905go00<0ool0FOl807?o001co`P0G_l305Wo201co`00L_l905ko00<0ool0
F_l707?o001ao`T0Gol00`3oo`1Jo`P0L_l0077o201Po`030?oo05[o201bo`00L?l9063o00<0ool0
Fol8077o001_o`T0HOl00`3oo`1Ko`P0LOl006oo201Ro`030?oo05_o201ao`00KOl:06;o00<0ool0
G?l8073o001/o`X0Hol00`3oo`1Lo`P0L?l006co2@1To`030?oo05co201`o`00Jol:06Co00<0ool0
GOl806oo001[o`T0IOl305go201_o`00J_l906Ko00<0ool0GOl806oo001Zo`T0I_l00`3oo`1No`P0
K_l006Wo2@1Wo`030?oo05ko201^o`00JOl906Oo00<0ool0G_l806ko001Xo`T0J?l00`3oo`1Oo`L0
K_l006So2@1Xo`030?oo05oo201]o`00Iol906Wo00<0ool0Gol806go001Wo`T0JOl00`3oo`1Oo`P0
KOl006Ko2@1Zo`030?oo063o1`1]o`00I_l906[o0`1Po`L0KOl006Go2@1[o`030?oo063o1`1]o`00
IOl906_o00<0ool0H?l706go001To`T0K?l00`3oo`1Po`P0K?l000go0`0_o`<08_l900Go1@0`o`D0
;Ol00`3oo`0_o`D0;?l8033o0`0co`<00ol000ko00<0ool0;Ol01@3oool0023o2@06o`050?ooo`00
<_l00`3oo`0]o`030?oo037o00<0ool0;?l802oo00D0oooo000co`030?oo00;o000>o`030?oo037o
00<0ool07_l900Oo00<0ool0<ol00`3oo`0]o`030?oo037o00<0ool0;?l903;o00<0ool0<Ol00`3o
o`02o`002_l603;o00<0ool07Ol900Wo00<0ool0<_l00`3oo`0]o`030?oo037o00<0ool0;Ol803;o
00<0ool0;Ol600?o0002o`H00ol0103oo`0Wo`H01?l2023o3P05o`030?oo02Ko1P05o`030?oo02go
00<0ool0<Ol00`3oo`0]o`P0<?l2037o00@0ool01?l000_o00@0ool0<ol00`3oo`0Lo`T02ol00`3o
o`0ao`030?oo02go00<0ool0<Ol00`3oo`0]o`P0<_l00`3oo`0^o`040?oo00Co000<o`030?l003?o
00<0ool07?l900co00<0ool0<?l00`3oo`0]o`030?oo037o00<0ool0;Ol9037o00<0ool0;ol00`3o
0004o`003?l00`3o000_o`050?ooo`007Ol900Wo00D0oooo000`o`<0;ol302oo0`0_o`T0;Ol01@3o
ool0037o00<0o`001?l000go0P0`o`<07_l900[o0`0co`030?oo02go00<0ool0<Ol00`3oo`0]o`T0
;_l303?o0P04o`00Gol9077o00<0ool0HOl906[o001Oo`T0LOl00`3oo`1Ro`P0J_l005ko2@1bo`03
0?oo06;o2@1Yo`00G_l907;o00<0ool0H_l906Wo001Mo`T0Lol00`3oo`1Ro`T0JOl005go2@1co`03
0?oo06?o201Yo`00G?l907Co00<0ool0Hol806Wo001Lo`T0M?l00`3oo`1So`P0JOl000Woo`2S00Go
0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01_l900;o00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Go
2@04o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00So00<0ool01Ol900?o00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00Ko2004o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo037o
00<0ool06_l900ko00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0<?l802ko00<0ool0<Ol00`3o
o`03o`00FOl907Oo00<0ool0I?l806So001Io`T0Mol00`3oo`1To`T0Iol005So2@1ho`030?oo06Co
2@1Wo`00Eol:07So00<0ool0I?l906Oo001Go`T0NOl00`3oo`1To`P0J?l005Ko2P1io`030?oo06Co
201Xo`00E_l907[o0`1To`P0J?l005Go2P1jo`030?oo06Co201Xo`00EOl907_o00<0ool0I?l806So
001Eo`T0Nol00`3oo`1To`P0J?l005Co2@1lo`030?oo06Co201Xo`00E?l907co00<0ool0I?l806So
001Co`T0OOl00`3oo`1To`P0J?l005?o201no`030?oo06Co201Xo`00Dol807ko00<0ool0I?l806So
001Bo`P0Ool00`3oo`1To`P0J?l005;o201oo`030?oo06Co201Xo`00DOl907oo0`1To`P0J?l0057o
2020o`030?oo06Co201Xo`00D?l9083o00<0ool0I?l806So001@o`P0POl00`3oo`1To`P0J?l0053o
2021o`030?oo06Co201Xo`00Col808;o00<0ool0I?l806So001?o`P0P_l00`3oo`1To`P0J?l004ko
2@22o`030?oo06Co201Xo`00C_l808?o00<0ool0I?l806So001=o`T0Pol00`3oo`1To`P0J?l004go
2024o`<0I?l806So001=o`P0Q?l00`3oo`1To`P0J?l004go2024o`030?oo06Co201Xo`00COl708Go
00<0ool0I?l806So001<o`P0QOl00`3oo`1To`P0J?l004co2025o`030?oo06Co2@1Wo`00C?l708Ko
00<0ool0I?l906Oo001;o`P0Q_l00`3oo`1To`P0J?l004_o2026o`030?oo06?o2@1Xo`00Bol708Oo
00<0ool0Hol906So001:o`P0Qol00`3oo`1So`T0J?l004[o2027o`<0Hol906So001:o`T0Q_l00`3o
o`1So`T0J?l004[o2@26o`030?oo06;o2@1Yo`00B_l808Oo00<0ool0H_l906Wo0019o`T0Qol00`3o
o`1So`P0JOl004Wo2@27o`030?oo06?o201Yo`00BOl908Oo00<0ool0Hol806Wo0019o`T0O?l500Ko
00<0ool0Hol806Wo0019o`T0O_l00`3oo`06o`030?oo06?o201Yo`00B?l907oo00<0ool01_l00`3o
o`1So`P0JOl004So2@1oo`030?oo00Ko101Ro`P0JOl004Wo201oo`030?oo00Ko00<0ool0H_l906Wo
0019o`P0Ool00`3oo`06o`030?oo06;o201Zo`00BOl807oo00<0ool01_l00`3oo`1Ro`P0J_l004Wo
201mo`<02?l00`3oo`1Qo`P0Jol004Wo201oo`030?oo00Ko00<0ool0HOl806_o0019o`P0R?l00`3o
o`1Po`T0Jol004Wo2028o`030?oo063o201/o`00BOl808So00<0ool0Gol906co0019o`P0R?l00`3o
o`1Oo`P0KOl004Wo2028o`030?oo063o1`1]o`00BOl808So0`1Po`L0KOl004So2@28o`030?oo05oo
2@1/o`00BOl908Oo00<0ool0Gol806go0019o`T0Qol00`3oo`1No`T0KOl004Wo2@27o`030?oo05go
2@1^o`00BOl908Oo00<0ool0GOl906ko0019o`X0Q_l00`3oo`1Lo`T0Kol004Wo2P26o`030?oo05co
201`o`00Bol808Ko00<0ool0Fol9073o001;o`P0Q_l00`3oo`1Ko`P0LOl004_o2@25o`<0F_l9077o
001<o`P0QOl00`3oo`1Io`X0LOl004co2025o`030?oo05So301`o`00C?l908Co00<0ool0Eol<077o
001=o`P0Q?l00`3oo`1Fo``0L_l004go2@23o`030?oo05Go301co`00C_l908;o00<0ool0E?l<07Co
001?o`T0POl00`3oo`1Co``0MOl004oo2P20o`030?oo05;o301fo`00D?l:07oo00<0ool0DOl<07Oo
001?o``0O_l304oo3@1ho`00D?l<07go00<0ool0C_l>07So001Ao``0O?l00`3oo`1<o`l0NOl005;o
301ko`030?oo04_o3P1ko`00Dol<07[o00<0ool0B_l>07co001Do``0NOl00`3oo`18o`l0OOl005Go
3@1go`030?oo04Ko3`1oo`00E_l=07Ko00<0ool0@olA083o001Go`h0M?l00`3oo`11oa80POl005So
3P1co`030?oo03ko4`23o`00FOl?077o00<0ool0>_lE08Go001Lo`h0Kol303Ko5`27o`00G_l@06_o
00<0ool0<_lI08Wo001Ooa<0Iol00`3oo`0]oa`0Rol0067o5@1So`030?oo02co6`2=o`00HOlJ05ko
00<0ool06olY093o001SoaT000Co0000FOl00`3oo`0IobT0T_l006Go7`1Eo`030?oo01?o:@2Ho`00
J?lS04;o1@07o`030?oo00ko:P2Lo`00JolT00Co0`0go`040?ooo`<00olk09ko001^ob`0<om20:7o
001boiL0Yol007GoU02Wo`00Non10;Co001oogL0^_l008?oK@30o`00R_mQ0<Go002=oe80dOl009So
=`0:o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00<ko0`08o`030?oo0=Co003=o`050?ooo`001ol00`3oo`3Do`00dOl00`3oo`05o`03
0?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<oo0P08o`@0dol00=7o00<0ool01Ol00`3oo`3Do`00
dOl00`3oo`05o`030?oo0=Co003=o`050?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00d?l300Ko00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3o
o`05o`030?oo0=Co003=o`H01_l00`3oo`3Do`00c_l0103oo`07o`@0dol00<ko00@0ool0g_l00<oo
00<0o`00g_l00<oo00<0o`00g_l00=3o0P3No`00oonao`00oonao`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.64695 .29775 m
.62074 .28107 L
.59089 .26681 L
.55873 .25555 L
.53968 .25042 L
.52213 .2465 L
.48929 .24095 L
.47143 .23881 L
.46349 .23806 L
.45484 .23738 L
.44682 .23689 L
.443 .23671 L
.4394 .23656 L
.43746 .2365 L
.43536 .23644 L
.43343 .23639 L
.43168 .23636 L
.43069 .23635 L
.42962 .23633 L
.4285 .23632 L
.42744 .23632 L
.42644 .23631 L
.4254 .23631 L
.42353 .23632 L
.42179 .23633 L
.42022 .23636 L
.41841 .23639 L
.4167 .23643 L
.41368 .23653 L
.41043 .23666 L
.40689 .23686 L
.40318 .23711 L
.39662 .2377 L
.38986 .23851 L
.38381 .23943 L
.37747 .24064 L
.37073 .24222 L
.35982 .24556 L
.34898 .25007 L
.33786 .25632 L
.3284 .26331 L
.31822 .27305 L
.30928 .28402 L
.30129 .29619 L
.29336 .31096 L
.28031 .34237 L
.26784 .38246 L
.25729 .42569 L
.24776 .47411 L
.23908 .53033 L
Mistroke
.23535 .56152 L
.23385 .57669 L
.23269 .59037 L
.23175 .60351 L
.23098 .61757 L
.23066 .62523 L
.23054 .62857 L
.23044 .63221 L
.23036 .63542 L
.23029 .63883 L
.23026 .64071 L
.23024 .64242 L
.23021 .64575 L
.2302 .6489 L
.2302 .65185 L
.23022 .65506 L
.23026 .65849 L
.23033 .66189 L
.23042 .66543 L
.23064 .6717 L
.23091 .67746 L
.23123 .68274 L
.23218 .69446 L
.2336 .7069 L
.23526 .71776 L
.23762 .72974 L
.2403 .74047 L
.24657 .75895 L
.25037 .76743 L
.25506 .77607 L
.26469 .78955 L
.27526 .80002 L
.28185 .80497 L
.28956 .80961 L
.29737 .81328 L
.30503 .81606 L
.31227 .81806 L
.32065 .81972 L
.32501 .82035 L
.32734 .82062 L
.32982 .82086 L
.33203 .82104 L
.33446 .82121 L
.33671 .82132 L
.33881 .82139 L
.34135 .82145 L
.34263 .82146 L
.34406 .82147 L
.3466 .82144 L
.349 .82139 L
Mistroke
.35045 .82134 L
.35185 .82129 L
.35448 .82115 L
.36049 .82072 L
.36581 .82021 L
.37083 .81961 L
.38246 .81784 L
.40347 .81351 L
.4268 .80726 L
.48145 .78829 L
.5341 .7658 L
.62972 .71703 L
.67203 .69187 L
.71144 .66505 L
.74149 .64017 L
.76181 .61804 L
.76991 .60633 L
.77592 .59518 L
.78057 .58329 L
.78247 .57648 L
.78321 .57316 L
.78379 .57011 L
.78462 .5644 L
.78492 .56137 L
.78505 .55983 L
.78516 .55817 L
.78523 .5567 L
.78529 .55535 L
.78533 .554 L
.78535 .55272 L
.78536 .55122 L
.78535 .54983 L
.78532 .5483 L
.78528 .54668 L
.78521 .54503 L
.78513 .54352 L
.78489 .5401 L
.78459 .53691 L
.78424 .53386 L
.78325 .52696 L
.78184 .51931 L
.77842 .50492 L
.7745 .49154 L
.76323 .46058 L
.73388 .39996 L
.697 .34547 L
.6744 .32083 L
.64778 .29836 L
.64695 .29775 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00[ol201;o0`0Co`030?oo0=Co
002ZobD02_l00`3oo`3Do`00Xolg0=Ko002Ooc/0e_l009oo@`3>o`00WOm90<[o002Joe00a_l009So
E`31o`00UOmM0;ko002Doa/05ola0;Wo002AoaT06ol600Go00@0oooo8`2io`00T?lB02ko00<0ool0
1_lP0;Oo002?oa40<Ol00`3oo`05o`030?oo00;o7@2eo`00S_l?033o00D0oooo0007o`030?oo00co
5`2ao`00S?l?03?o0`08o`030?oo013o5@2_o`00Rol>043o00<0ool04olE0:co002:o`h0@Ol00`3o
o`0Eoa@0Zol008So3P13o`030?oo01So502Xo`00Qol=04Go00<0ool06olC0:Ko0028o`/0A_l00`3o
o`0Moa<0Y?l008So2@18o`<08?lB0:;o0028o`P0BOl00`3oo`0Roa<0Wol008Oo201:o`030?oo02Co
4@2Oo`00Q_l:04Wo00<0ool09_l@09ko0026o`T0B_l00`3oo`0Yo`l0W?l008Co2`1:o`030?oo02_o
402Io`00Pol;04_o00<0ool0;Ol?09So0023o`X0C?l00`3oo`0_o`l0U_l008;o2P1=o`030?oo037o
3P2Eo`00P_l:04go00<0ool0<_l>09Co0021o`X0C_l303Co3@2Co`00POl904oo00<0ool0=_l<09;o
0020o`T0D?l00`3oo`0go`d0T?l0083o2@1@o`030?oo03Wo302?o`00Ool9057o00<0ool0>_l=08go
001oo`P0D_l00`3oo`0ko`d0S?l007ko2@1Bo`030?oo03co3@2;o`00O_l805?o00<0ool0?Ol=08[o
001no`P0Dol00`3oo`0oo``0ROl007go2@1Co`030?oo043o3028o`00OOl805Co00<0ool0@Ol<08Oo
001mo`P0E?l304;o3026o`00O?l805Go00<0ool0@ol;08Ko001lo`P0EOl00`3oo`15o`X0QOl007_o
2@1Eo`030?oo04Ko2P24o`00Nol805Ko00<0ool0Aol:08?o001ko`P0E_l00`3oo`18o`X0P_l007[o
201Go`030?oo04So2`21o`00N_l805Oo00<0ool0BOl;083o001io`T0Eol00`3oo`1:o`/0Ool007Wo
201Ho`030?oo04_o2@20o`00NOl805So0`1<o`T0Ool007Wo1`1Io`030?oo04go2@1no`00N?l805Wo
00<0ool0COl907ko001ho`P0FOl00`3oo`1>o`T0OOl007So1`1Jo`030?oo04oo2@1lo`00Mol805[o
00<0ool0D?l807co001go`P0F_l00`3oo`1@o`T0Nol007Oo1`1@o`D01_l00`3oo`1Ao`T0N_l007Ko
201Bo`030?oo00Ko00<0ool0D_l807[o001fo`P0D_l00`3oo`06o`030?oo05;o2@1io`00MOl805?o
00<0ool01_l00`3oo`1Co`T0N?l007Go2018o`H01Ol00`3oo`06o`@0Dol807So001do`T0Dol00`3o
o`06o`030?oo05Co2@1go`00M?l805Co00<0ool01_l00`3oo`1Eo`T0M_l007Co201Bo`<02?l00`3o
o`1Fo`P0M_l007Co1`1Eo`030?oo00Ko00<0ool0E_l907Go001co`P0G_l00`3oo`1Go`T0M?l007?o
201No`030?oo05So2@1co`00Lol805ko00<0ool0F?l:07;o001co`L0Gol00`3oo`1Io`T0L_l007?o
1`1Oo`030?oo05[o2@1ao`00Lol705oo0`1Ko`P0LOl007?o1`1Oo`030?oo05_o2@1`o`00L_l805oo
00<0ool0G?l8073o001bo`P0Gol00`3oo`1Lo`T0Kol007;o1`1Po`030?oo05go201_o`00L_l7063o
00<0ool0GOl906ko001bo`L0H?l00`3oo`1No`P0K_l0077o201Po`030?oo05ko201^o`00LOl8063o
00<0ool0Gol806go001ao`L0HOl00`3oo`1Oo`P0KOl0073o201Qo`030?oo05oo2@1/o`00L?l8067o
0`1Po`P0K?l0073o201Qo`030?oo063o2@1[o`00L?l8067o00<0ool0HOl806_o001`o`L0H_l00`3o
o`1Qo`T0J_l0073o1`1Ro`030?oo06;o201Zo`00Kol806;o00<0ool0H_l906Wo001_o`L0Hol00`3o
o`1So`P0JOl006oo1`1So`030?oo06?o201Yo`00Kol706?o00<0ool0I?l806So001_o`L0Hol00`3o
o`1To`P0J?l006ko201So`<0I?l906Oo001^o`L0I?l00`3oo`1Uo`P0Iol006ko1`1To`030?oo06Go
2@1Vo`00K_l706Co00<0ool0I_l806Ko000=o`<0;ol302co2@0`o`D0;Ol00`3oo`0_o`D0;ol<02Wo
0`0co`<00ol000ko00<0ool0;Ol01@3oool002[o20000ol0o`0ao`030?oo02go00<0ool0<Ol00`3o
o`0_o`040?ooo`P0:?l01@3oool003?o00<0ool00_l000ko00<0ool0<Ol00`3oo`0Xo`L0=Ol00`3o
o`0]o`030?oo037o00<0ool0<?l00`3oo`0902_o00<0ool0<Ol00`3oo`02o`002_l603;o00<0ool0
:?l803Co00<0ool0;Ol00`3oo`0ao`030?oo037o00<0ool0200[o`030?oo02go1P03o`000_l600?o
00@0ool09ol600Co0P0Xo`X000?o0?l09ol600Go00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0o`00
1`0Yo`80<Ol0103oo`04o`002ol0103oo`0co`030?oo02So1`000ol0o`0bo`030?oo02go00<0ool0
<Ol00`3oo`0bo`030?oo00P0:_l00`3oo`0^o`040?oo00Co000<o`030?l003?o00<0ool09ol800;o
00<0ool0<?l00`3oo`0]o`030?oo037o00<0ool0<ol00`3o000702[o00<0ool0;ol00`3o0004o`00
3?l00`3o000_o`050?ooo`00:Ol800;o00<0ool0;_l302oo0`0_o`<0<Ol01P3oool0o`T09Ol01@3o
ool0037o00<0o`001?l000go0P0`o`<0:_l:03?o00<0ool0;Ol00`3oo`0ao`030?oo033o0`03o`P0
9_l303?o0P04o`00K?l706Ko00<0ool0J_l806;o001/o`L0I_l00`3oo`1[o`P0HOl006co1`1Vo`03
0?oo06_o201Qo`00Jol806Ko00<0ool0Jol9063o001[o`L0Iol00`3oo`1/o`P0H?l006_o1`1Wo`03
0?oo06co2@1Oo`00Jol706Oo00<0ool0K?l905oo001[o`L0Iol00`3oo`1/o`T0Gol000Woo`2S00Go
0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`07o`040?ooo`P02Ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`03
0?oo00Co2006o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol0103oool800Wo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`04o`P01_l00`3oo`07o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool0<Ol00`3o
o`0Zo`P0<ol00`3oo`0ao`030?oo037o00<0ool0<_l00`3oo`04o`T09?l00`3oo`0ao`030?oo00?o
001Zo`L0J?l00`3oo`1^o`P0G_l006[o1`1Xo`030?oo06ko201No`00J_l706So00<0ool0K_l805ko
001Yo`P0J?l00`3oo`1_o`P0GOl006Wo1`1Yo`030?oo06oo2@1Lo`00J?l806Wo00<0ool0Kol905co
001Xo`P0JOl3073o201Lo`00J?l806Wo00<0ool0L?l805co001Xo`P0JOl00`3oo`1`o`P0G?l006So
201Yo`030?oo073o2@1Ko`00J?l806Wo00<0ool0L?l905_o001Xo`P0JOl00`3oo`1`o`P0G?l006So
201Yo`030?oo073o201Lo`00J?l806Wo00<0ool0L?l805co001Xo`P0JOl00`3oo`1`o`P0G?l006Oo
2@1Yo`030?oo073o201Lo`00Iol806[o00<0ool0L?l805co001Wo`P0J_l3073o201Lo`00Iol806[o
00<0ool0L?l805co001Wo`P0J_l00`3oo`1`o`P0G?l006Oo201Zo`030?oo073o201Lo`00Iol806[o
00<0ool0L?l805co001Wo`P0J_l00`3oo`1`o`P0G?l006Oo201Zo`030?oo073o2@1Ko`00Iol806[o
00<0ool0Kol:05_o001Vo`T0J_l00`3oo`1_o`T0G?l006Ko201[o`030?oo06oo2@1Lo`00I_l806_o
0`1_o`T0G?l006Ko201[o`030?oo06ko2P1Lo`00I_l806_o00<0ool0K_l:05co001Vo`P0Jol00`3o
o`1^o`T0GOl006Ko201[o`030?oo06ko2@1Mo`00I_l806_o00<0ool0K_l905go001Vo`P0Jol00`3o
o`1]o`P0Gol006Ko201[o`030?oo06go201Oo`00I_l806_o00<0ool0K?l905oo001Uo`T0Jol00`3o
o`1/o`P0H?l006Go2@1[o`030?oo06_o2@1Po`00IOl906_o0`1[o`P0HOl006Go201/o`030?oo06[o
2@1Qo`00IOl806co00<0ool0J_l806;o001Uo`P0K?l00`3oo`1Yo`T0H_l006Go201/o`030?oo06So
2@1So`00IOl806co00<0ool0Iol:06?o001Uo`P0K?l00`3oo`1Vo`/0Hol006Go201Qo`D01_l00`3o
o`1Uo`/0I?l006Go201So`030?oo00Ko00<0ool0I?l;06Go001Uo`P0Hol00`3oo`06o`030?oo06Co
2P1Vo`00IOl806?o00<0ool01_l406;o2P1Wo`00IOl806?o00<0ool01_l00`3oo`1Ro`/0Iol006Go
201So`030?oo00Ko00<0ool0HOl:06Wo001Uo`P0Hol00`3oo`06o`030?oo063o2P1Zo`00IOl8067o
0`08o`030?oo05oo2`1Zo`00IOl806?o00<0ool01_l00`3oo`1No`/0Jol006Go201/o`030?oo05go
2`1/o`00IOl806co00<0ool0G?l<06co001Uo`P0K?l00`3oo`1Ko``0KOl006Go201/o`030?oo05[o
301^o`00IOl806co00<0ool0F?l=06oo001Uo`P0K?l305Oo301ao`00IOl806co00<0ool0E_l<07;o
001Uo`P0K?l00`3oo`1Eo``0Lol006Go201/o`030?oo05Co301do`00IOl806co00<0ool0D_l=07Go
001Uo`P0K?l00`3oo`1Ao``0Mol006Go201/o`030?oo053o301ho`00IOl806co00<0ool0C_l=07Wo
001Uo`P0K?l00`3oo`1=o`d0N_l006Go201/o`030?oo04_o3P1ko`00IOl806co0`19o`h0OOl006Go
201/o`030?oo04So3P1no`00IOl806co00<0ool0A_l>083o001Uo`P0K?l00`3oo`15o`d0P_l006Go
201/o`030?oo04?o3P23o`00IOl806co00<0ool0@Ol>08Go001Uo`P0K?l00`3oo`10o`d0Qol006Go
201/o`030?oo03ko3P28o`00IOl806co00<0ool0?Ol=08[o001Uo`P0K?l00`3oo`0ko`h0Rol006Go
201/o`<0>Ol>08go001Uo`P0K?l00`3oo`0ho`h0S_l006Go2@1[o`030?oo03Ko3P2@o`00I_l806_o
00<0ool0=Ol=09;o001Wo`L0Jol00`3oo`0co`h0Tol006Oo1`1[o`030?oo037o3P2Eo`00Iol706_o
00<0ool0;ol>09Oo001Wo`P0J_l00`3oo`0]o`l0V?l006Oo201Zo`030?oo02_o3`2Jo`00J?l706[o
00<0ool0:Ol@09_o001Xo`P0JOl00`3oo`0Woa40W?l006So201Yo`<09OlA09ko001Xo`P0JOl00`3o
o`0Soa40X?l006So201Yo`030?oo027o4@2Ro`00JOl806So00<0ool07olA0:Co001Yo`P0J?l00`3o
o`0Moa40Y_l006Wo201Xo`030?oo01_o4@2Xo`00J_l706So00<0ool06OlA0:[o001Zo`P0Fol500Oo
00<0ool05olA0:co001Zo`P0Fol01@3oool000Oo00<0ool05OlA0:ko001[o`L0G?l00`3oo`08o`03
0?oo01?o4@2`o`00Jol705go00<0ool01ol4013o4@2bo`00Jol805go00<0ool01_l00`3oo`0?oa40
]?l006[o2@1Mo`030?oo00Ko00<0ool03OlA0;Ko001[o`P0G_l00`3oo`05o`030?oo00_o4@2ho`00
Jol805[o00D0oooo0007o`030?oo00Wo4@2jo`00K?l805[o0`08o`030?oo00Ko4P2lo`00K?l806Go
00<0ool01?lB0;ko001/o`T0I?l00`3oo`02oa80`?l006go201To`030?oo0180`_l006go2@1Soa<0
a?l006ko2@1Poa<0a_l006oo201Noa<0b?l006oo2@1Joa@0b_l0073o2@1Goa<0cOl0077o2@1Coa@0
col0077o2P1@oa@0dOl007;o2P1<oa@0e?l0077o3018oaD0e_l007;o3014oaH000?o0?l0eOl007?o
3010oaH01?l00`3oo`3Do`00M?l<03co5`06o`030?oo0=Co001eo``0>?lF00[o0`3Do`00M_l=03?o
5`0<o`030?oo0=Co001go`h0;_lG00oo00<0ool0e?l007So3`0YoaL04_l00`3oo`3Do`00NOlA00;o
0P0Eo`801_lI01Go00<0ool0e?l007[o600=ob806?l00`3oo`3Do`00O?m301[o00<0ool0e?l007ko
?P0Mo`030?oo0=Co0020ocP08Ol00`3oo`3Do`00P_lc02Co00<0ool0e?l008Co;P0Wo`030?oo0=Co
0027obD0;Ol30=Co0027obD0;Ol00`3oo`3Do`00S?lI03Co00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go00D0oooo0007o`03
0?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00col200So103Co`00
dOl00`3oo`05o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<go00D0oooo0007o`030?oo0=Co
003>o`<02?l00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003@o`<01_l00`3oo`3Do`00dOl00`3o
o`05o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<go1P06o`030?oo0=Co003>o`040?oo00Oo
103Co`00c_l0103oo`3No`00col00`3o003No`00col00`3o003No`00d?l20=ko003ook7o003ook7o
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.55198 .25546 m
.54446 .25398 L
.53741 .25281 L
.52898 .25168 L
.52126 .25089 L
.51735 .25058 L
.5131 .2503 L
.50908 .2501 L
.50535 .24997 L
.50331 .24992 L
.5014 .24989 L
.4993 .24987 L
.49812 .24986 L
.49704 .24986 L
.49487 .24987 L
.49364 .24988 L
.4925 .2499 L
.49041 .24994 L
.48818 .25 L
.48586 .25008 L
.48339 .25018 L
.47898 .25041 L
.46899 .25116 L
.46035 .25205 L
.45086 .25326 L
.43336 .25611 L
.41711 .25942 L
.35436 .27757 L
.32335 .29001 L
.29723 .30337 L
.28606 .31045 L
.27526 .31854 L
.25886 .33495 L
.25207 .34441 L
.24598 .35563 L
.2436 .36118 L
.24139 .36731 L
.23819 .37902 L
.23678 .38619 L
.23577 .393 L
.23532 .39691 L
.23492 .40124 L
.23462 .40544 L
.23451 .40734 L
.23441 .4094 L
.23433 .41134 L
.23428 .41313 L
.23423 .41495 L
.23421 .41669 L
.23419 .41873 L
Mistroke
.23418 .42064 L
.23419 .42275 L
.23422 .42503 L
.23427 .42727 L
.23434 .42973 L
.23451 .43424 L
.23475 .43872 L
.23501 .4429 L
.23577 .45234 L
.23684 .46281 L
.23944 .48264 L
.24826 .53186 L
.26114 .58727 L
.27643 .64204 L
.31293 .74314 L
.33537 .78825 L
.34781 .80823 L
.36194 .82697 L
.37587 .84158 L
.38925 .85233 L
.40261 .86013 L
.40952 .86311 L
.41724 .86564 L
.42132 .86665 L
.42578 .86751 L
.42785 .86783 L
.43004 .86811 L
.43195 .8683 L
.43401 .86846 L
.43601 .86857 L
.43785 .86863 L
.43971 .86865 L
.44148 .86863 L
.44354 .86857 L
.44546 .86847 L
.44757 .86832 L
.44983 .8681 L
.45411 .86755 L
.45876 .86674 L
.4673 .86473 L
.47763 .86143 L
.48726 .85756 L
.52293 .83748 L
.56331 .80598 L
.64222 .72558 L
.70992 .64126 L
.73825 .60071 L
.76271 .56042 L
.77165 .54309 L
.77928 .52577 L
Mistroke
.78426 .5118 L
.78632 .50474 L
.78812 .49723 L
.78887 .49345 L
.78945 .48999 L
.78994 .48645 L
.79029 .48329 L
.79042 .4818 L
.79054 .4802 L
.79063 .47883 L
.7907 .47733 L
.79075 .47574 L
.79078 .47408 L
.79079 .47254 L
.79077 .47112 L
.79073 .46946 L
.79069 .46852 L
.79065 .46766 L
.79056 .46608 L
.79043 .46442 L
.79014 .46156 L
.78973 .45843 L
.78848 .45161 L
.78688 .44531 L
.78279 .43368 L
.77706 .42168 L
.76353 .40053 L
.72491 .35738 L
.67292 .31345 L
.64642 .29531 L
.6164 .27834 L
.59958 .27057 L
.5838 .26444 L
.55198 .25546 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00bOl30003
o`0000<01ol00`3oo`06o`<0bol00<Co9`35o`00^Olg0<3o002iocP0_ol00;So?02lo`00]?m30;Wo
002`od/0]Ol00:coDP2bo`00Z?mK0:go002Tob405?l00`3oo`09ob00Zol00:3o7@0Lo`030?oo01;o
6P2Xo`00W?lN01oo00<0ool05_lH0:Ko002Gob408Ol00`3oo`0IoaL0Y?l009Oo6`0Wo`030?oo01co
5`2Qo`00UOlI02_o0`0Ooa@0XOl009?o5`0_o`030?oo02?o4@2Po`00T?lF03?o00<0ool09_l@09ko
002>oa@0=ol00`3oo`0Xo`l0WOl008_o500jo`030?oo02_o3P2Ko`00RolB03co00<0ool0;Ol=09[o
0029oa80?_l00`3oo`0_o`d0V?l008So4011o`030?oo033o3@2Go`00QOlA04?o00<0ool0<_l=09Go
0023oa00A_l00`3oo`0co`d0U?l008;o3`18o`<0=Ol=09;o0020o`l0B_l00`3oo`0fo`l0Sol007ko
3`1<o`030?oo03So3P2>o`00N_l20003o`0000d0COl00`3oo`0io`l0S?l007Wo4@1?o`030?oo03_o
3P2;o`00N?l@057o00<0ool0??l>08[o001ho`h0Dol00`3oo`0no`d0ROl007Ko3P1Eo`030?oo043o
3028o`00M_l<05Oo00<0ool0@Ol=08Ko001eo``0F?l00`3oo`13o``0QOl007?o301Jo`030?oo04Co
3024o`00Lol;05_o0`15o``0Pol007;o2`1Lo`030?oo04Ko3022o`00LOl;05go00<0ool0Aol=083o
001ao`X0G_l00`3oo`19o``0Ool0073o2P1Oo`030?oo04[o301no`00Kol:063o00<0ool0Bol<07go
001_o`T0HOl00`3oo`1<o``0O?l006ko2P1Qo`030?oo04go3@1jo`00K_l906;o00<0ool0Col=07So
001]o`T0Hol00`3oo`1@o`d0Mol006co2P1So`<0DOl=07Ko001/o`T0I?l00`3oo`1Bo`d0MOl006_o
2@1Uo`030?oo05?o3@1do`00Jol906Go00<0ool0EOl<07?o001Zo`T0I_l00`3oo`1Fo`/0Lol006[o
201Wo`030?oo05Oo2`1bo`00JOl906Oo00<0ool0F?l;077o001Yo`T0G?l500Ko00<0ool0FOl;073o
001Yo`P0Gol00`3oo`06o`030?oo05_o2P1_o`00JOl805oo00<0ool01_l00`3oo`1Ko`/0K_l006So
2@1Oo`030?oo00Ko00<0ool0G?l;06go001Xo`T0E?l600Go00<0ool01_l405co2`1/o`00Iol9063o
00<0ool01_l00`3oo`1No`/0Jol006Oo2@1Po`030?oo00Ko00<0ool0Gol;06[o001Wo`T0G_l300So
00<0ool0H?l;06Wo001Wo`T0H?l00`3oo`06o`030?oo067o2`1Xo`00Iol806[o00<0ool0H_l:06So
001Vo`T0J_l00`3oo`1So`X0Iol006Ko2@1Zo`030?oo06Co2P1Vo`00Iol806[o00<0ool0IOl:06Go
001Wo`T0JOl00`3oo`1Vo`X0I?l006Ko2P1Yo`<0I_l;06?o001Vo`T0J_l00`3oo`1Wo`T0I?l006Ko
2@1Zo`030?oo06So2@1So`00I_l906[o00<0ool0JOl806?o001Uo`X0J_l00`3oo`1Yo`T0H_l006Go
2P1Zo`030?oo06[o2@1Qo`00I_l806_o00<0ool0Jol9063o001Vo`P0Jol00`3oo`1[o`T0H?l006Ko
201[o`030?oo06co2@1Oo`00I_l806_o00<0ool0KOl805oo001Vo`P0Jol00`3oo`1]o`T0G_l006Ko
201[o`<0K_l805ko001Vo`P0Jol00`3oo`1^o`P0G_l006Ko2@1Zo`030?oo06ko2@1Mo`00IOl:06[o
00<0ool0Kol805go001To``0JOl00`3oo`1_o`T0G?l006Go301Xo`030?oo073o201Lo`00I_l:06Wo
00<0ool0L?l805co001Vo`T0J_l00`3oo`1ao`P0Fol006Ko2@1Zo`030?oo077o2@1Jo`00Iol806[o
00<0ool0LOl905[o001Wo`P0J_l307;o201Jo`00Iol806[o00<0ool0L_l805[o001Wo`P0J_l00`3o
o`1bo`P0F_l006Oo201Zo`030?oo07;o2@1Io`003Ol302oo0`0Uo`P00ol5033o1@0]o`030?oo02oo
1@0_o`D02Ol:01go0`0co`<00ol000ko00<0ool0;Ol01@3oool002Co2003o`050?ooo`00<_l00`3o
o`0]o`030?oo037o00<0ool0;ol01@3oool000So300Ko`050?ooo`00<ol00`3oo`02o`003_l00`3o
o`0ao`030?oo02;o2004o`030?oo03?o00<0ool0;Ol00`3oo`0ao`030?oo033o00<0ool02_l<01ko
00<0ool0<Ol00`3oo`02o`002_l603;o00<0ool08_l800Go00<0ool0<_l00`3oo`0]o`030?oo037o
00<0ool0<Ol00`3oo`0:o`X07ol00`3oo`0]o`H00ol000;o1P03o`040?oo02Oo1P04o`809Ol900Go
00<0ool09_l600Go00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0ool02Ol901ko0P0ao`040?oo00Co
000;o`040?oo03?o00<0ool08_l900Go00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0<_l00`3o
o`09o`T08?l00`3oo`0^o`040?oo00Co000<o`030?l003?o00<0ool08ol800Ko00<0ool0<?l00`3o
o`0]o`030?oo037o00<0ool0<ol00`3oo`09o`P08?l00`3oo`0_o`030?l000Co000<o`030?l002oo
00D0oooo000Uo`P00_l01@3oool0033o0`0_o`<0;ol3037o00D0oooo000:o`T07?l01@3oool0037o
00<0o`001?l000go0P0`o`<09_l800?o0`0co`030?oo02go00<0ool0<Ol00`3oo`0`o`<02ol:01co
0`0co`801?l006So201Yo`030?oo077o301Go`00J?l806Wo00<0ool0L?l<05So001Xo`P0JOl00`3o
o`1ao`X0FOl006So201Yo`030?oo07;o2@1Io`00J?l806Wo00<0ool0L_l905Wo001Yo`L0JOl00`3o
o`1bo`T0FOl006Wo201Xo`030?oo07;o201Jo`00J_l706So00<0ool0L_l805[o0009ool0X`05o`00
2Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool01ol0103oool800Wo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`X000?o0?l02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00?o0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`040?ooo`P02Ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo2P000ol0o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool0<Ol00`3oo`0Zo`P0
<ol00`3oo`0ao`030?oo037o00<0ool0<_l00`3oo`08o`T08?l00`3oo`0ao`030?oo00?o001[o`L0
Iol00`3oo`1`o`P0G?l006_o1`1Wo`030?oo073o201Lo`00Jol706Oo00<0ool0L?l805co001[o`L0
Iol00`3oo`1_o`P0GOl006_o201Vo`030?oo06oo201Mo`00K?l706Ko00<0ool0Kol805go001/o`P0
IOl306ko2@1Mo`00K?l806Go00<0ool0K_l805ko001/o`P0IOl00`3oo`1]o`T0G_l006co201Uo`03
0?oo06go201Oo`00K?l906Co00<0ool0KOl805oo001]o`P0I?l00`3oo`1/o`P0H?l006go201To`03
0?oo06co201Po`00K_l706Co00<0ool0Jol9063o001^o`P0Hol00`3oo`1[o`P0HOl006ko201So`03
0?oo06[o2@1Qo`00Kol706?o00<0ool0JOl906;o001_o`L0Hol306Wo2@1Ro`00Kol806;o00<0ool0
J?l906?o001_o`P0H_l00`3oo`1Xo`P0I?l0073o1`1Ro`030?oo06Oo2@1To`00L?l706;o00<0ool0
Iol806Go001`o`P0HOl00`3oo`1Vo`T0IOl0073o201Qo`030?oo06Ko201Vo`00LOl7067o00<0ool0
IOl906Ko001ao`L0HOl00`3oo`1Uo`P0Iol0077o201Po`030?oo06Co201Xo`00LOl8063o0`1So`T0
J?l007;o1`1Po`030?oo06?o201Yo`00L_l805oo00<0ool0H_l906Wo001bo`P0Gol00`3oo`1Qo`T0
J_l007;o201Oo`030?oo067o201[o`00Lol705oo00<0ool0H?l906_o001co`P0G_l00`3oo`1Po`P0
K?l007?o201No`030?oo05oo201]o`00Lol805ko00<0ool0G_l906go001do`L0G_l00`3oo`1No`P0
K_l007Co201Mo`030?oo05go2@1^o`00M?l805go0`1Mo`P0Kol007Go1`1Mo`030?oo05co2@1_o`00
MOl705go00<0ool0Fol9073o001eo`P0G?l00`3oo`1Jo`T0LOl007Go201Lo`030?oo05[o2@1ao`00
M_l705co00<0ool0FOl907;o001fo`L0G?l00`3oo`1Ho`T0Lol007Ko201@o`D01_l00`3oo`1Ho`P0
M?l007Ko201Bo`030?oo00Ko00<0ool0Eol907Co001go`L0D_l00`3oo`06o`030?oo05Ko2@1eo`00
Mol705;o00<0ool01_l405Go201fo`00Mol8057o00<0ool01_l00`3oo`1Eo`T0M_l007Oo201Ao`03
0?oo00Ko00<0ool0E?l907Oo001ho`L0DOl00`3oo`06o`030?oo05?o2@1ho`00Mol804oo0`08o`03
0?oo05?o2@1ho`00Mol9053o00<0ool01_l00`3oo`1Bo`T0NOl007So201Io`030?oo057o2P1io`00
N?l805Wo00<0ool0D?l:07[o001ho`P0FOl00`3oo`1@o`T0Nol007Wo201Ho`030?oo04oo2P1ko`00
NOl805So00<0ool0C_l:07co001io`P0F?l304go2P1mo`00N_l805Oo00<0ool0C?l:07ko001jo`P0
Eol00`3oo`1<o`X0O_l007_o1`1Go`030?oo04_o2P1oo`00Nol805Ko00<0ool0B_l:083o001ko`P0
E_l00`3oo`19o`X0POl007co1`1Fo`030?oo04So2P22o`00O?l805Go00<0ool0B?l:08;o001lo`P0
EOl00`3oo`17o`X0Pol007go1`1Eo`030?oo04Ko2P24o`00OOl805Co0`15o`X0QOl007go201Do`03
0?oo04Go2@26o`00O_l705Co00<0ool0A?l:08Ko001no`P0Dol00`3oo`13o`X0Qol007ko201Co`03
0?oo04;o2P28o`00Ool705?o00<0ool0@Ol:08Wo001oo`P0D_l00`3oo`11o`X0ROl007oo201Bo`03
0?oo043o2P2:o`00P?l8057o00<0ool0?ol:08_o0020o`P0DOl00`3oo`0no`X0S?l0087o1`1Ao`<0
?Ol:08go0021o`P0D?l00`3oo`0mo`X0SOl0087o201@o`030?oo03co2P2>o`00P_l7053o00<0ool0
>ol:08oo0022o`P0Col00`3oo`0jo`X0T?l008;o201?o`030?oo03[o2@2Ao`00Pol704oo00<0ool0
>?l;097o0023o`P0C_l00`3oo`0go`/0T_l008?o201>o`030?oo03Ko2`2Co`00Q?l704ko00<0ool0
=Ol;09Co0024o`P0COl00`3oo`0do``0U?l008Co201=o`<0<ol<09Go0025o`L0COl00`3oo`0bo``0
U_l008Go201<o`030?oo037o302Go`00QOl804co00<0ool0<?l<09So0026o`P0Bol00`3oo`0_o`d0
V?l008Ko201;o`030?oo02ko3@2Io`00Q_l804_o00<0ool0;Ol<09_o0027o`P0?_l500Oo00<0ool0
;?l<09co0027o`P0?_l01@3oool000Oo00<0ool0:ol<09go0028o`P0?_l00`3oo`08o`030?oo02[o
302No`00R?l803oo00<0ool01ol402So302Oo`00R?l903oo00<0ool01_l00`3oo`0Xo``0X?l008Wo
2@0no`030?oo00Ko00<0ool09ol<0:7o002:o`P0?ol00`3oo`05o`030?oo02Ko302Ro`00R_l903[o
00D0oooo0007o`030?oo02Ko2`2So`00Rol803_o0`08o`030?oo02Go2`2To`00S?l804Go00<0ool0
9?l;0:Go002<o`P0AOl00`3oo`0So`/0Y_l008go2014o`030?oo02;o2`2Wo`00SOl904?o00<0ool0
8Ol;0:So002>o`P0@ol00`3oo`0Po``0Z?l008ko2@12o`<07ol<0:Wo002?o`P0@_l00`3oo`0No``0
Z_l0093o2011o`030?oo01go302[o`00T?l8047o00<0ool07?l<0:co002Ao`P0@?l00`3oo`0Ko``0
[Ol0097o2010o`030?oo01[o302^o`00T_l803oo00<0ool06Ol<0:oo002Bo`T0?_l00`3oo`0Ho``0
/?l009?o200no`030?oo01Oo302ao`00Tol903go00<0ool05_l<0;;o002Do`P0?Ol301Go302co`00
UOl803co00<0ool05?l<0;Co002Eo`T0>ol00`3oo`0Co``0]Ol009Go2@0ko`030?oo01;o302fo`00
U_l903[o00<0ool04Ol=0;Ko002Fo`X0>Ol00`3oo`0?o`h0]ol009Oo2@0io`030?oo00ko3@2io`00
V?l903So00<0ool03?l>0;[o002Ho`X0=ol00`3oo`0;o`h0^ol009Wo2P0fo`030?oo00[o3@2mo`00
V_l903Ko00<0ool02?l>0;ko002Jo`X0=Ol300Oo3@30o`00Vol:03Co00<0ool01Ol>0<7o002Lo`X0
<ol00`3oo`04o`d0`ol009co2`0bo`030?oo00?o3@34o`00WOl;037o00@0oooo3P35o`00W_l:037o
00<0ool03@37o`00W_l<02oo4037o`00X?l;02ko3`38o`00X?l=02[o3`3:o`00XOl>0003o`0002;o
403<o`00X_lA01oo403>o`00XolA01co403@o`00Y?lB00?o0P0Aoa80d_l00:Ko4@000ol0000200[o
5`3Co`00Z?lF00Co6@3Eo`00Z_l`0=Ko002/ob/00_l00`3oo`3Do`00[_lW00Co00<0ool0e?l00:ko
9@06o`030?oo0=Co002`ob801ol00`3oo`3Do`00/OlK00Go00<0ool01Ol00`3oo`3Do`00/_lJ00?o
0P08o`@0dol00;Oo4@09o`030?oo00Go00<0ool0e?l00;[o0P0Eo`030?oo00Go00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003>o`<02?l00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003@o`<0
1_l00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00<go1P06o`03
0?oo0=Co003>o`040?oo00Oo103Co`00c_l0103oo`3No`00col00`3o003No`00col00`3o003No`00
d?l20=ko003ook7o003ook7o0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.44802 .25546 m
.43363 .25897 L
.4181 .26378 L
.38752 .27642 L
.35516 .29432 L
.32642 .31393 L
.27639 .35613 L
.25452 .37856 L
.23465 .40304 L
.22704 .41453 L
.2203 .42682 L
.21572 .43746 L
.21377 .44314 L
.21203 .44943 L
.21129 .45269 L
.2107 .45575 L
.21019 .45894 L
.20982 .46185 L
.20968 .46324 L
.20954 .46475 L
.20944 .46606 L
.20936 .4675 L
.20928 .46904 L
.20923 .47068 L
.20921 .47221 L
.20921 .47364 L
.20924 .47532 L
.20926 .47628 L
.20929 .47717 L
.20937 .4788 L
.20948 .48055 L
.20974 .48359 L
.21013 .487 L
.21136 .49467 L
.21299 .50209 L
.21732 .51661 L
.22365 .5328 L
.2394 .56424 L
.28822 .63871 L
.35841 .72631 L
.43443 .80399 L
.47613 .83684 L
.49481 .84852 L
.51413 .85817 L
.52253 .86149 L
.53142 .86437 L
.53646 .8657 L
.54102 .8667 L
.54561 .86751 L
.54783 .86783 L
Mistroke
.54984 .86807 L
.55165 .86825 L
.5536 .86841 L
.55566 .86854 L
.55758 .86861 L
.5597 .86865 L
.56192 .86863 L
.56381 .86858 L
.56587 .86847 L
.56782 .86832 L
.56959 .86815 L
.57353 .86762 L
.57715 .86697 L
.58054 .86622 L
.58785 .86406 L
.59573 .86091 L
.60378 .85675 L
.61114 .85206 L
.62387 .84182 L
.63697 .82823 L
.66252 .79187 L
.68659 .74424 L
.72301 .64388 L
.73919 .58597 L
.75096 .53556 L
.7557 .51173 L
.75987 .48722 L
.76285 .46546 L
.76393 .45549 L
.76471 .4467 L
.76532 .43751 L
.76556 .4326 L
.76564 .43037 L
.76571 .42803 L
.76576 .42606 L
.76579 .42391 L
.76581 .42196 L
.76582 .42016 L
.76581 .41805 L
.76579 .41615 L
.76575 .41407 L
.76569 .41191 L
.7656 .40972 L
.76551 .40774 L
.76525 .40339 L
.76493 .39945 L
.76456 .39581 L
.76351 .38793 L
.76199 .37982 L
.76035 .37312 L
Mistroke
.75855 .36713 L
.75347 .35447 L
.74723 .34332 L
.7391 .33249 L
.73028 .32337 L
.71931 .31428 L
.69601 .29956 L
.66956 .28691 L
.63826 .27499 L
.60394 .26457 L
.5877 .26051 L
.57034 .25681 L
.55417 .254 L
.54559 .25278 L
.53639 .25169 L
.52793 .2509 L
.52024 .25037 L
.51654 .25018 L
.51459 .25009 L
.51253 .25002 L
.51072 .24997 L
.50874 .24992 L
.50693 .24989 L
.50524 .24987 L
.50347 .24986 L
.50158 .24986 L
.4998 .24987 L
.49818 .2499 L
.49628 .24993 L
.49422 .24999 L
.49049 .25012 L
.48659 .25032 L
.48246 .25059 L
.4751 .25123 L
.46838 .252 L
.46213 .25288 L
.44802 .25546 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00cOl500Oo
00<0ool02Ol30<So0038ob@000Co0000`?l00<Co0`000ol0000/0;[o002ooc`0]Ol00;[o@`2co`00
]om90;3o002eodl0[?l00;;oE@2Yo`00/OmI0:Ko002^oa`03ol00`3oo`0<obH0X_l00:co6@0Do`03
0?oo01So7P2No`00Z_lG01So00<0ool07_lJ09co002Xoa<07_l00`3oo`0Qoa/0V?l00:Go4`0Qo`03
0?oo02Go6@2Fo`00YOlA02?o0`0XoaP0U?l00:?o4@0Uo`030?oo02co602@o`00XOl@02So00<0ool0
<?lF08ko002Po`l0:_l00`3oo`0coaH0Rol009go400/o`030?oo03Ko502:o`00Vol@02ko00<0ool0
>OlD08Oo002Jo`l0<?l00`3oo`0loa<0QOl009So3`0bo`030?oo03ko4`23o`00Uol>03Co00<0ool0
@OlC083o002Eo`l0=Ol00`3oo`13oa40P?l009Co3P0go`<0AOlA07ko002Ao`l0>Ol00`3oo`17oa00
00?o0000N_l0093o3P0ko`030?oo04[o4@1io`00Sol=03go00<0ool0C?l@07So002=o`h0?_l00`3o
o`1>o`l0Mol008co3@10o`030?oo053o3P1fo`00Rol=047o00<0ool0D_l=07Go002:o``0@ol00`3o
o`1Co`d0M?l008Wo3014o`030?oo05Go301co`00R?l<04Go00<0ool0E_l<07;o0026o``0Aol00`3o
o`1Go``0LOl008Go3018o`<0F?l<073o0024o``0BOl00`3oo`1Io``0Kol008?o301:o`030?oo05[o
301^o`00P_l<04_o00<0ool0Fol<06go0021o``0C?l00`3oo`1Lo`X0K_l007oo301>o`030?oo05go
2P1]o`00O_l<04oo00<0ool0G_l:06co001mo``0D?l00`3oo`1Oo`T0K?l007_o3@1Ao`030?oo063o
2@1[o`00N_l=05;o00<0ool0H?l:06[o001io`d0Dol3067o2@1Zo`00N?l<05Go00<0ool0H_l906Wo
001go``0E_l00`3oo`1Ro`T0JOl007Ko301Go`030?oo06?o2@1Xo`00MOl<05So00<0ool0Hol906So
001do``0FOl00`3oo`1To`P0J?l007?o301Jo`030?oo06Co201Xo`00L_l<053o1@06o`030?oo06Go
201Wo`00LOl<05?o00<0ool01_l00`3oo`1Uo`P0Iol0073o301Do`030?oo00Ko00<0ool0I_l706Oo
001_o``0EOl00`3oo`06o`030?oo06Ko2@1Uo`00K_l<04_o1P05o`030?oo00Ko101Uo`T0IOl006go
301Go`030?oo00Ko00<0ool0Iol806Go001]o`/0F?l00`3oo`06o`030?oo06Ko2@1Uo`00K?l;05Oo
0`08o`030?oo06Ko2@1Uo`00K?l:05[o00<0ool01_l00`3oo`1Wo`T0I?l006_o2P1To`030?oo06Oo
2@1To`00J_l:06Go00<0ool0Iol906Co001Xo`/0I_l00`3oo`1Wo`T0I?l006So2P1Wo`030?oo06Oo
2@1To`00Iol;06Oo00<0ool0Iol906Co001Vo`/0J?l306So2@1So`00I_l:06Wo00<0ool0J?l906?o
001Uo`X0J_l00`3oo`1Xo`P0I?l006Co2P1[o`030?oo06So201To`00I?l906co00<0ool0J?l806Co
001So`X0K?l00`3oo`1Xo`P0I?l006?o2@1]o`030?oo06So201To`00H_l906ko00<0ool0J?l806Co
001Qo`X0K_l00`3oo`1Xo`P0I?l0067o2@1_o`030?oo06So201To`00H?l9073o00<0ool0J?l806Co
001Po`T0L?l306So201To`00Gol9077o00<0ool0J?l806Co001Po`L0L_l00`3oo`1Xo`P0I?l0063o
201ao`030?oo06So201To`00Gol9077o00<0ool0J?l806Co001Oo`P0L_l00`3oo`1Xo`P0I?l005ko
2@1bo`030?oo06So2@1So`00GOl907?o00<0ool0J?l906?o001Mo`T0Lol00`3oo`1Xo`P0I?l005go
2@1co`030?oo06Oo2@1To`00G?l:07?o0`1Wo`T0I?l005co2@1do`030?oo06Oo2@1To`00G?l907Co
00<0ool0Iol906Co001Lo`T0M?l00`3oo`1Wo`T0I?l000go0`0_o`<06Ol:00go1@0`o`D0;Ol00`3o
o`0_o`D0;ol<02Wo0`0co`<00ol000ko00<0ool0;Ol01@3oool001So2P0=o`050?ooo`00<_l00`3o
o`0]o`030?oo037o00<0ool0;ol00`3oo`0902So00D0oooo000co`030?oo00;o000>o`030?oo037o
00<0ool05ol800oo00<0ool0<ol00`3oo`0]o`030?oo037o00<0ool0<?l00`3oo`0802co00<0ool0
<Ol00`3oo`02o`002_l603;o00<0ool05ol8013o00<0ool0<_l00`3oo`0]o`030?oo037o00<0ool0
<Ol00`3o000702co00<0ool0;Ol600?o0002o`H00ol0103oo`0Wo`H01?l201[o2006o`H01Ol00`3o
o`0Vo`H01Ol00`3oo`0]o`030?oo037o00<0ool0<_l902[o0P0ao`040?oo00Co000;o`040?oo03?o
00<0ool05ol8017o00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0<_l902co00<0ool0;_l0103o
o`04o`003?l00`3o000co`030?oo01Oo200Bo`030?oo033o00<0ool0;Ol00`3oo`0ao`030?oo03?o
200/o`030?oo02oo00<0o`001?l000co00<0o`00;ol01@3oool001Wo200>o`050?ooo`00<?l302oo
0`0_o`<0<Ol00`3oo`0902So00D0oooo000ao`030?l000Co000=o`80<?l301[o200?o`<0<ol00`3o
o`0]o`030?oo037o00<0ool0<?l:02[o0`0co`801?l005_o2@1eo`030?oo06Ko201Vo`00Fol907Go
00<0ool0I_l806Ko001Lo`P0MOl00`3oo`1Vo`P0I_l005co2@1do`030?oo06Ko201Vo`00G?l907Co
00<0ool0I_l806Ko001Lo`T0M?l00`3oo`1Vo`P0I_l005co2@1do`030?oo06Ko201Vo`00G?l907Co
00<0ool0I_l706Oo0009ool0X`05o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo2`0:o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool01ol700Co00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool01ol00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`T000?o0?l02Ol00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo1`04o`030?oo00So00<0ool01ol00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o
0009o`030?oo037o00<0ool07Ol900_o00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0<Ol702ko
00<0ool0<Ol00`3oo`03o`00GOl907?o00<0ool0I?l806So001Mo`T0Lol00`3oo`1To`P0J?l005ko
2@1bo`030?oo06Co201Xo`00Gol807;o00<0ool0I?l706Wo001Oo`T0LOl00`3oo`1To`L0JOl0063o
201ao`030?oo06Co1`1Yo`00H?l8077o0`1So`P0JOl0067o201`o`030?oo06?o1`1Zo`00HOl8073o
00<0ool0Hol706[o001Qo`T0Kol00`3oo`1Ro`P0J_l006;o201_o`030?oo06;o201Zo`00H_l906ko
00<0ool0H_l806[o001So`P0K_l00`3oo`1Ro`P0J_l006?o2@1]o`030?oo06;o1`1[o`00I?l806go
00<0ool0HOl806_o001To`T0K?l00`3oo`1Qo`P0Jol006Go201/o`030?oo067o1`1/o`00IOl806co
0`1Qo`L0K?l006Ko201[o`030?oo067o1`1/o`00I_l806_o00<0ool0H?l806co001Vo`T0J_l00`3o
o`1Po`P0K?l006Oo201Zo`030?oo063o1`1]o`00Iol906Wo00<0ool0H?l706go001Xo`P0JOl00`3o
o`1Oo`P0KOl006So2@1Xo`030?oo05oo201]o`00JOl906Oo00<0ool0Gol706ko001Yo`T0Iol00`3o
o`1Oo`L0K_l006[o2@1Vo`<0Gol706ko001[o`T0IOl00`3oo`1No`P0K_l006co201Uo`030?oo05ko
201^o`00K?l906Co00<0ool0G_l806ko001]o`T0Hol00`3oo`1No`L0Kol006ko201So`030?oo05go
201_o`00K_l906;o00<0ool0GOl806oo001_o`T0HOl00`3oo`1Mo`P0Kol0073o201Qo`030?oo05go
1`1`o`00L?l9063o00<0ool0G?l8073o001ao`T0Gol00`3oo`1Lo`P0L?l007;o2@1No`<0G?l7077o
001bo`T0G_l00`3oo`1Ko`P0LOl007?o2@1Mo`030?oo05_o201ao`00M?l905co00<0ool0Fol707;o
001eo`P0G?l00`3oo`1Jo`P0L_l007Go2@1Ko`030?oo05[o201bo`00M_l905[o00<0ool0F_l707?o
001go`P0Col500Ko00<0ool0FOl807?o001go`T0D?l00`3oo`06o`030?oo05Wo201co`00N?l904oo
00<0ool01_l00`3oo`1Io`L0M?l007Wo201?o`030?oo00Ko101Go`P0M?l007Wo2P1=o`030?oo00Ko
00<0ool0F?l807Co001jo`X0C?l00`3oo`06o`030?oo05So1`1eo`00Nol904co00<0ool01_l00`3o
o`1Ho`L0MOl007_o2P19o`<02?l00`3oo`1Go`P0MOl007co2P1:o`030?oo00Ko00<0ool0Eol807Go
001mo`X0D_l00`3oo`1Go`P0MOl007go2`1Ao`030?oo05Ko2@1eo`00O_l:057o00<0ool0E_l807Ko
001oo`X0D?l00`3oo`1Fo`P0M_l007oo2`1?o`030?oo05Go2@1fo`00POl:04ko0`1Eo`P0Mol008;o
2@1>o`030?oo05Go201go`00P_l:04go00<0ool0E?l807So0023o`X0C?l00`3oo`1Do`P0N?l008Co
2P1;o`030?oo05Co201ho`00QOl:04[o00<0ool0Dol807Wo0025o`X0B_l00`3oo`1Co`P0NOl008Ko
2P19o`030?oo05;o2@1io`00Qol:04So00<0ool0D_l807[o0028o`X0Aol00`3oo`1Bo`P0N_l008Wo
2P16o`<0DOl807_o0029o`X0A_l00`3oo`1Ao`P0Nol008[o2P15o`030?oo057o201ko`00Rol:04Co
00<0ool0D?l807co002<o`X0@ol00`3oo`1@o`P0O?l008go2P12o`030?oo053o201lo`00SOl:04;o
00<0ool0Col807go002>o`X0@Ol00`3oo`1?o`P0OOl008oo2P10o`030?oo04ko2@1mo`00T?l:03oo
00<0ool0C_l807ko002Ao`X0?_l304ko201no`00TOl:03ko00<0ool0COl807oo002Bo`X0?Ol00`3o
o`1=o`P0Ool009?o2P0lo`030?oo04go201oo`00U?l:03_o00<0ool0C?l8083o002Eo`T0>ol00`3o
o`1<o`P0P?l009Go2P0jo`030?oo04co2020o`00U_l:03Wo00<0ool0Bol8087o002Go`X0>?l00`3o
o`1;o`P0POl009So2P0go`030?oo04[o2@21o`00V?l;03Ko00<0ool0B_l808;o002Ho``0=Ol304[o
2022o`00VOl<03Co00<0ool0BOl808?o002Jo``0<ol00`3oo`19o`P0Pol009_o300bo`030?oo04Wo
2023o`00W?l<037o00<0ool0B?l808Co002Mo``0<?l00`3oo`18o`P0Q?l009ko300_o`030?oo04Oo
2@24o`00Wol<02;o1@07o`030?oo04Oo2@24o`00X?l<027o00D0oooo0007o`030?oo04Oo2025o`00
XOl<027o00<0ool02?l00`3oo`16o`T0QOl00:;o300Qo`030?oo00Oo1015o`P0Q_l00:?o300Qo`03
0?oo00Ko00<0ool0AOl908Ko002To``08?l00`3oo`06o`030?oo04Go2027o`00YOl<023o00<0ool0
1Ol00`3oo`14o`T0Qol00:Ko2`0Lo`050?ooo`001ol00`3oo`14o`P0R?l00:Oo2`0Lo`<02?l00`3o
o`13o`T0R?l00:So2`0Vo`030?oo04?o2029o`00ZOl;02Go00<0ool0@_l908Wo002Zo`/09?l00`3o
o`12o`P0R_l00:_o2`0So`030?oo047o2@2:o`00Zol<02;o00<0ool0@Ol808_o002/o``08Ol3043o
2@2;o`00[Ol<023o00<0ool0@?l808co002^o``07ol00`3oo`0oo`T0S?l00:oo300No`030?oo03oo
202=o`00/?l<01go00<0ool0?_l908go002ao``07?l00`3oo`0mo`T0S_l00;;o300Ko`030?oo03go
2@2>o`00/ol<01[o00<0ool0??l908oo002do``06Ol00`3oo`0ko`X0Sol00;Go300Ho`030?oo03_o
2@2@o`00]_l<01Oo0`0jo`X0T?l00;Oo300Fo`030?oo03Wo2P2Ao`00^?l<01Go00<0ool0>Ol909;o
002io``05?l00`3oo`0ho`T0Tol00;[o3@0Bo`030?oo03Oo2P2Co`00^ol=017o00<0ool0=_l:09Co
002lo`d04?l00`3oo`0fo`T0UOl00;go3@0?o`030?oo03Go2P2Eo`00_ol<00ko00<0ool0=?l:09Ko
0030o`d03?l00`3oo`0co`X0Uol00<;o300;o`030?oo03?o2@2Ho`00`ol<00[o0`0bo`X0V?l00<Co
3009o`030?oo037o2P2Io`00aOl<00So00<0ool0<?l:09[o0036o`d01_l00`3oo`0_o`/0V_l00<So
3005o`030?oo02ko2`2Ko`00bOl=00?o00<0ool0;Ol;09co003:o`d00_l00`3oo`0[o`d0W?l00<_o
3`0/o`d0WOl00<co3`0Zo`d0W_l00<ko3`0Vo`d0X?l00<oo400So`h0X?l00=;o4@0No`h0XOl00=;o
5P03o`804_l?0:;o003Doa@00_l400[o0P02oa00Y?l00=Ko6P04oaH0Y_l00=So<P2Vo`00fOl_0:So
003>o`<02?l00`3oo`0Z0:[o003=o`050?ooo`001ol00`3oo`02obH0[?l00=7o00<0ool01Ol00`3o
o`07oal0[_l00=7o00<0ool01Ol00`3oo`08oa/0/Ol00<oo0P08o`@01olK0;7o003Ao`030?oo00Go
00<0ool03OlA0;Ko003Ao`030?oo00Go00<0ool04?l20<;o003=o`050?ooo`001ol00`3oo`3Do`00
c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00d?l300Ko00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`H01_l00`3oo`3Do`00c_l0103oo`07o`@0
dol00<ko00@0ool0g_l00<oo00<0o`00g_l00<oo00<0o`00g_l00=3o0P3No`00oonao`00oonao`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.35305 .29775 m
.3291 .31751 L
.30631 .3415 L
.26575 .40062 L
.23778 .45811 L
.22694 .48711 L
.22217 .50274 L
.21869 .51678 L
.21737 .52342 L
.21619 .53063 L
.21533 .53776 L
.21515 .53962 L
.215 .54162 L
.21488 .54348 L
.21478 .5452 L
.21472 .54681 L
.21469 .5477 L
.21467 .54852 L
.21466 .54941 L
.21465 .55037 L
.21464 .55128 L
.21465 .55211 L
.21467 .55362 L
.21471 .55527 L
.21474 .5561 L
.21478 .55698 L
.21487 .55858 L
.21512 .56181 L
.21544 .56485 L
.21628 .57049 L
.21743 .57607 L
.21908 .58217 L
.22371 .59436 L
.2296 .60552 L
.2366 .61594 L
.25793 .63962 L
.2843 .66185 L
.36114 .71183 L
.45427 .7604 L
.50968 .78475 L
.55937 .80298 L
.58331 .81014 L
.59558 .81328 L
.60826 .8161 L
.61907 .81811 L
.62469 .81899 L
.63063 .81979 L
.636 .8204 L
.64083 .82083 L
.64312 .821 L
Mistroke
.6456 .82116 L
.64778 .82127 L
.65007 .82136 L
.65138 .8214 L
.65281 .82143 L
.65531 .82147 L
.65671 .82147 L
.6582 .82146 L
.6596 .82143 L
.66086 .8214 L
.6633 .82132 L
.66467 .82125 L
.66592 .82118 L
.6706 .82083 L
.67467 .82039 L
.67905 .81977 L
.68763 .81808 L
.69228 .81687 L
.69643 .81559 L
.70534 .81211 L
.7127 .80836 L
.71994 .80373 L
.7319 .79333 L
.73782 .78647 L
.74272 .77961 L
.751 .76455 L
.75731 .74837 L
.76004 .73923 L
.76262 .72866 L
.76486 .71704 L
.76656 .7057 L
.7678 .69468 L
.76866 .68432 L
.76903 .67847 L
.76935 .67201 L
.76947 .66902 L
.76957 .66582 L
.76965 .66283 L
.76971 .66002 L
.76976 .65706 L
.76979 .6538 L
.7698 .6506 L
.7698 .64717 L
.76978 .64395 L
.76974 .64089 L
.7697 .63814 L
.76964 .63514 L
.76945 .62821 L
.76917 .6208 L
.76848 .60738 L
Mistroke
.76765 .5948 L
.7667 .58294 L
.76402 .55577 L
.75633 .49865 L
.74749 .44866 L
.73615 .3977 L
.7244 .35625 L
.71184 .32231 L
.69686 .29315 L
.68825 .28073 L
.67824 .26936 L
.66805 .26048 L
.65801 .25378 L
.64719 .24832 L
.63646 .2443 L
.62397 .24095 L
.61664 .23951 L
.60976 .23846 L
.6031 .23767 L
.59939 .23732 L
.59586 .23704 L
.58954 .23666 L
.58613 .23652 L
.58434 .23646 L
.58242 .23641 L
.58046 .23637 L
.57864 .23634 L
.57751 .23633 L
.57645 .23632 L
.57446 .23631 L
.57343 .23631 L
.57234 .23632 L
.57037 .23633 L
.56928 .23635 L
.56825 .23636 L
.56591 .23641 L
.562 .23652 L
.55841 .23665 L
.55024 .23705 L
.54254 .23757 L
.53424 .23826 L
.51914 .23987 L
.50096 .24237 L
.4844 .24522 L
.45216 .2525 L
.41835 .26319 L
.38765 .27661 L
.35769 .29446 L
.35305 .29775 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`0@o`804ol20:go
003Io`030?oo00Go0`03ob80Yol00=Wo00<0o`00<P2Ro`00e_lh00;o0P2No`00eOm109[o003BodD0
VOl00<goC02Go`00a_mF09Co0031oe`0Tol00<3o;00Goad0T?l00;co8@0_oaD0Sol00;Oo8002o`03
0?oo03Go4@2>o`00]OlO00Go00<0ool0>?l?08go002boad00_l00`3oo`05o`030?oo03[o3`2;o`00
/OlH00Go0`08o`030?oo03co3P2:o`00[_lG01Co00<0ool0?Ol>08Wo002/oaH05ol00`3oo`0oo`h0
Qol00:[o500Ko`030?oo047o3@26o`00Z?lC01ko00<0ool0@_l<08Ko002Uoa<08Ol00`3oo`13o``0
QOl00:Go4@0So`<0A?l<08Co002Soa409Ol00`3oo`15o``0Pol00:7o400Xo`030?oo04Ko3022o`00
WOl20003o`0000d0:_l00`3oo`17o`X0Pol009co4@0/o`030?oo04So2@23o`00Vol@02ko00<0ool0
BOl808?o002Jo`l0<?l00`3oo`1:o`P0P_l009Wo3P0bo`030?oo04[o2022o`00V?l=03Co00<0ool0
Bol8087o002Go`d0=Ol00`3oo`1;o`T0P?l009Go3@0go`<0C?l8083o002Do`d0>?l00`3oo`1<o`T0
Ool009?o3@0io`030?oo04go2@1no`00TOl>03[o00<0ool0C_l807ko002@o`h0>ol00`3oo`1>o`T0
OOl008oo3P0lo`030?oo04oo201mo`00SOl=03oo00<0ool0D?l807co002<o`d0@?l00`3oo`1@o`T0
Nol008co3011o`030?oo057o201ko`00Rol<04;o00<0ool0DOl907[o002:o``0@ol00`3oo`1Bo`P0
N_l008Wo3014o`<0D_l907Wo0028o``0AOl00`3oo`1Co`P0NOl008Oo3016o`030?oo05?o201io`00
Q_l<04Oo00<0ool0E?l707Wo0025o``0B?l00`3oo`1Do`P0N?l008Co3019o`030?oo05Co201ho`00
Pol<04[o00<0ool0EOl707So0022o``0Bol00`3oo`1Eo`P0Mol008?o2P1<o`030?oo05Go201go`00
P_l:04go00<0ool0E_l707Oo0022o`T0C_l305Ko201fo`00POl904oo00<0ool0E_l807Ko0020o`T0
D?l00`3oo`1Go`P0MOl0083o201Ao`030?oo05Oo201eo`00Ool9057o00<0ool0Eol807Go001no`T0
D_l00`3oo`1Ho`P0M?l007ko201Co`030?oo05So201do`00OOl904So1@06o`030?oo05So201do`00
O?l904_o00<0ool01_l00`3oo`1Io`L0M?l007_o2@1<o`030?oo00Ko00<0ool0FOl807?o001ko`T0
C?l00`3oo`06o`030?oo05Wo201co`00N_l904;o1P05o`030?oo00Ko101Io`L0Lol007Wo2@1>o`03
0?oo00Ko00<0ool0F_l707?o001io`P0Col00`3oo`06o`030?oo05[o201bo`00N?l904go0`08o`03
0?oo05[o201bo`00Mol9053o00<0ool01_l00`3oo`1Ko`L0L_l007Oo201Jo`030?oo05_o201ao`00
M_l905[o00<0ool0Fol8077o001eo`T0Fol00`3oo`1Lo`P0L?l007Co2@1Lo`030?oo05co201`o`00
M?l905co00<0ool0G?l8073o001co`T0GOl305go1`1`o`00Lol805ko00<0ool0GOl806oo001bo`T0
G_l00`3oo`1Mo`P0Kol007;o201Oo`030?oo05go201_o`00LOl905oo00<0ool0G_l706oo001ao`P0
H?l00`3oo`1No`L0Kol0073o2@1Po`030?oo05ko1`1_o`00L?l8067o00<0ool0G_l806ko001`o`P0
HOl00`3oo`1No`P0K_l006oo201Ro`030?oo05oo1`1^o`00Kol806;o00<0ool0Gol706ko001^o`T0
H_l305oo1`1^o`00K_l806?o00<0ool0Gol806go001]o`T0Hol00`3oo`1Oo`P0KOl006go201To`03
0?oo063o1`1]o`00K?l906Co00<0ool0H?l706go001/o`P0IOl00`3oo`1Po`L0KOl006co201Uo`03
0?oo063o201/o`00Jol806Ko00<0ool0H?l806co001[o`P0I_l00`3oo`1Po`P0K?l006[o2@1Vo`03
0?oo063o2@1[o`00J_l806Oo0`1Qo`P0Jol006Wo2@1Wo`030?oo067o201[o`00JOl806So00<0ool0
HOl806_o001Xo`T0J?l00`3oo`1Qo`P0Jol000go0`0_o`<09_l800;o1@0`o`D0;Ol00`3oo`0_o`D0
;Ol802oo0`0co`<00ol000ko00<0ool0;Ol01@3oool002Co2@02o`050?ooo`00<_l00`3oo`0]o`03
0?oo037o00<0ool0;Ol902go00D0oooo000co`030?oo00;o000>o`030?oo037o00<0ool08_l800Co
00<0ool0<ol00`3oo`0]o`030?oo037o00<0ool0;_l8037o00<0ool0<Ol00`3oo`02o`002_l603;o
00<0ool08_l800Go00<0ool0<_l00`3oo`0]o`030?oo037o00<0ool0;_l8037o00<0ool0;Ol600?o
0002o`H00ol0103oo`0Wo`H01?l202Co2P05o`030?oo02Ko1P05o`030?oo02go00<0ool0<Ol00`3o
o`0^o`P0;ol2037o00@0ool01?l000_o00@0ool0<ol00`3oo`0Qo`P01ol00`3oo`0ao`030?oo02go
00<0ool0<Ol00`3oo`0^o`P0<Ol00`3oo`0^o`040?oo00Co000<o`030?l003?o00<0ool08?l900So
00<0ool0<?l00`3oo`0]o`030?oo037o00<0ool0;_l9033o00<0ool0;ol00`3o0004o`003?l00`3o
000_o`050?ooo`008_l800Go00D0oooo000`o`<0;ol302oo0`0ao`P0;?l01@3oool0037o00<0o`00
1?l000go0P0`o`<08ol800Ko0`0co`030?oo02go00<0ool0<Ol00`3oo`0_o`P0;Ol303?o0P04o`00
I?l806go00<0ool0Hol806Wo001To`P0KOl00`3oo`1So`P0JOl006?o2@1]o`030?oo06?o2@1Xo`00
Hol806ko00<0ool0I?l806So001Ro`T0K_l00`3oo`1To`P0J?l006;o201_o`030?oo06Co201Xo`00
H_l806oo00<0ool0I?l906Oo001Ro`P0Kol00`3oo`1To`T0Iol000Woo`2S00Go0009o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`02o`P02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo2003o`030?oo00So
00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00?o0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`02o`L02Ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00Oo2003o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo037o00<0ool08?l800Wo
00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0<Ol802go00<0ool0<Ol00`3oo`03o`00H?l9073o
00<0ool0IOl806Oo001Qo`P0L?l00`3oo`1Uo`P0Iol0067o1`1ao`030?oo06Go2@1Vo`00Gol9077o
00<0ool0I_l806Ko001Oo`T0LOl00`3oo`1Vo`P0I_l005oo201bo`030?oo06Ko201Vo`00Gol9077o
0`1Vo`P0I_l005oo2@1ao`030?oo06Ko201Vo`00G_l907;o00<0ool0I_l806Ko001No`T0L_l00`3o
o`1Vo`P0I_l005ko2@1bo`030?oo06Ko2@1Uo`00G_l907;o00<0ool0Iol806Go001No`T0L_l00`3o
o`1Wo`P0IOl005ko2@1bo`030?oo06Oo201Uo`00GOl907?o00<0ool0Iol806Go001Mo`T0Lol00`3o
o`1Wo`P0IOl005ko201co`030?oo06Ko2@1Uo`00G_l807?o0`1Vo`T0IOl005ko201co`030?oo06Ko
2P1To`00G_l807?o00<0ool0Iol906Co001No`P0Lol00`3oo`1Wo`T0I?l005go2@1co`030?oo06Oo
2@1To`00G_l907;o00<0ool0Iol906Co001No`T0L_l00`3oo`1Wo`T0I?l005ko2@1bo`030?oo06So
201To`00G_l907;o00<0ool0J?l806Co001No`T0L_l00`3oo`1Xo`P0I?l005ko2P1ao`<0J?l906?o
001Oo`P0L_l00`3oo`1Yo`P0Hol005oo2@1ao`030?oo06Wo201So`00Gol9077o00<0ool0JOl806?o
001Oo`X0L?l00`3oo`1Yo`P0Hol005oo2P1`o`030?oo06Wo2@1Ro`00HOl8073o00<0ool0JOl906;o
001Qo`T0Kol00`3oo`1Yo`T0H_l006;o201_o`030?oo06Wo201So`00H_l906ko00<0ool0JOl806?o
001So`P0K_l00`3oo`1Yo`P0Hol006?o2@1]o`<0JOl806?o001So`T0KOl00`3oo`1Yo`P0Hol006Co
2@1/o`030?oo06Wo201So`00I?l:06_o00<0ool0JOl806?o001Uo`X0J_l00`3oo`1Yo`P0Hol006Go
2`1Yo`030?oo06Wo2@1Ro`00I_l;06So00<0ool0JOl906;o001Wo`/0G?l500Ko00<0ool0JOl906;o
001Wo``0GOl00`3oo`06o`030?oo06[o201Ro`00J?l;05go00<0ool01_l00`3oo`1Zo`P0H_l006Wo
2`1Lo`030?oo00Ko101Yo`P0H_l006Wo301Ko`030?oo00Ko00<0ool0J_l806;o001/o`X0F_l00`3o
o`06o`030?oo06[o201Ro`00KOl:05Wo00<0ool01_l00`3oo`1Zo`P0H_l006go2`1Fo`<02?l00`3o
o`1Zo`P0H_l006ko2`1Go`030?oo00Ko00<0ool0J_l806;o001_o`/0Gol00`3oo`1Zo`P0H_l0073o
2`1No`030?oo06[o201Ro`00LOl;05go00<0ool0J_l806;o001bo`/0G?l00`3oo`1Zo`P0H_l007?o
2`1Ko`030?oo06[o201Ro`00M?l;05[o0`1Zo`P0H_l007Go2`1Io`030?oo06[o201Ro`00M_l;05So
00<0ool0J_l806;o001go`/0Eol00`3oo`1Zo`P0H_l007So301Eo`030?oo06[o201Ro`00NOl=05?o
00<0ool0J_l806;o001jo`d0D_l00`3oo`1Zo`P0H_l007_o3P1@o`030?oo06[o201Ro`00O?l>04oo
00<0ool0J_l806;o001mo`l0COl00`3oo`1Zo`P0H_l007ko401;o`<0J_l9067o0022o`d0B_l00`3o
o`1Yo`X0HOl008?o3P18o`030?oo06Wo2@1Ro`00QOl=04Oo00<0ool0JOl906;o0026o`h0AOl00`3o
o`1Yo`T0H_l008So3@14o`030?oo06So2P1Ro`00R_l=04;o00<0ool0J?l:06;o002;o`h0@?l00`3o
o`1Yo`P0Hol008go3@0oo`030?oo06Wo201So`00S_l>03go00<0ool0JOl806?o002@o`d0??l306Wo
201So`00TOl>03[o00<0ool0JOl806?o002Co`h0>?l00`3oo`1Yo`P0Hol009Go3@0go`030?oo06Wo
201So`00U_l>03Go00<0ool0JOl806?o002Ho`h0<ol00`3oo`1Yo`P0Hol009Wo3`0ao`030?oo06Wo
201So`00V_l@02oo00<0ool0JOl806?o002Koa40;Ol00`3oo`1Yo`L0I?l009go4@0[o`030?oo06So
201To`00WolA02Wo00<0ool0J?l806Co002Qoa409ol306So201To`00XolA02Go00<0ool0Iol806Go
002Uoa009?l00`3oo`1Wo`P0IOl00:Oo400Ro`030?oo06Oo201Uo`00ZOl@023o00<0ool0Iol806Go
002[oa007_l00`3oo`1Wo`P0IOl00:go400Lo`030?oo06Oo1`1Vo`00[ol@00ko1@07o`030?oo06Ko
201Vo`00/Ol@00co00D0oooo0007o`030?oo06Ko201Vo`00/_lA00_o00<0ool02?l00`3oo`1Uo`T0
I_l00;Co4@0:o`030?oo00Oo101To`P0Iol00;Ko4@09o`030?oo00Ko00<0ool0I?l906Oo002hoa40
1ol00`3oo`06o`030?oo06Co2@1Wo`00^_lA00Ko00<0ool01Ol00`3oo`1So`X0Iol00;co4P03o`03
0?oo00Go00<0ool0Hol906So002noa<02?l00`3oo`1Ro`T0JOl00<3o4@08o`030?oo06;o201Zo`00
`OlC00Go00<0ool0HOl906[o0033oa<00ol00`3oo`1Qo`P0Jol00<Go4`000ol0o`1Ro`P0Jol00<Oo
4`1Ro`P0K?l00<[o4`1Oo`P0K?l00<co4`1Lo`T0K?l00<ko501Go`X0KOl00=7o501Co`/0KOl00=?o
5@1?o`/0K_l00=Go5@1<o``0K_l00=Oo5P18o`d0K_l00=Wo6013o`d0Kol00=Wo00<0ool0600oo``0
LOl00=Wo00<0ool01?lG03_o3@1ao`00fOl300Oo6@0eo``0Lol00=Wo00<0ool02_lH037o3@1do`00
fOl00`3oo`0<oaT0;?l>07Go003Io`030?oo00oo600Woa00M_l00=Wo00<0ool04_lN01[o4`1go`00
fOl00`3oo`0Eob004olD07So003Io`030?oo01Wo@P1io`00fOl00`3oo`0Loch0N_l00=Wo00<0ool0
7olh07go003Io`030?oo027o<`20o`00fOl00`3oo`0Tobl0POl00=Wo0`0ZobT0POl00=Wo00<0ool0
:olR08Oo003Io`030?oo033o7028o`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3o
o`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`03
0?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.28349 .375 m
.26965 .4028 L
.25858 .43398 L
.25413 .45099 L
.25076 .46714 L
.24785 .48511 L
.24656 .49518 L
.24558 .50449 L
.24485 .51278 L
.24422 .52189 L
.24374 .53102 L
.24355 .536 L
.24341 .54065 L
.24336 .54273 L
.24331 .54501 L
.24328 .54715 L
.24325 .54913 L
.24324 .55109 L
.24323 .55287 L
.24323 .55491 L
.24323 .55683 L
.24325 .55893 L
.24326 .55998 L
.24327 .56113 L
.24334 .56507 L
.24339 .56728 L
.24345 .56964 L
.2436 .57388 L
.244 .58233 L
.2445 .59002 L
.24521 .5983 L
.24614 .60692 L
.24816 .62088 L
.25113 .63552 L
.25478 .64869 L
.25893 .66003 L
.26448 .67162 L
.27162 .68284 L
.27922 .69203 L
.28878 .70098 L
.29927 .70865 L
.31011 .715 L
.33857 .72702 L
.35754 .73275 L
.3769 .73743 L
.41795 .74482 L
.44377 .74826 L
.46932 .75099 L
.49719 .75332 L
.51129 .75427 L
Mistroke
.52454 .75502 L
.53765 .75564 L
.5496 .75609 L
.56295 .75646 L
.56647 .75653 L
.57029 .7566 L
.5739 .75666 L
.5772 .7567 L
.5807 .75673 L
.58401 .75675 L
.5875 .75676 L
.58948 .75677 L
.5913 .75677 L
.59433 .75676 L
.59767 .75674 L
.60115 .75671 L
.60441 .75667 L
.60805 .75661 L
.61187 .75654 L
.61867 .75638 L
.62597 .75615 L
.63389 .75583 L
.64854 .75505 L
.6639 .75392 L
.67809 .75257 L
.69065 .75108 L
.7156 .74716 L
.73705 .74246 L
.75864 .73599 L
.77897 .72757 L
.79459 .71867 L
.8022 .71317 L
.80874 .70755 L
.81421 .70198 L
.81949 .69552 L
.82706 .68324 L
.83032 .6759 L
.83278 .66867 L
.83481 .66036 L
.83565 .65551 L
.83595 .65333 L
.83623 .65096 L
.83646 .64858 L
.83663 .64639 L
.83676 .64417 L
.83684 .64205 L
.83688 .64084 L
.8369 .63955 L
.83691 .63723 L
.8369 .63593 L
Mistroke
.83688 .6347 L
.83684 .63335 L
.83679 .63189 L
.83665 .62921 L
.83645 .62624 L
.83593 .62076 L
.83524 .61533 L
.83445 .61021 L
.83237 .59947 L
.82945 .5875 L
.8225 .565 L
.80453 .52073 L
.74943 .41952 L
.68918 .33026 L
.63434 .26431 L
.60837 .24036 L
.59447 .23013 L
.58188 .22263 L
.56929 .21691 L
.56268 .21462 L
.55568 .21274 L
.55275 .21211 L
.5496 .21154 L
.54688 .21112 L
.54389 .21076 L
.54057 .21047 L
.53875 .21036 L
.53789 .21031 L
.53706 .21028 L
.53547 .21023 L
.53403 .21021 L
.53246 .21021 L
.53158 .21022 L
.53077 .21023 L
.5292 .21028 L
.5277 .21034 L
.52636 .21041 L
.52489 .21051 L
.5216 .2108 L
.51853 .21115 L
.51292 .21198 L
.50689 .21313 L
.49268 .21678 L
.47953 .22118 L
.42323 .24786 L
.36844 .28342 L
.34239 .30451 L
.31653 .32994 L
.28349 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo013o0P32o`00fOl300Go0P08o`@0`Ol00=Wo
00@0oooo502oo`00f?lL0;co003Fob00^_l00=Co902ho`00dOlZ0;Go003?obh0/ol00<co=P2^o`00
bolh0:go0039oaX01olJ0:co0036oaH04Ol200?o502Zo`00a?lC00;o00<0ool06OlA0:[o0032oa80
1Ol00`3oo`0Lo`l0ZOl00<3o4P07o`030?oo01ko3P2Xo`00_OlC00Wo00<0ool08?l=0:Oo002koa<0
2ol00`3oo`0Ro``0Y_l00;Wo4`0=o`030?oo02?o302Uo`00]olB00Co1@07o`030?oo02Co302To`00
]?lC00Ko00D0oooo0007o`030?oo02Go302So`00]?lA00Wo00<0ool02?l00`3oo`0Vo``0X_l00;?o
400<o`030?oo00Oo00<0ool09ol<0:7o002ao`l01Ol600Go00<0ool01_l402Oo302Po`00/?l>01;o
00<0ool01_l00`3oo`0Yo`d0W_l00:ko3P0Eo`030?oo00Go00<0ool0:ol<09go002]o`d04ol01@3o
ool000Oo00<0ool0;?l<09co002[o`d05_l300So00<0ool0;Ol;09co002Yo`h08_l00`3oo`0^o`/0
Vol00:So3@0To`030?oo02oo2`2Jo`00Y_l>02Go00<0ool0<?l;09Wo002Uo`d09ol00`3oo`0ao`/0
V?l00:?o3P0Xo`030?oo03;o2`2Go`00X_l=02[o0`0co`/0U_l00:3o3@0/o`030?oo03Co2P2Fo`00
Wol=02go00<0ool0=Ol:09Go002Mo`d0;ol00`3oo`0fo`X0U?l009co3@0`o`030?oo03Oo2P2Co`00
V_l>037o00<0ool0>?l:09;o002Io`h0<_l00`3oo`0ho`/0TOl009Oo3P0do`030?oo03Wo2`2@o`00
U_l>03Go00<0ool0>_l:093o002Do`h0=ol00`3oo`0ko`X0Sol009?o3P0ho`<0??l:08ko002Ao`h0
>_l00`3oo`0mo`X0SOl009;o300ko`030?oo03ko2P2<o`00TOl;03go00<0ool0?_l;08_o002@o`/0
?_l00`3oo`0oo`X0Rol008oo2`0oo`030?oo043o2P2:o`00S_l;043o00<0ool0@Ol:08Wo002=o`/0
@Ol00`3oo`12o`X0R?l008_o3012o`030?oo04?o2P27o`00Rol;04?o00<0ool0@ol;08Ko002:o`/0
A?l00`3oo`14o`/0QOl008Wo2`15o`<0AOl:08Go0028o`/0A_l00`3oo`16o`X0Q?l008Oo2`17o`03
0?oo04Oo2P23o`00Qol:04So00<0ool0B?l:08;o0026o`X0BOl00`3oo`19o`T0P_l008Ko2@1:o`03
0?oo04Wo2@22o`00QOl:04[o00<0ool0B_l9087o0024o`X0Bol00`3oo`1;o`T0P?l008Co2@1<o`03
0?oo04co2020o`00Pol904go00<0ool0C?l907oo0022o`X0COl304go2@1no`00P_l904ko00<0ool0
C_l807ko0021o`T0Col00`3oo`1>o`T0OOl0083o2P1?o`030?oo04oo2@1lo`00P?l9053o00<0ool0
D?l807co001oo`T0DOl00`3oo`1@o`T0Nol007go2`1Ao`030?oo057o2@1jo`00OOl:04Oo1@06o`03
0?oo05;o201jo`00O?l:04[o00<0ool01_l00`3oo`1Bo`T0NOl007co2P1:o`030?oo00Ko00<0ool0
Dol907So001ko`X0Bol00`3oo`06o`030?oo05Co2@1go`00Nol9047o1P05o`030?oo00Ko101Co`T0
Mol007[o2@1=o`030?oo00Ko00<0ool0EOl907Ko001jo`T0COl00`3oo`06o`030?oo05Ko2@1eo`00
NOl904co0`08o`030?oo05Oo201eo`00N?l904oo00<0ool01_l00`3oo`1Go`T0M?l007So2@1Ho`03
0?oo05So2@1co`00Mol905Wo00<0ool0FOl807?o001go`P0F_l00`3oo`1Io`T0L_l007Ko201Ko`03
0?oo05[o2@1ao`00M_l805_o00<0ool0Fol8077o001eo`T0Fol305_o2@1`o`00MOl805co00<0ool0
G?l906oo001do`T0G?l00`3oo`1Mo`P0Kol007Co201Mo`030?oo05go2P1]o`00M?l805go00<0ool0
G_l906go001co`T0GOl00`3oo`1Oo`T0K?l007?o201No`030?oo05oo2@1/o`00Lol805ko00<0ool0
H?l906_o001bo`P0Gol00`3oo`1Qo`P0Jol007;o201Oo`030?oo067o2@1Zo`00LOl905oo00<0ool0
H_l806[o001ao`P0H?l306?o201Yo`00LOl8063o00<0ool0Hol806Wo001`o`T0H?l00`3oo`1To`P0
J?l0073o2@1Po`030?oo06Co201Xo`00Kol9067o00<0ool0IOl806Oo001_o`T0HOl00`3oo`1Uo`T0
I_l0073o201Qo`030?oo06Ko201Vo`00L?l8067o00<0ool0I_l906Go001`o`P0HOl00`3oo`1Wo`P0
IOl0073o201Qo`030?oo06So201To`00L?l8067o0`1Xo`P0I?l006oo2@1Qo`030?oo06Wo201So`00
Kol806;o00<0ool0JOl806?o001^o`T0H_l00`3oo`1Zo`P0H_l000go0`0_o`<0;?l9033o1@0]o`03
0?oo02oo1@0_o`D00_l802Ko0`0co`<00ol000ko00<0ool0;Ol01@3oool002_o2@0bo`030?oo02go
00<0ool0<Ol00`3oo`0_o`050?ooo`000ol802Co00D0oooo000co`030?oo00;o000>o`030?oo037o
00<0ool0:?l903?o00<0ool0;Ol00`3oo`0ao`030?oo033o00<0ool01?l902Oo00<0ool0<Ol00`3o
o`02o`002_l603;o00<0ool0:?l903?o00<0ool0;Ol00`3oo`0ao`030?oo037o00<0ool01?l802Oo
00<0ool0;Ol600?o0002o`H00ol0103oo`0Wo`H01?l202So300Xo`H01Ol00`3oo`0]o`030?oo037o
00<0ool0<_l00`3oo`03o`T09?l2037o00@0ool01?l000_o00@0ool0<ol00`3oo`0Wo`X0<ol00`3o
o`0]o`030?oo037o00<0ool0<_l00`3oo`04o`P09_l00`3oo`0^o`040?oo00Co000<o`030?l003?o
00<0ool09ol90003o`3o037o00<0ool0;Ol00`3oo`0ao`030?oo03?o00<0ool01?l802Go00<0ool0
;ol00`3o0004o`003?l00`3o000_o`050?ooo`00:_l80003o`3o02oo0`0_o`<0;ol3037o00D0oooo
0006o`P08Ol01@3oool0037o00<0o`001?l000go0P0`o`<0:ol903?o00<0ool0;Ol00`3oo`0ao`03
0?oo033o0`08o`P08Ol303?o0P04o`00KOl806Co00<0ool0Kol805go001]o`P0I?l00`3oo`1`o`P0
G?l006co2@1To`030?oo073o201Lo`00Jol906Go00<0ool0LOl805_o001[o`T0IOl00`3oo`1ao`P0
Fol006_o2@1Uo`030?oo07;o201Jo`00Jol806Ko00<0ool0L_l905Wo001[o`P0I_l00`3oo`1co`P0
FOl000Woo`2S00Go0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00;o2008o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol0103oool800Wo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`07o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`02o`T0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00_l800So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`03o`00
2Ol00`3oo`0ao`030?oo02_o2@0ao`030?oo037o00<0ool0<Ol00`3oo`0bo`030?oo00co200Mo`03
0?oo037o00<0ool00ol006_o2@1Uo`030?oo07Ko201Fo`00Jol806Ko00<0ool0M_l805Ko001Zo`T0
I_l00`3oo`1go`P0EOl006[o2@1Vo`030?oo07Oo201Eo`00J_l906Ko00<0ool0Mol905Co001Zo`T0
I_l00`3oo`1ho`P0E?l006[o201Wo`<0N?l905?o001Zo`P0Iol00`3oo`1io`P0Dol006[o201Wo`03
0?oo07Wo2@1Bo`00J_l806Oo00<0ool0N_l805;o001Zo`P0Iol00`3oo`1jo`P0D_l006[o201Wo`03
0?oo07_o201Ao`00J_l806Oo00<0ool0Nol8057o001Zo`P0Iol00`3oo`1ko`T0D?l006[o201Wo`03
0?oo07co201@o`00J_l806Oo00<0ool0O?l904oo001Zo`P0Iol00`3oo`1mo`P0Col006[o201Wo`<0
OOl804oo001Zo`P0Iol00`3oo`1no`P0C_l006[o201Wo`030?oo07ko201>o`00J_l806Oo00<0ool0
O_l904go001Zo`P0Iol00`3oo`1oo`P0COl006[o201Wo`030?oo07oo2@1<o`00J_l806Oo00<0ool0
P?l804co001Zo`P0Iol00`3oo`20o`T0Bol006[o201Wo`030?oo087o201;o`00J_l806Oo00<0ool0
POl804_o001Zo`P0Iol3087o201;o`00J_l806Oo00<0ool0P_l704_o001Zo`P0Iol00`3oo`22o`P0
B_l006[o201Wo`030?oo08;o201:o`00J_l906Ko00<0ool0Pol704[o001Zo`T0I_l00`3oo`23o`P0
BOl006[o2@1Vo`030?oo08?o2019o`00J_l906Ko00<0ool0Q?l704Wo001[o`T0IOl00`3oo`24o`P0
B?l006_o2@1Uo`030?oo08Co2018o`00Jol906Go00<0ool0Q?l804So001[o`P0I_l308Co2018o`00
Jol806Ko00<0ool0QOl804Oo001[o`P0I_l00`3oo`25o`P0Aol006_o201Vo`030?oo08Go2017o`00
Jol806Ko00<0ool0Q?l904Oo001[o`P0I_l00`3oo`25o`T0A_l006_o201Vo`030?oo08Go2@16o`00
Jol905[o1@06o`030?oo08Go2@16o`00K?l805co00<0ool01_l00`3oo`25o`T0A_l006co201Lo`03
0?oo00Ko00<0ool0QOl904Ko001/o`P0G?l00`3oo`06o`@0Q?l:04Go001/o`T0Fol00`3oo`06o`03
0?oo08Ko2016o`00KOl805_o00<0ool01_l00`3oo`26o`P0A_l006co2@1Ko`030?oo00Ko00<0ool0
Q_l804Ko001/o`T0FOl300So00<0ool0Q_l804Ko001]o`P0Fol00`3oo`06o`030?oo08Ko2016o`00
KOl906?o00<0ool0Q_l804Ko001^o`P0Hol00`3oo`26o`P0A_l006ko201So`030?oo08Ko2016o`00
K_l906;o00<0ool0Q_l804Ko001_o`P0H_l00`3oo`25o`T0A_l006oo2@1Qo`<0QOl:04Go001`o`P0
HOl00`3oo`24o``0A?l0073o201Qo`030?oo08?o3015o`00L?l9063o00<0ool0Q?l:04Ko001ao`P0
H?l00`3oo`25o`T0A_l0077o2@1Oo`030?oo08Go2@16o`00L_l805oo00<0ool0Q?l904Oo001bo`T0
G_l00`3oo`24o`T0Aol007;o2P1Mo`030?oo08Co2@17o`00Lol905go00<0ool0Pol804Wo001co`X0
G?l308?o2019o`00M?l:05_o00<0ool0Pol804Wo001do`X0Fol00`3oo`22o`T0BOl007Go2P1Jo`03
0?oo08;o201:o`00M_l:05Wo00<0ool0POl904[o001fo`/0F?l00`3oo`21o`P0Bol007Oo2`1Go`03
0?oo083o2@1;o`00Mol<05Ko00<0ool0O_l:04co001ho``0EOl00`3oo`1no`X0C?l007Wo301Do`03
0?oo07go2P1=o`00N_l<05?o0`1ko`d0C?l007_o3@1Ao`030?oo07co2`1=o`00Nol>053o00<0ool0
Nol;04ko001lo`l0C_l00`3oo`1io``0Col007ko3P1=o`030?oo07So2P1Bo`00Ool?04_o00<0ool0
M_l=057o0020oa40B?l00`3oo`1eo`d0D_l008?o4016o`030?oo07?o3@1Do`00Q?lB04?o00<0ool0
L_l>05Co0025oaD0?ol00`3oo`1`o`d0Eol008Oo5`0ko`030?oo06ko3P1Ho`00ROlJ03Ko0`1[o`l0
F_l008_o6`0co`030?oo06Wo401Ko`00S_lM02ko00<0ool0Iol@05go002@ob00:Ol00`3oo`1Soa@0
GOl009?o8@0Uo`030?oo05co6@1Oo`00UOlV01ko00<0ool0F_lI067o002Lob806ol00`3oo`1Coah0
Hol00:3o<P07o`030?oo04So0`06oad0I_l00:;o>P04o`<0=?l300Ko:@1Wo`00YOm202co<`1Zo`00
Z_nF073o002_ohh0Lol00;?oQ01io`00_Omg07co002nog00P_l00<SoI@23o`00e?m>08ko003Io`03
0?oo00Wo<02Ko`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3o
o`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`03
0?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.25137 .47387 m
.25101 .47755 L
.25069 .4815 L
.25045 .48492 L
.25026 .48864 L
.25016 .49091 L
.2501 .493 L
.25005 .49501 L
.25001 .49714 L
.24999 .49904 L
.24999 .50083 L
.25 .50279 L
.25003 .5049 L
.25008 .50708 L
.25014 .50911 L
.25033 .51371 L
.25057 .51777 L
.25089 .5221 L
.25168 .53038 L
.2526 .53788 L
.25546 .55525 L
.25958 .57399 L
.2694 .60758 L
.281 .63876 L
.2955 .67114 L
.31078 .6996 L
.32583 .72246 L
.34286 .74232 L
.35309 .75137 L
.36349 .7586 L
.37413 .76422 L
.38031 .76677 L
.38637 .76881 L
.39217 .7704 L
.39769 .7716 L
.40406 .77264 L
.40751 .77308 L
.41122 .77344 L
.41303 .77358 L
.41502 .77372 L
.41679 .77381 L
.41868 .77389 L
.4204 .77395 L
.42232 .77399 L
.42407 .774 L
.42574 .77401 L
.42783 .77399 L
.42985 .77395 L
.43167 .77389 L
.43368 .77382 L
Mistroke
.43825 .77357 L
.44258 .77325 L
.45078 .77245 L
.45846 .77147 L
.47659 .76847 L
.51734 .75902 L
.56653 .74427 L
.67283 .70401 L
.72558 .67965 L
.77113 .65495 L
.8115 .62793 L
.84167 .60094 L
.85387 .58613 L
.85916 .57818 L
.86389 .56963 L
.86714 .56237 L
.86995 .55428 L
.87092 .55071 L
.87178 .54684 L
.87243 .54318 L
.87288 .5398 L
.87309 .5377 L
.87324 .53571 L
.87333 .53391 L
.87339 .53197 L
.8734 .52984 L
.87339 .52877 L
.87336 .52759 L
.87326 .52549 L
.87313 .52353 L
.87294 .52155 L
.87273 .51967 L
.87222 .51613 L
.87152 .51231 L
.87057 .50813 L
.86793 .49923 L
.8642 .48969 L
.85521 .47234 L
.84423 .45587 L
.82985 .43795 L
.79805 .40539 L
.70857 .33434 L
.61636 .27519 L
.53716 .23434 L
.50239 .22131 L
.49316 .21867 L
.48475 .21663 L
.47751 .2152 L
.47375 .21459 L
.46979 .21405 L
Mistroke
.46602 .21363 L
.46263 .21335 L
.46102 .21325 L
.45927 .21316 L
.45763 .2131 L
.45613 .21306 L
.45525 .21305 L
.4543 .21305 L
.45259 .21305 L
.45094 .21309 L
.44943 .21314 L
.44781 .21322 L
.44604 .21333 L
.44252 .21365 L
.43944 .21403 L
.43668 .21445 L
.43058 .21566 L
.42506 .21711 L
.41994 .21877 L
.40884 .22344 L
.39747 .2298 L
.37779 .24453 L
.33908 .28564 L
.3006 .34049 L
.28503 .36807 L
.27055 .39931 L
.25961 .43114 L
.2553 .44878 L
.25242 .46533 L
.25137 .47387 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co0030o`805ol30=Co002oo`@01_l200ko
00<0ool0e?l00;co4`0:o`030?oo0=Co002hoa`01Ol00`3oo`3Do`00^?lN00?o00<0ool0e?l00;Go
9@3Fo`00/ol/0=7o002aobh0dOl00:ko=03>o`00[?lh0<co002Yoa/01OlP0<Oo002Yoa801?l2017o
6@35o`00Z?lA01co6@32o`00YOlA02?o5P31o`00Y?l@02Go00@0oooo502oo`00Xol>02So00<0ool0
1?lC0;go002Ro`h0:Ol00`3oo`06oa<0^ol00:3o3P0Oo`D01ol00`3oo`09oa80^Ol00:7o300Po`05
0?ooo`001ol00`3oo`0<oa40]ol00:3o2`0So`030?oo00So00<0ool03_lA0;Go002Oo`/09Ol00`3o
o`07o`030?oo013o4@2co`00W_l:01go1P05o`030?oo00Ko100Aoa40/Ol009go2P0Yo`030?oo00Ko
00<0ool05?lA0:oo002Lo`/0:_l00`3oo`05o`030?oo01Ko4@2]o`00Vol;02Oo00D0oooo0007o`03
0?oo01So4@2[o`00V_l;02Wo0`08o`030?oo01[o4@2Yo`00VOl;03Go00<0ool07?lA0:Oo002Ho`/0
=_l00`3oo`0Noa40YOl009Oo2`0go`030?oo023o4@2So`00U_l;03So00<0ool08_lA0:7o002Fo`X0
>Ol00`3oo`0To`l0XOl009Co2`0jo`<09_l>0:3o002Do`X0>ol00`3oo`0Xo`h0W_l009?o2P0lo`03
0?oo02[o3@2Mo`00T_l:03go00<0ool0;?l=09_o002Ao`/0?Ol00`3oo`0]o`d0V_l0093o2`0no`03
0?oo02oo3@2Ho`00T?l:03oo00<0ool0<?l=09Oo002?o`X0@?l00`3oo`0bo`d0UOl008oo2@11o`03
0?oo03?o3@2Do`00S_l:047o00<0ool0=Ol=09;o002=o`X0@_l303Ko3P2@o`00SOl904?o00<0ool0
>?l=08oo002<o`T0A?l00`3oo`0io`h0SOl008_o2P14o`030?oo03_o3@2<o`00Rol904Go00<0ool0
??l>08[o002:o`T0A_l00`3oo`0no`d0ROl008Wo2P16o`030?oo043o3@27o`00ROl904Oo00<0ool0
@Ol=08Ko0028o`T0B?l00`3oo`13o`d0Q?l008Oo2P18o`030?oo04Co3@23o`00Qol904Wo00<0ool0
A_l=087o0026o`T0B_l304Oo3@20o`00QOl:04[o00<0ool0BOl=07ko0024o`X0Bol00`3oo`1:o`d0
OOl008?o2P1<o`030?oo04co3@1ko`00Pol:04co00<0ool0COl=07[o0022o`X0COl00`3oo`1>o`d0
NOl008;o2@1>o`030?oo04oo3@1ho`00POl904oo00<0ool0DOl=07Ko0021o`T0Col00`3oo`1Bo`d0
MOl0083o2@1@o`030?oo05?o3@1do`00P?l8057o0`1Eo`d0L_l007oo2@1Ao`030?oo05Ko3@1ao`00
Ool805;o00<0ool0Eol>06oo001no`T0D_l00`3oo`1Io`d0K_l007ko201Co`030?oo05[o3@1]o`00
OOl905?o00<0ool0Fol>06_o001mo`P0E?l00`3oo`1Mo`d0J_l007co2@19o`D01_l00`3oo`1No`d0
JOl007co201<o`030?oo00Ko00<0ool0H?l=06Oo001ko`T0C?l00`3oo`06o`030?oo067o3@1Vo`00
Nol804go00<0ool01_l00`3oo`1Ro`d0IOl007[o2@12o`H01Ol00`3oo`06o`@0Hol=06?o001jo`P0
C_l00`3oo`06o`030?oo06Go3@1Ro`00NOl804oo00<0ool01_l00`3oo`1Vo`h0H?l007So2@1=o`<0
2?l00`3oo`1Xo`d0Gol007So201@o`030?oo00Ko00<0ool0JOl=05ko001go`T0FOl00`3oo`1Zo`h0
G?l007Oo201Jo`030?oo06co3@1Ko`00M_l805_o00<0ool0KOl=05[o001fo`P0Fol00`3oo`1_o`d0
F?l007Go201Lo`030?oo073o3@1Go`00MOl805co0`1ao`d0E_l007Co2@1Lo`030?oo07?o3@1Do`00
MOl705go00<0ool0M?l;05Go001do`P0GOl00`3oo`1eo`/0E?l007Co201Mo`030?oo07Ko2`1Co`00
M?l705ko00<0ool0Mol;05;o001co`P0G_l00`3oo`1ho`/0DOl007?o201No`030?oo07Wo2`1@o`00
Lol705oo00<0ool0N_l;04oo001bo`P0Gol00`3oo`1ko`/0C_l007;o201Oo`030?oo07co2`1=o`00
L_l805oo0`1mo``0Bol0077o2@1Oo`030?oo07ko2`1;o`00LOl8063o00<0ool0Ool;04[o001ao`P0
H?l00`3oo`20o`/0BOl0073o2@1Po`030?oo087o2`18o`00L?l9063o00<0ool0P_l;04Oo001ao`L0
HOl00`3oo`23o`X0Aol0073o201Qo`030?oo08Co2@17o`00L?l8067o00<0ool0QOl904Ko001_o`T0
HOl00`3oo`25o`X0AOl006oo201Ro`<0Q_l:04Co001_o`P0H_l00`3oo`27o`T0A?l006oo201Ro`03
0?oo08Oo2P13o`00Kol806;o00<0ool0R?l:04;o000=o`<0;ol302co2@0`o`D0;Ol00`3oo`0_o`D0
;ol5027o2P05o`<0<ol300?o000>o`030?oo02go00D0oooo000[o`T0<_l00`3oo`0]o`030?oo037o
00<0ool0;ol01@3oool0027o2`03o`050?ooo`00<ol00`3oo`02o`003_l00`3oo`0ao`030?oo02Wo
200co`030?oo02go00<0ool0<Ol00`3oo`0`o`030?oo02?o2`06o`030?oo037o00<0ool00_l000[o
1P0bo`030?oo02So2@0co`030?oo02go00<0ool0<Ol00`3oo`0ao`030?oo02?o2P06o`030?oo02go
1P03o`000_l600?o00@0ool09ol600Co0P0Xo``0:?l600Go00<0ool0;Ol00`3oo`0ao`030?oo03;o
00<0ool08_l;00?o0P0ao`040?oo00Co000;o`040?oo03?o00<0ool0:?l903?o00<0ool0;Ol00`3o
o`0ao`030?oo03;o00<0ool09?l:00Co00<0ool0;_l0103oo`04o`003?l00`3o000co`030?oo02So
20000ol0o`0ao`030?oo02go00<0ool0<Ol00`3oo`0co`030?oo02Co2P03o`030?oo02oo00<0o`00
1?l000co00<0o`00;ol01@3oool002[o20000ol0o`0_o`<0;ol302oo0`0ao`050?ooo`009ol900?o
00<0ool0;ol00`3o0004o`003Ol2033o0`0Zo`X0<ol00`3oo`0]o`030?oo037o00<0ool0<?l302So
20001?l0000co`801?l006co2@1To`030?oo08oo2@0lo`00KOl806Co00<0ool0T?l803co001]o`P0
I?l00`3oo`2@o`P0??l006go201To`030?oo097o200ko`00KOl806Co00<0ool0TOl803_o001]o`P0
I?l00`3oo`2Ao`T0>_l006go201To`030?oo09;o200jo`00KOl806Co00<0ool0T_l803[o0009ool0
X`05o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool01ol00`3oo`04o`P01_l00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo
00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00@0oooo2@08o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool01?l800Ko00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`03
0?oo00;o2008o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool00ol000Wo00<0ool0
<Ol00`3oo`0]o`P0<?l00`3oo`0ao`030?oo037o00<0ool0<_l00`3oo`0Zo`T0<_l00`3oo`03o`00
KOl806Co00<0ool0U?l903Oo001]o`P0I?l00`3oo`2Do`T0=ol006go201To`030?oo09Co2@0go`00
KOl806Co00<0ool0U?l903Oo001]o`P0I?l00`3oo`2Do`T0=ol006go201To`030?oo09Co2P0fo`00
KOl906?o0`2Eo`P0=ol006go2@1So`030?oo09Go200go`00KOl906?o00<0ool0UOl803Oo001]o`T0
Hol00`3oo`2Eo`P0=ol006go2P1Ro`030?oo09Go200go`00KOl:06;o00<0ool0UOl803Oo001^o`T0
H_l00`3oo`2Eo`T0=_l006ko201So`030?oo09Co2P0fo`00K_l806?o00<0ool0U?l903Oo001^o`T0
H_l00`3oo`2Do`T0=ol006ko2@1Ro`030?oo09Co2@0go`00Kol806;o0`2Co`X0=ol006oo201Ro`03
0?oo09?o2P0go`00Kol806;o00<0ool0U?l803So001_o`T0HOl00`3oo`2Do`P0>?l0073o201Qo`03
0?oo09?o2@0ho`00L?l8067o00<0ool0T_l:03So001ao`L0HOl00`3oo`2Bo`X0>?l0073o2@1Po`03
0?oo097o2@0jo`00L?l9063o00<0ool0TOl903[o001ao`P0H?l00`3oo`2@o`T0>ol0077o201Po`<0
T?l803co001ao`T0Gol00`3oo`2?o`T0??l007;o201Oo`030?oo08ko2@0mo`00L_l805oo00<0ool0
S_l903go001bo`P0Gol00`3oo`2=o`X0?Ol007?o1`1Oo`030?oo08co2P0no`00Lol805ko00<0ool0
Rol:03oo001co`P0G_l00`3oo`2:o`X0@?l007Co1`1No`030?oo08Wo2`10o`00M?l705ko00<0ool0
R?l;047o001do`P0GOl00`3oo`27o`/0@_l007Co201Mo`<0Q_l<04;o001do`P0GOl00`3oo`25o``0
@ol007Co2@1Lo`030?oo08Co3014o`00MOl805co00<0ool0P_l=04Go001eo`P0G?l00`3oo`21o`d0
A_l007Ko201Ko`030?oo083o3@17o`00M_l805_o00<0ool0Ool<04Wo001fo`T0Col500Ko00<0ool0
O_l<04[o001go`P0DOl00`3oo`06o`030?oo07go301;o`00Mol8057o00<0ool01_l00`3oo`1ko``0
COl007So201@o`030?oo00Ko101io``0C_l007So201@o`030?oo00Ko00<0ool0NOl<04oo001ho`T0
Col00`3oo`06o`030?oo07Oo3P1?o`00NOl804oo00<0ool01_l00`3oo`1fo`h0D?l007Wo201=o`<0
2?l00`3oo`1do`h0D_l007Wo2@1>o`030?oo00Ko00<0ool0Lol>05?o001jo`P0Eol00`3oo`1ao`h0
EOl007[o2@1Fo`030?oo073o3P1Fo`00Nol805Ko00<0ool0K_l>05So001ko`T0EOl00`3oo`1]o`h0
FOl007co201Eo`030?oo06_o3P1Ko`00O?l905Co0`1Zo`h0G?l007go201Do`030?oo06So3P1No`00
OOl805Co00<0ool0I_l?05oo001no`P0Dol00`3oo`1To`l0HOl007ko201Co`030?oo06;o4P1Po`00
O_l905;o00<0ool0H?lB06;o001oo`P0D_l00`3oo`1Noa80I?l007oo2@1Ao`030?oo05co4P1Vo`00
P?l8057o00<0ool0F_lB06So0020o`T0D?l00`3oo`1Hoa80J_l0087o201@o`<0EOlC06co0021o`P0
D?l00`3oo`1Eoa40K_l008;o201?o`030?oo05;o4P1`o`00Pol704oo00<0ool0D?lB07;o0023o`P0
C_l00`3oo`1>oa80M?l008Co1`1>o`030?oo04co4P1fo`00Q?l804go00<0ool0B_lB07So0025o`L0
COl00`3oo`17oa<0N_l008Go201<o`030?oo04Go4`1lo`00QOl904_o00<0ool0@olB07oo0026o`P0
Bol3043o4`21o`00Q_l904[o00<0ool0?_lC08?o0027o`T0BOl00`3oo`0koa@0QOl008So2@18o`03
0?oo03So5@27o`00R?l904So00<0ool0=_lD08[o0029o`T0Aol00`3oo`0coaD0S?l008[o2@16o`03
0?oo037o5@2>o`00Rol904Go00<0ool0;_lE097o002;o`X0A?l00`3oo`0/oaD0Tol008_o2`13o`03
0?oo02Wo5@2Fo`00S?l;04;o00<0ool09olD09Wo002=o`/0@Ol302Co5@2Ko`00S_l:047o00<0ool0
8_lD09ko002?o`X0@?l00`3oo`0OoaD0X?l008oo2`0oo`030?oo01co5@2So`00TOl:03ko00<0ool0
6_lE0:Go002Bo`X0?Ol00`3oo`0GoaD0Z?l009;o2`0lo`030?oo01?o5`2Zo`00T_l<02oo1@07o`03
0?oo013o5`2]o`00Tol<02ko00D0oooo0007o`030?oo00go602_o`00U?l<02ko00<0ool02?l00`3o
o`0:oaP0/_l009Go300^o`030?oo00Oo1006oaP0]Ol009Ko3@0]o`030?oo00Ko00<0ool00olJ0;Oo
002Fo`l0:ol00`3oo`06o`030?l001X0^_l009Oo400Zo`030?oo00;o6`2oo`00VOlA02?o00<0o`00
7P32o`00V_lB0003o`0001[o8P35o`00VolH017o9038o`00WOm80<_o002Ood<0c_l00:;o>`3Co`00
Y?ld0003o`3o0=Go002Vobd01_l30=Co002XobP02Ol00`3oo`3Do`00Z?lS00ko00<0ool0e?l00:go
700@o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003>o`<02?l00`3o
o`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`03
0?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00
cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=3o
0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl600Ko
00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`030?l00=ko003?o`030?l00=ko
003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.26224 .57725 m
.27363 .60615 L
.2894 .63523 L
.33309 .69208 L
.37914 .73644 L
.40538 .75719 L
.42903 .77272 L
.4407 .77903 L
.45332 .78464 L
.45911 .78675 L
.46526 .78865 L
.47093 .79008 L
.47635 .79115 L
.47924 .7916 L
.4824 .792 L
.48379 .79214 L
.48528 .79227 L
.48668 .79237 L
.48797 .79245 L
.48961 .79252 L
.49048 .79254 L
.49139 .79256 L
.49293 .79258 L
.49381 .79257 L
.49463 .79256 L
.49616 .79253 L
.49757 .79247 L
.49919 .79239 L
.50074 .79228 L
.50356 .79202 L
.50659 .79165 L
.51208 .79076 L
.51808 .78947 L
.52483 .78763 L
.53887 .78257 L
.55232 .77635 L
.58491 .75677 L
.6558 .69999 L
.73072 .62693 L
.7712 .58187 L
.80426 .54023 L
.83266 .4972 L
.84244 .47891 L
.85097 .45938 L
.85404 .45067 L
.85673 .44149 L
.85793 .43651 L
.85885 .43201 L
.85956 .42779 L
.86015 .42335 L
Mistroke
.86041 .42086 L
.86059 .41862 L
.86072 .41639 L
.8608 .4143 L
.86083 .41312 L
.86084 .41188 L
.86083 .40967 L
.8608 .40844 L
.86076 .4073 L
.8607 .40606 L
.86061 .40473 L
.86043 .40253 L
.86017 .40015 L
.85955 .39589 L
.85874 .3918 L
.85782 .38808 L
.85548 .38078 L
.85221 .37316 L
.84434 .36004 L
.83864 .35281 L
.83177 .34551 L
.81733 .33322 L
.80079 .32217 L
.78066 .31133 L
.73884 .29409 L
.68348 .27742 L
.62767 .26472 L
.57163 .25481 L
.52184 .24808 L
.49693 .2455 L
.47471 .24373 L
.46247 .243 L
.45165 .24253 L
.44581 .24235 L
.44256 .24227 L
.43958 .24222 L
.43701 .24219 L
.43556 .24217 L
.4342 .24216 L
.43148 .24216 L
.42996 .24216 L
.42858 .24217 L
.42595 .24219 L
.42349 .24222 L
.4213 .24226 L
.41895 .24232 L
.41376 .2425 L
.40906 .24272 L
.40075 .24326 L
.3923 .24404 L
Mistroke
.38354 .24513 L
.37572 .24639 L
.36762 .24802 L
.35926 .25013 L
.34518 .2549 L
.33324 .26053 L
.32284 .26707 L
.31419 .27406 L
.30502 .2835 L
.29735 .29351 L
.28509 .31497 L
.27422 .34177 L
.26592 .36919 L
.25895 .39921 L
.25567 .41711 L
.25319 .4337 L
.25217 .44185 L
.25122 .45075 L
.25054 .45846 L
.24995 .46698 L
.24969 .47162 L
.24951 .47598 L
.24943 .47822 L
.24936 .48058 L
.24933 .48182 L
.24931 .48316 L
.24929 .48438 L
.24927 .48553 L
.24925 .48778 L
.24924 .48982 L
.24925 .49201 L
.24926 .49325 L
.24927 .49439 L
.2493 .49629 L
.24935 .49838 L
.24941 .50056 L
.24948 .50259 L
.24967 .50696 L
.2499 .511 L
.25061 .5201 L
.25147 .52808 L
.25262 .5365 L
.25554 .55239 L
.25901 .56652 L
.26224 .57725 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00]Ol200[o0P0Fo`030?oo0=Co002]o`800_lF01;o00<0ool0e?l00:Ko=`3Co`00XOm60<Wo
002NodX0b?l009WoE@32o`00VOmJ0004o`000;Wo002GofD0]?l009CoK@2_o`00T_lU00[oAP2Yo`00
S_lO02Co00<0ool0>02To`00SOlF02[o00D0oooo0007o`030?oo00Go<P2Mo`00S?lC02oo0`08o`03
0?oo00_o;@2Lo`00RolA03go00<0ool04Ol/09Oo002:oa00?ol00`3oo`0Fob`0T_l008Wo3P12o`03
0?oo01oo:P2;o`00R?l=04Co00<0ool09?lZ08Ko0026o`d0A_l00`3oo`0ZobD0QOl008Ko3017o`<0
;olS08;o0025o``0B?l00`3oo`0goah0Ool008Co3019o`030?oo03co7@1ko`00Pol<04[o00<0ool0
@OlK07So0022o``0Bol00`3oo`16oa/0Lol008;o2`1<o`030?oo04[o6@1ao`00P_l:04go00<0ool0
COlI06ko0021o`X0C_l00`3oo`1@oaP0K?l0087o2@1?o`030?oo05?o5`1Zo`00P?l9053o00<0ool0
EolF06Oo0020o`T0D?l305[o5@1Uo`00Ool9057o00<0ool0GOlE06;o001no`T0D_l00`3oo`1Poa@0
H?l007ko2@1Bo`030?oo06?o501Mo`00OOl905?o00<0ool0IOlC05co001mo`P0E?l00`3oo`1Woa<0
F_l007co2@1Do`030?oo06[o4@1Io`00O?l805Go00<0ool0K?lA05Oo001ko`T0EOl00`3oo`1_oa00
EOl007_o201Fo`030?oo077o4@1Bo`00N_l905Ko00<0ool0M?l?057o001jo`P0Eol307Ko3P1@o`00
N_l805Oo00<0ool0Mol?04ko001io`P0F?l00`3oo`1io`l0C?l007Wo201Ho`030?oo07_o3`1:o`00
N?l905So00<0ool0OOl=04[o001ho`P0FOl00`3oo`1no`d0BOl007Oo2@1Io`030?oo07oo3@18o`00
Mol805[o00<0ool0POl<04Oo001fo`T0F_l00`3oo`22o``0A_l007Ko201Ko`030?oo08?o2P17o`00
M_l805_o0`24o`X0A_l007Ko201Ko`030?oo08Go2P15o`00M_l705co00<0ool0Q_l904Go001fo`L0
G?l00`3oo`27o`T0A?l007Go201Lo`030?oo08Oo2P13o`00MOl805co00<0ool0R?l904?o001do`P0
GOl00`3oo`29o`T0@_l007Co201Bo`D01_l00`3oo`29o`T0@_l007Co201Do`030?oo00Ko00<0ool0
Rol8047o001do`L0EOl00`3oo`06o`030?oo08_o2@10o`00Lol805Go00<0ool01_l00`3oo`2<o`T0
?ol007?o201:o`H01Ol00`3oo`06o`@0Rol903oo001co`P0EOl00`3oo`06o`030?oo08go2@0no`00
Lol705Ko00<0ool01_l00`3oo`2>o`T0?Ol007?o1`1Do`<02?l00`3oo`2>o`T0?Ol007?o1`1Fo`03
0?oo00Ko00<0ool0Sol803go001co`L0Gol00`3oo`2?o`P0?Ol007;o201Oo`030?oo08oo200mo`00
L_l805oo00<0ool0Sol903co001bo`P0Gol00`3oo`2>o`X0??l007;o1`1Po`030?oo08go300ko`00
LOl8063o0`2>o``0>_l0077o201Po`030?oo08oo2P0ko`00LOl8063o00<0ool0Sol903co001`o`P0
HOl00`3oo`2?o`T0??l0073o201Qo`030?oo093o200lo`00L?l8067o00<0ool0T?l803co001_o`T0
HOl00`3oo`2@o`P0??l006oo201Ro`030?oo093o200lo`00Kol806;o00<0ool0T?l903_o001^o`T0
H_l00`3oo`2?o`X0>ol006ko2@1Ro`030?oo08oo2@0lo`00K_l906;o0`2?o`T0??l006ko201So`03
0?oo08oo2@0lo`00K_l806?o00<0ool0S_l:03co001^o`P0Hol00`3oo`2>o`X0??l006go2P1Ro`03
0?oo08oo200mo`00KOl:06;o00<0ool0Sol803go001]o`T0Hol00`3oo`2>o`T0?Ol006go2@1So`03
0?oo08ko2@0mo`00KOl906?o00<0ool0S_l903go001]o`T0Hol00`3oo`2=o`T0?_l006go2@1So`<0
SOl803oo001]o`T0Hol00`3oo`2=o`P0?ol006co2@1To`030?oo08co2@0oo`00K?l906Co00<0ool0
S?l903oo000=o`<0;ol302_o2P0`o`D0;Ol00`3oo`0_o`D0;ol502Co2004o`<0<ol300?o000>o`03
0?oo02go00D0oooo000Zo`P000?o0?l0<Ol00`3oo`0]o`030?oo037o00<0ool0;ol01@3oool002?o
2@03o`050?ooo`00<ol00`3oo`02o`003_l00`3oo`0ao`030?oo02So200do`030?oo02go00<0ool0
<Ol00`3oo`0`o`030?oo02Co2@07o`030?oo037o00<0ool00_l000[o1P0bo`030?oo02So200do`03
0?oo02go00<0ool0<Ol00`3oo`0ao`030?oo02;o2P07o`030?oo02go1P03o`000_l600?o00@0ool0
9ol600Co0P0Xo``0:?l600Go00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0ool08Ol900Ko0P0ao`04
0?oo00Co000;o`040?oo03?o00<0ool0:?l903?o00<0ool0;Ol00`3oo`0ao`030?oo03;o00<0ool0
8?l900Wo00<0ool0;_l0103oo`04o`003?l00`3o000co`030?oo02So20000ol0o`0ao`030?oo02go
00<0ool0<Ol00`3oo`0co`030?oo01oo200:o`030?oo02oo00<0o`001?l000co00<0o`00;ol01@3o
ool002[o20000ol0o`0_o`<0;ol302oo0`0ao`050?ooo`008?l900Ko00D0oooo000ao`030?l000Co
000=o`80<?l302_o2@0co`030?oo02go00<0ool0<Ol00`3oo`0`o`<08Ol800So0`0co`801?l006go
201To`030?oo08Oo2@14o`00KOl806Co00<0ool0Qol804Go001]o`P0I?l00`3oo`26o`T0AOl006go
201To`030?oo08Ko2016o`00KOl806Co00<0ool0QOl904Ko001]o`P0I?l00`3oo`25o`P0Aol006go
201To`030?oo08Co2@17o`00KOl806Co00<0ool0Q?l804So0009ool0X`05o`002Ol00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1ol00`3oo`04o`P01_l00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`04o`T01?l00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`03o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`04o`P01_l00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`04o`T01?l00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`0ao`030?oo02go200`o`03
0?oo037o00<0ool0<Ol00`3oo`0bo`030?oo01So2@0@o`030?oo037o00<0ool00ol006go201To`03
0?oo083o2@1;o`00KOl806Co00<0ool0P?l804co001]o`P0I?l00`3oo`1oo`T0C?l006go201To`03
0?oo07ko2@1=o`00KOl806Co00<0ool0O_l804ko001/o`T0I?l00`3oo`1mo`T0C_l006co2@1To`<0
O?l904oo001]o`P0I?l00`3oo`1lo`P0D?l006go201To`030?oo07_o2@1@o`00KOl806Co00<0ool0
N_l9057o001]o`T0Hol00`3oo`1jo`P0D_l006go2@1So`030?oo07Wo2@1Bo`00KOl906?o00<0ool0
N?l:05;o001^o`T0H_l00`3oo`1go`X0Dol006ko2@1Ro`030?oo07Ko2P1Do`00K_l906;o00<0ool0
MOl;05Co001^o`T0H_l00`3oo`1eo`X0EOl006oo201Ro`<0M?l:05Ko001_o`P0H_l00`3oo`1co`X0
Eol006oo2@1Qo`030?oo07;o2P1Ho`00L?l8067o00<0ool0LOl:05Wo001`o`T0H?l00`3oo`1`o`/0
FOl0077o201Po`030?oo073o2P1Jo`00LOl8063o00<0ool0Kol:05_o001ao`P0H?l00`3oo`1^o`X0
G?l007;o201Oo`030?oo06go2P1Mo`00LOl905oo00<0ool0K?l:05ko001ao`T0Gol306_o2`1No`00
L_l805oo00<0ool0Jol:05oo001bo`T0G_l00`3oo`1Zo`X0H?l007?o201No`030?oo06Wo2P1Qo`00
Lol805ko00<0ool0J?l:06;o001do`P0GOl00`3oo`1Wo`X0Hol007Co201Mo`030?oo06Ko2`1So`00
M?l905co00<0ool0I_l:06Co001eo`P0G?l00`3oo`1Uo`X0IOl007Go201Lo`030?oo06Co2P1Vo`00
M_l805_o00<0ool0Hol:06Oo001fo`P0Fol306;o2P1Xo`00M_l905[o00<0ool0HOl;06So001go`P0
F_l00`3oo`1Po`/0JOl007Oo2@1Io`030?oo063o2P1Zo`00N?l805Wo00<0ool0Gol:06_o001ho`P0
FOl00`3oo`1No`X0K?l007Wo201Ho`030?oo05go2P1]o`00N_l704go1@06o`030?oo05co2P1^o`00
N_l804ko00<0ool01_l00`3oo`1Ko`/0K_l007_o201=o`030?oo00Ko00<0ool0F_l;06oo001ko`T0
C?l00`3oo`06o`@0F?l;073o001lo`P0C?l00`3oo`06o`030?oo05So2`1ao`00O?l904_o00<0ool0
1_l00`3oo`1Go`/0L_l007co2P1:o`030?oo00Ko00<0ool0E_l;07?o001mo`X0Aol300So00<0ool0
EOl<07?o001no`T0BOl00`3oo`06o`030?oo05Co301do`00O_l:057o00<0ool0Dol<07Go001oo`X0
D?l00`3oo`1Bo`/0Mol007oo2`1?o`030?oo057o2`1ho`00POl:04ko00<0ool0D?l;07Wo0021o`X0
C_l00`3oo`1?o`/0N_l008;o2P1=o`<0C_l;07_o0023o`X0C?l00`3oo`1=o`/0O?l008Co2P1;o`03
0?oo04co2`1mo`00QOl904_o00<0ool0B_l<07ko0025o`X0B_l00`3oo`19o``0Ool008Ko2P19o`03
0?oo04So3020o`00Qol:04So00<0ool0Aol<087o0028o`T0B?l00`3oo`16o``0P_l008So2P17o`03
0?oo04Go3023o`00ROl:04Ko00<0ool0A?l;08Go002:o`X0AOl304?o2`26o`00Rol:04Co00<0ool0
@_l;08Oo002;o`X0A?l00`3oo`11o`/0R?l008co2P13o`030?oo043o2`29o`00SOl:04;o00<0ool0
?ol;08[o002>o`X0@Ol00`3oo`0no`/0Rol008oo2P10o`030?oo03go2`2<o`00S_l<03oo00<0ool0
>ol<08go002?o``0?_l00`3oo`0jo``0S_l0093o300mo`030?oo03Wo302?o`00TOl<03co0`0ho``0
T?l009;o300ko`030?oo03Oo302Ao`00Tol<03[o00<0ool0=Ol=09;o002Do``0>Ol00`3oo`0do`d0
Tol009Go300ho`030?oo03?o3@2Do`00U_l<03Oo00<0ool0<_l=09Go002Go``0=_l00`3oo`0ao``0
Uol009So300eo`030?oo02oo3@2Ho`00VOl<03Co00<0ool0;_l<09[o002Jo``0<ol00`3oo`0]o``0
Vol009_o300bo`030?oo02co302Lo`00W?l<037o0`0[o``0WOl009go300`o`030?oo02Wo3@2No`00
W_l<02oo00<0ool0:?l<0:3o002Oo``0;_l00`3oo`0Wo``0XOl00:3o300]o`030?oo02Ko302Ro`00
XOl<02co00<0ool09Ol<0:?o002Ro``0:ol00`3oo`0So`d0Y?l00:?o3@0Mo`D01ol00`3oo`0Ro``0
Y_l00:Co3@0Lo`050?ooo`001ol00`3oo`0Qo``0Yol00:Go3P0Ko`030?oo00So00<0ool08?l<0:So
002Vo`h06ol00`3oo`07o`@07_l<0:Wo002Yo``06ol00`3oo`06o`030?oo01go3@2Zo`00Z_l=01Wo
00<0ool01_l00`3oo`0Lo``0[?l00:co300Io`030?oo00Go00<0ool06ol<0:go002]o`d04ol01@3o
ool000Oo00<0ool06Ol>0:go002^o`d04ol300So00<0ool05ol?0:ko002`o``07Ol00`3oo`0Eo`l0
/?l00;7o3@0Ko`030?oo01?o3`2bo`00/ol=01Wo00<0ool04Ol@0;?o002do`h05ol00`3oo`0?oa00
]Ol00;Ko3`0Do`030?oo00go402go`00]ol?01?o0`0;oa00^Ol00;Oo4@0Ao`030?oo00So4@2ko`00
^OlD00co00<0ool00_l200;o4P2lo`00^olF00So6@2no`00_Olc0<3o002oobl0`_l00<7o:`34o`00
`olW0<Ko0035ob80bOl00<Oo7P3;o`00aolN0<_o003;oaD0d?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003>o`<02?l00`3oo`3Do`00
cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co
003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl01@3o
ool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=3o0`06o`03
0?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl600Ko00<0ool0
e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`030?l00=ko003?o`030?l00=ko003@o`80
g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.31421 .66728 m
.33638 .68904 L
.36261 .7092 L
.39429 .72827 L
.42565 .74336 L
.48575 .76516 L
.50198 .76964 L
.51698 .77319 L
.53002 .77573 L
.53727 .77688 L
.54396 .77777 L
.55048 .77844 L
.5541 .77873 L
.55737 .77893 L
.55914 .77902 L
.56078 .77908 L
.56257 .77913 L
.56356 .77915 L
.56446 .77916 L
.56611 .77917 L
.56703 .77917 L
.56788 .77916 L
.56943 .77914 L
.57107 .7791 L
.57256 .77904 L
.57392 .77898 L
.57695 .77878 L
.57973 .77855 L
.58235 .77826 L
.58812 .77744 L
.59429 .77621 L
.60012 .7747 L
.6055 .77296 L
.61746 .76781 L
.62874 .7611 L
.64059 .75186 L
.66182 .72915 L
.68388 .69698 L
.72396 .61869 L
.76496 .51476 L
.78122 .46392 L
.79499 .40985 L
.79776 .39598 L
.80022 .38162 L
.80203 .36864 L
.80273 .36243 L
.80328 .35683 L
.80369 .35166 L
.80404 .34611 L
.80419 .3431 L
Mistroke
.80429 .34033 L
.80437 .33771 L
.80441 .33495 L
.80443 .33337 L
.80443 .33194 L
.80442 .33036 L
.8044 .32872 L
.80434 .32596 L
.8043 .32442 L
.80424 .32298 L
.80397 .31791 L
.80376 .31512 L
.80353 .3126 L
.80234 .30306 L
.80155 .29841 L
.80052 .29342 L
.79829 .28495 L
.79573 .27742 L
.79212 .2691 L
.78824 .26198 L
.78338 .25479 L
.77748 .24777 L
.77134 .24187 L
.76521 .23701 L
.75174 .22889 L
.74335 .22512 L
.73359 .22166 L
.72377 .21897 L
.71422 .21697 L
.70448 .21546 L
.69883 .21479 L
.69356 .21429 L
.68857 .21392 L
.6859 .21376 L
.68303 .21362 L
.68052 .21352 L
.67772 .21343 L
.67515 .21337 L
.67272 .21333 L
.66985 .21331 L
.66669 .21331 L
.66508 .21332 L
.66336 .21334 L
.66023 .2134 L
.65708 .21348 L
.65409 .21358 L
.64843 .21383 L
.64166 .21423 L
.63534 .21468 L
.62079 .21601 L
Mistroke
.59484 .21927 L
.56995 .22326 L
.51243 .23508 L
.40921 .26362 L
.36327 .27969 L
.32046 .2979 L
.28748 .3161 L
.26404 .33402 L
.25392 .34452 L
.24614 .35487 L
.24051 .3646 L
.23789 .37024 L
.23576 .37564 L
.23233 .38704 L
.23098 .39331 L
.22985 .40021 L
.22941 .40375 L
.22902 .40764 L
.22874 .41137 L
.22863 .41317 L
.22854 .41486 L
.22847 .41652 L
.22842 .41804 L
.22838 .41974 L
.22836 .42064 L
.22834 .42158 L
.22833 .42337 L
.22833 .42504 L
.22834 .42689 L
.22836 .42793 L
.22837 .42887 L
.22841 .43058 L
.22846 .43218 L
.22861 .43586 L
.2288 .43947 L
.22907 .44339 L
.23039 .45724 L
.23147 .46583 L
.23269 .47411 L
.23545 .4899 L
.2427 .52221 L
.25144 .55236 L
.26363 .5854 L
.27713 .61392 L
.29343 .64085 L
.31421 .66728 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0B_l208So003Io`030?oo03oo
0P08o`@0Qol00=Wo00<0ool0>_lE0004o`00087o003Io`030?oo02co:`1mo`00fOl00`3oo`0Yoc<0
N?l00=Wo00<0ool05_m:07Co003Io`030?oo01KoCP1`o`00fOl00`3oo`0Eoe<0K?l00=Wo00<0ool0
4?mH06co003Io`030?oo00[oGP1/o`00fOl300?o?009ob80J_l00=Wo;@0Qo`803?lC06So003Hobh0
<olA06Ko003Eob80A_l@06?o003Aob40Bol@06?o003>oal0D_l?06;o003:oad0F_l?063o0037oa/0
HOl=063o0034oaT0J?l<05oo0030oaX0KOl;05ko002moaX00_l00`3oo`1[o``0GOl00;Wo6P06o`@0
Jol<05co002doad02?l00`3oo`1]o``0Fol00;7o6`05o`030?oo00Go00<0ool0K_l<05[o002^oa/0
1?l01@3oool000Oo00<0ool0Kol:05_o002/oaX02?l300So00<0ool0L?l:05[o002YoaT05ol00`3o
o`1ao`T0F_l00:Oo600Jo`030?oo07;o2@1Io`00Y?lG01ko00<0ool0L_l905Wo002PoaP08Ol00`3o
o`1co`T0F?l009ko5`0To`030?oo07?o2@1Ho`00VolF02So0`1do`T0Eol009[o500[o`030?oo07Co
2P1Fo`00UolD02ko00<0ool0MOl905Ko002Eoa@0<?l00`3oo`1fo`P0E_l009?o4`0co`030?oo07Ko
201Fo`00T?lC03Ko00<0ool0Mol805Go002>oa<0>?l00`3oo`1go`P0EOl008co4`0jo`030?oo07Oo
201Eo`00ROlD03co00<0ool0Mol805Go0029oa40?ol00`3oo`1go`T0E?l008Oo4@11o`<0Mol905Co
0025oa40@ol00`3oo`1go`T0E?l0087o0P000ol0000=04Ko00<0ool0Mol805Go0020oa40B?l00`3o
o`1go`T0E?l007ko4@1:o`030?oo07Oo2@1Do`00OOl@04co00<0ool0Mol905Co001lo`l0C_l00`3o
o`1go`T0E?l007[o3`1@o`030?oo07So2@1Co`00NOl?057o00<0ool0N?l905?o001ho`h0Dol00`3o
o`1ho`T0Dol007Ko3P1Eo`030?oo07So201Do`00MOl=05Oo0`1ho`P0E?l007Co3@1Ho`030?oo07So
201Do`00L_l=05[o00<0ool0N?l805Co001ao`d0Fol00`3oo`1ho`P0E?l0077o301Lo`030?oo07So
201Do`00L?l<05go00<0ool0N?l805Co001_o``0G_l00`3oo`1ho`P0E?l006ko301Oo`030?oo07So
201Do`00KOl<063o00<0ool0N?l805Co001/o``0HOl00`3oo`1ho`P0E?l006_o301Ro`<0N?l805Co
001Zo``0Hol00`3oo`1ho`P0E?l006Wo301To`030?oo07So201Do`00J_l:06Go00<0ool0N?l805Co
001Zo`T0I_l00`3oo`1ho`T0Dol006Wo2@1Wo`030?oo07Oo2P1Co`00JOl806So00<0ool0Mol905Co
001Xo`T0GOl500Ko00<0ool0Mol905Co001Xo`T0Gol00`3oo`06o`030?oo07Oo2@1Do`00J?l8063o
00<0ool01_l00`3oo`1fo`X0E?l006Oo2@1Po`030?oo00Ko00<0ool0M_l:05Co001Wo`P0E_l600Go
00<0ool01_l407Ko201Eo`00I_l9067o00<0ool01_l00`3oo`1go`P0EOl006Ko201Ro`030?oo00Ko
00<0ool0Mol805Go001Wo`P0Gol300So00<0ool0Mol805Go001Vo`T0HOl00`3oo`06o`030?oo07Oo
201Eo`00I_l806_o00<0ool0Mol805Go001Uo`T0Jol00`3oo`1go`P0EOl006Co2@1/o`030?oo07Oo
201Eo`00I?l906co00<0ool0M_l905Go001To`P0KOl00`3oo`1fo`P0E_l006Co201]o`<0MOl905Ko
001To`P0KOl00`3oo`1eo`P0Eol006?o2@1]o`030?oo07Co2@1Go`00Hol906go00<0ool0M?l905Oo
001To`P0KOl00`3oo`1do`P0F?l006Co201]o`030?oo07?o2@1Ho`00I?l806go00<0ool0Lol805Wo
001To`P0KOl00`3oo`1co`P0FOl006Co201]o`030?oo07?o201Io`00I?l806go00<0ool0Lol705[o
001To`P0KOl00`3oo`1co`L0F_l006Co201]o`<0Lol705[o001To`P0KOl00`3oo`1bo`P0F_l006Co
201]o`030?oo07;o201Jo`00I?l806go00<0ool0L_l705_o001So`T0KOl00`3oo`1bo`L0Fol006?o
2@1]o`030?oo07;o1`1Ko`00Hol906go00<0ool0L_l705_o001To`P0KOl00`3oo`1ao`P0Fol006Co
201]o`030?oo077o201Ko`00I?l806go00<0ool0LOl705co001To`T0K?l3077o1`1Lo`00I?l906co
00<0ool0LOl705co001Uo`P0K?l00`3oo`1`o`P0G?l006Go201/o`030?oo073o201Lo`003Ol302oo
0`0Ro`X01?l5033o1@0]o`030?oo02oo1@0_o`D02?l8023o0`0co`<00ol000ko00<0ool0;Ol01@3o
ool0027o2P04o`050?ooo`00<_l00`3oo`0]o`030?oo037o00<0ool0;ol01@3oool000So1`0Po`05
0?ooo`00<ol00`3oo`02o`003_l00`3oo`0ao`030?oo023o2@05o`030?oo03?o00<0ool0;Ol00`3o
o`0ao`030?oo033o00<0ool02?l802Co00<0ool0<Ol00`3oo`02o`002_l603;o00<0ool08?l800Oo
00<0ool0<_l00`3oo`0]o`030?oo037o00<0ool0<Ol00`3oo`07o`P09?l00`3oo`0]o`H00ol000;o
1P03o`040?oo02Oo1P04o`808ol;00Go00<0ool09_l600Go00<0ool0;Ol00`3oo`0ao`030?oo03;o
00<0ool01_l802;o0P0ao`040?oo00Co000;o`040?oo03?o00<0ool08?l900Oo00<0ool0<Ol00`3o
o`0]o`030?oo037o00<0ool0<_l00`3oo`05o`P09Ol00`3oo`0^o`040?oo00Co000<o`030?l003?o
00<0ool08?l900So00<0ool0<?l00`3oo`0]o`030?oo037o00<0ool0<ol00`3oo`04o`P09Ol00`3o
o`0_o`030?l000Co000<o`030?l002oo00D0oooo000Ro`T01?l01@3oool0033o0`0_o`<0;ol3037o
00D0oooo0006o`L08_l01@3oool0037o00<0o`001?l000go0P0`o`<09?l900Co0`0co`030?oo02go
00<0ool0<Ol00`3oo`0`o`<01_l802?o0`0co`801?l006Ko2@1Zo`030?oo06go201Oo`00Iol806[o
00<0ool0KOl7063o001Wo`P0J_l00`3oo`1/o`P0H?l006Oo201Zo`030?oo06co201Po`00Iol806[o
00<0ool0Jol8067o001Wo`T0JOl00`3oo`1[o`P0HOl006So201Yo`030?oo06_o1`1Ro`00J?l806Wo
00<0ool0J_l806;o0009ool0X`05o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`070003o`3o00So00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l0103oool700[o00<0ool01ol00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo00Oo
00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3o
o`07o`030?oo00L000?o0?l02?l00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So
00<0ool01ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3o
o`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00P0
2_l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool00ol000Wo00<0ool0<Ol00`3oo`0Yo`L000?o0?l0<_l00`3oo`0ao`030?oo037o
00<0ool0<_l00`3oo`0802Wo00<0ool0<Ol00`3oo`03o`00JOl706Wo00<0ool0JOl806?o001Yo`P0
J?l00`3oo`1Xo`T0Hol006Wo201Xo`030?oo06So201To`00J_l806Oo00<0ool0J?l806Co001Zo`P0
Iol00`3oo`1Wo`P0IOl006[o201Wo`030?oo06Oo201Uo`00J_l806Oo0`1Vo`T0IOl006[o201Wo`03
0?oo06Ko201Vo`00Jol806Ko00<0ool0I_l806Ko001[o`P0I_l00`3oo`1Uo`P0Iol006co1`1Vo`03
0?oo06Go201Wo`00K?l706Ko00<0ool0IOl806Oo001/o`L0I_l00`3oo`1To`P0J?l006co1`1Vo`03
0?oo06Co201Xo`00K?l806Go00<0ool0Hol906So001/o`P0IOl00`3oo`1So`P0JOl006co201Uo`03
0?oo06?o201Yo`00K?l906Co0`1Ro`P0J_l006go201To`030?oo06;o201Zo`00KOl906?o00<0ool0
HOl906[o001]o`T0Hol00`3oo`1Qo`P0Jol006ko201So`030?oo067o201[o`00K_l906;o00<0ool0
H?l806co001_o`P0H_l00`3oo`1Po`P0K?l006oo2@1Qo`030?oo05oo2@1/o`00L?l8067o00<0ool0
Gol806go001`o`T0H?l00`3oo`1Oo`P0KOl0077o201Po`<0G_l806ko001ao`P0H?l00`3oo`1No`P0
K_l007;o201Oo`030?oo05go2@1^o`00L_l805oo00<0ool0GOl806oo001bo`T0G_l00`3oo`1Mo`P0
Kol007?o201No`030?oo05co201`o`00Lol905go00<0ool0G?l8073o001do`P0GOl00`3oo`1Ko`T0
L?l007Co201Mo`030?oo05_o201ao`00MOl805co00<0ool0Fol8077o001eo`P0G?l00`3oo`1Jo`P0
L_l007Go2@1Ko`<0F_l807;o001fo`P0Fol00`3oo`1Jo`P0L_l007Ko201Ko`030?oo05Wo201co`00
Mol805[o00<0ool0FOl807?o001go`P0F_l00`3oo`1Ho`T0Lol007Oo2@1Io`030?oo05So201do`00
N?l805Wo00<0ool0F?l807Co001ho`T0COl500Ko00<0ool0Eol807Go001io`T0C_l00`3oo`06o`03
0?oo05Oo201eo`00NOl904ko00<0ool01_l00`3oo`1Fo`T0MOl007[o2@1=o`030?oo00Ko101Eo`P0
M_l007_o201=o`030?oo00Ko00<0ool0EOl907Ko001lo`P0C?l00`3oo`06o`030?oo05Go201go`00
O?l904_o00<0ool01_l00`3oo`1Do`P0N?l007go2@18o`<02?l00`3oo`1Do`P0N?l007go2@1:o`03
0?oo00Ko00<0ool0Dol807Wo001mo`X0D_l00`3oo`1Co`P0NOl007ko2P1Ao`030?oo05;o201jo`00
Ool:053o00<0ool0D_l807[o0020o`X0Col00`3oo`1Ao`P0Nol0083o2`1>o`030?oo057o201ko`00
POl:04ko0`1@o`P0O?l008;o2P1=o`030?oo053o201lo`00Pol:04co00<0ool0Col807go0024o`X0
Bol00`3oo`1>o`T0OOl008Go2P1:o`030?oo04ko201no`00QOl;04Wo00<0ool0COl907ko0026o`/0
B?l00`3oo`1=o`P0Ool008Ko3017o`030?oo04co2020o`00Qol<04Ko00<0ool0C?l8083o0028o``0
AOl00`3oo`1;o`P0POl008Wo3014o`<0Bol8087o002:o``0@ol00`3oo`1:o`P0P_l008_o3012o`03
0?oo04[o2022o`00S?l<047o00<0ool0BOl808?o002=o``0@?l00`3oo`19o`P0Pol008ko300oo`03
0?oo04So2024o`00Sol<03ko00<0ool0B?l808Co002@o``0?Ol00`3oo`17o`P0QOl0097o3@0ko`03
0?oo04Ko2@25o`00T_l=03[o00<0ool0A_l808Ko002Co`h0>?l304Go2@26o`00U?l>03Oo00<0ool0
A?l908Oo002Go``0=_l00`3oo`14o`T0Qol009So3@0do`030?oo04?o2@28o`00V_l=03;o00<0ool0
@ol908So002Ko`d0<Ol00`3oo`12o`P0R_l009co3P0_o`030?oo047o2@2:o`00W_l=02ko00<0ool0
@Ol808_o002Oo`h0;?l00`3oo`10o`T0Rol00:7o3P0Zo`030?oo03oo2@2<o`00Xol>02So00<0ool0
?_l908go002To`l09_l303go2P2=o`00Y_l?02Co00<0ool0??l:08ko002Woa008_l00`3oo`0ko``0
SOl00:So4@0Po`030?oo03[o302>o`00Z_lA01ko00<0ool0>Ol<08oo002/oa407?l00`3oo`0ho``0
T?l00:ko4@0Jo`030?oo03Oo302Ao`00/?lA00co1@07o`030?oo03Ko302Bo`00/_lB00Wo00D0oooo
0007o`030?oo03Go302Co`00]?lC00Oo00<0ool02?l00`3oo`0do``0U?l00;Go5006o`030?oo00Oo
100ao`d0UOl00;Oo5@04o`030?oo00Ko00<0ool0<Ol=09Ko002joaD000?o0?l01ol00`3oo`0`o`d0
Uol00;co5P07o`030?oo02ko3P2Ho`00_olF00Co00<0ool0;Ol>09Wo0032oaP0;_l>09[o0035oa/0
9Ol@09_o0037oah03?l200Co0P09oa40WOl00<[o8006o`@00_l400?o502Oo`00cOm30:3o003@ocl0
XOl00=;o>`2So`00e_le0:Go003Iobl0Z?l00=Wo00@0oooo:P2Yo`00fOl00`3oo`07ob@0ZOl00=Wo
00<0ool02OlM0:ko003Io`030?oo01?o302eo`00fOl00`3oo`0Fo`800_l20;So003Io`030?oo0=Co
003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3o
ool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`80
2?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo
00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co
003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko
00@0ool01ol40=?o003>o`040?oo0=ko003?o`030?l00=ko003?o`030?l00=ko003@o`80g_l00?oo
/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.39832 .72839 m
.41202 .73401 L
.42741 .73925 L
.44408 .74376 L
.45958 .747 L
.47718 .74967 L
.48697 .75075 L
.49628 .75153 L
.50047 .75181 L
.50493 .75205 L
.50878 .75223 L
.51293 .75237 L
.51526 .75244 L
.51739 .75249 L
.51952 .75252 L
.52156 .75255 L
.5227 .75256 L
.52391 .75257 L
.5261 .75258 L
.52744 .75258 L
.5287 .75258 L
.52983 .75257 L
.53106 .75256 L
.53318 .75254 L
.53512 .75251 L
.53947 .75241 L
.54349 .75229 L
.5473 .75215 L
.55578 .75172 L
.56495 .75112 L
.58315 .74944 L
.59957 .74738 L
.62841 .74228 L
.6438 .73857 L
.65745 .73449 L
.67008 .7298 L
.68242 .72406 L
.7019 .7113 L
.71062 .70325 L
.71894 .69338 L
.72585 .68272 L
.73136 .67183 L
.73679 .6579 L
.74102 .64358 L
.74484 .62618 L
.74661 .6158 L
.74802 .60584 L
.75012 .58626 L
.75102 .57483 L
.7517 .56359 L
Mistroke
.75218 .55291 L
.75252 .54273 L
.75266 .53676 L
.75276 .53128 L
.7528 .52821 L
.75283 .52487 L
.75286 .5217 L
.75287 .51877 L
.75287 .5155 L
.75287 .51239 L
.75286 .50959 L
.75284 .50652 L
.75281 .50317 L
.75276 .4996 L
.75266 .49314 L
.75253 .48713 L
.75238 .48146 L
.75194 .46839 L
.75131 .45396 L
.75059 .44061 L
.74844 .41021 L
.7458 .38224 L
.74274 .35645 L
.73835 .32695 L
.73334 .30013 L
.72755 .27515 L
.72019 .24991 L
.7125 .22904 L
.70435 .21141 L
.69469 .19497 L
.68277 .17967 L
.66978 .16771 L
.6619 .16232 L
.65433 .15825 L
.64702 .1552 L
.64289 .15382 L
.63892 .15271 L
.63521 .15186 L
.63174 .1512 L
.62783 .15062 L
.62558 .15037 L
.62352 .15018 L
.62142 .15003 L
.61914 .14991 L
.61702 .14985 L
.61499 .14983 L
.61261 .14985 L
.6104 .14991 L
.60923 .14996 L
.60794 .15003 L
Mistroke
.60532 .15021 L
.60273 .15044 L
.60035 .15069 L
.59491 .15143 L
.58484 .15332 L
.57527 .15569 L
.56481 .15885 L
.54539 .16609 L
.49912 .18899 L
.40277 .25356 L
.31772 .32385 L
.2551 .38685 L
.23261 .4161 L
.22394 .43017 L
.21677 .44471 L
.21406 .45159 L
.21196 .45803 L
.21033 .46423 L
.20919 .46991 L
.20842 .47526 L
.20814 .47795 L
.20802 .47949 L
.20793 .48091 L
.20785 .48235 L
.2078 .48386 L
.20777 .48538 L
.20776 .48624 L
.20776 .48704 L
.20778 .48849 L
.20781 .48981 L
.20787 .49134 L
.20795 .49278 L
.20817 .49575 L
.20846 .49853 L
.20938 .50486 L
.21063 .51104 L
.21233 .51771 L
.21633 .52987 L
.22092 .54111 L
.25086 .5935 L
.29009 .64428 L
.31529 .67081 L
.33993 .69251 L
.39512 .72694 L
.39832 .72839 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00c_l300So00<0ool0e?l00<go
00D0oooo0007o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol40=?o0035o`H0
1?l200So00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00dOl00`3oo`05o`030?oo0=Co003=o`05
0?ooo`001ol00`3oo`3Do`00c_l300So00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool09Ol300[o
0P2Po`00fOl00`3oo`0QoaP0Vol00=Wo00<0ool07?lQ09Oo003Io`030?oo01So9P2Fo`00fOl301So
:02Do`00fOl00`3oo`0Fobd0TOl00=Wo00<0ool04ola093o003Io`030?oo013o=@2?o`00fOl00`3o
o`0>ocP0S_l00=Wo00<0ool02olE01;o5P2<o`00fOl00`3oo`0:oa@07?l?08_o003Io`030?oo00So
4`0Ro`d0R_l00=Wo00<0ool01_lC02Ko3@28o`00fOl00`3oo`03oa<0:_l<08So003Io`<000?o0000
4@0]o`d0Q_l00=Wo00<0o`004@0bo``0QOl00=Wo4P0eo``0Q?l00=Oo4P0ho`X0QOl00=Co4`0ko`/0
Pol00=Co4@0no`X0Pol00=?o3`12o`X0P_l00=7o3`15o`T0P_l00=3o3P18o`T0POl00<ko3P1;o`P0
POl00<go3@1=o`T0P?l00<_o3@001?l0001<o`T0Ool00<[o3@02o`030?oo04go201oo`00b?l=00Co
00<0ool0COl907ko0037o`d01Ol00`3oo`1>o`P0O_l00<Go3@07o`030?oo04ko2@1mo`00a?l=00So
00<0ool0Col807go0032o`d02_l00`3oo`1?o`T0O?l00<7o3@0;o`030?oo053o201lo`00`?l<00go
00<0ool0D?l807co002no`d03_l00`3oo`1Ao`P0Nol00;go300@o`<0DOl807_o002ko`d04Ol00`3o
o`1Ao`T0N_l00;[o300Co`030?oo05;o201jo`00^?l=01Co00<0ool0D_l907Wo002go`d05Ol00`3o
o`1Co`P0NOl00;Go3@0Go`030?oo05?o201io`00]?l=01So00<0ool0Dol807Wo002ao`h03_l500Oo
00<0ool0E?l807So002`o`h03ol01@3oool000Oo00<0ool0E?l807So002^o`h04_l00`3oo`08o`03
0?oo05Co201ho`00[Ol>01Co00<0ool01ol00`3oo`1Eo`P0Mol00:co3@0<o`H01Ol00`3oo`06o`@0
E?l807Oo002[o`d06?l00`3oo`06o`030?oo05Go201go`00ZOl=01_o00<0ool01Ol00`3oo`1Fo`P0
M_l00:So3@0Ho`050?ooo`001ol00`3oo`1Fo`P0M_l00:Oo300Ko`<02?l00`3oo`1Fo`P0M_l00:Go
3@0Wo`030?oo05Oo1`1fo`00Y?l=02So00<0ool0Eol807Go002So`d0:Ol00`3oo`1Go`P0MOl00:;o
300[o`030?oo05Oo201eo`00X?l=02co00<0ool0F?l807Co002Oo`d0;Ol305So201do`00W_l<02oo
00<0ool0F?l807Co002Mo``0<?l00`3oo`1Io`P0Lol009_o3@0ao`030?oo05Wo201co`00V_l=03;o
00<0ool0FOl807?o002Io``0=?l00`3oo`1Jo`L0Lol009So300eo`030?oo05[o1`1co`00U_l=03Ko
00<0ool0F_l807;o002Eo`d0=ol00`3oo`1Jo`P0L_l009Co300io`030?oo05[o201bo`00Tol<03[o
0`1Jo`T0LOl0097o3@0ko`030?oo05_o201ao`00T?l=03co00<0ool0Fol8077o002?o``0?_l00`3o
o`1Ko`T0L?l008go3@0oo`030?oo05_o2@1`o`00S?l=043o00<0ool0G?l8073o002;o`d0@Ol00`3o
o`1Lo`P0L?l008[o3013o`030?oo05co201`o`00R?l=04Co00<0ool0G?l8073o0027o`d0AOl00`3o
o`1Lo`T0Kol008So2`16o`030?oo05co2@1_o`00Qol;04Oo0`1Lo`T0Kol008Ko2`18o`030?oo05go
201_o`00QOl;04Wo00<0ool0GOl906ko0024o`/0B_l00`3oo`1Mo`T0K_l008?o2`1;o`030?oo05go
2@1^o`00P_l;04co00<0ool0GOl906ko0021o`/0COl00`3oo`1No`P0K_l0083o2`1>o`030?oo05ko
201^o`00Ool;04oo00<0ool0G_l806ko001no`/0D?l00`3oo`1No`T0KOl007go2`1Ao`<0Gol806go
001lo`/0D_l00`3oo`1Oo`P0KOl007_o2`1Co`030?oo05oo201]o`00N_l;05Co00<0ool0Gol806go
001io`/0EOl00`3oo`1Oo`T0K?l007So2`1Fo`030?oo05oo2@1/o`00Mol;05Oo00<0ool0Gol906co
001fo`/0COl500Ko00<0ool0Gol806go001eo`/0D?l00`3oo`06o`030?oo05oo2@1/o`00M?l;057o
00<0ool01_l00`3oo`1Po`P0K?l007?o2`1Bo`030?oo00Ko00<0ool0H?l806co001ao``0B?l600Go
00<0ool01_l405oo201/o`00LOl;05Co00<0ool01_l00`3oo`1Po`P0K?l0073o2`1Eo`030?oo00Ko
00<0ool0H?l806co001_o`/0E?l300So00<0ool0H?l806co001^o`/0Eol00`3oo`06o`030?oo063o
201/o`00KOl;067o00<0ool0H?l806co001]o`X0H_l00`3oo`1Po`P0K?l006go2@1So`030?oo063o
201/o`00K?l906Co00<0ool0H?l906_o001[o`X0I?l00`3oo`1Qo`P0Jol006[o2P1Uo`<0HOl806_o
001Zo`T0I_l00`3oo`1Qo`P0Jol006Wo2P1Vo`030?oo067o201[o`00J?l:06Oo00<0ool0HOl806_o
001Xo`T0J?l00`3oo`1Qo`P0Jol006Oo2@1Yo`030?oo067o201[o`00I_l:06Wo00<0ool0HOl806_o
001Vo`T0J_l00`3oo`1Qo`P0Jol006Go2@1[o`030?oo067o201[o`00I?l:06_o00<0ool0HOl806_o
001So`X0K?l00`3oo`1Qo`T0J_l006?o2@1]o`<0H_l806[o001Ro`X0KOl00`3oo`1Ro`P0J_l006;o
201_o`030?oo06;o201Zo`00HOl906oo00<0ool0H_l806[o001Qo`P0L?l00`3oo`1Ro`P0J_l0063o
2@1`o`030?oo06;o201Zo`00H?l8077o00<0ool0H_l806[o001Oo`T0LOl00`3oo`1Ro`P0J_l005oo
201bo`030?oo06;o201Zo`00G_l907;o00<0ool0H_l806[o001No`T0L_l306;o201Zo`00G_l807?o
00<0ool0H_l806[o001Mo`T0Lol00`3oo`1Ro`P0J_l005co2@1do`030?oo06;o201Zo`003Ol302oo
0`0Jo`T03Ol5033o1@0]o`030?oo02oo1@0^o`P0;_l303?o0`03o`003_l00`3oo`0]o`050?ooo`00
6Ol800ko00D0oooo000bo`030?oo02go00<0ool0<Ol00`3oo`0^o`P0;Ol01@3oool003?o00<0ool0
0_l000ko00<0ool0<Ol00`3oo`0Go`P03ol00`3oo`0co`030?oo02go00<0ool0<Ol00`3oo`0^o`P0
<Ol00`3oo`0ao`030?oo00;o000:o`H0<_l00`3oo`0Go`P04?l00`3oo`0bo`030?oo02go00<0ool0
<Ol00`3oo`0^o`P0<Ol00`3oo`0]o`H00ol000;o1P03o`040?oo02Oo1P04o`806Ol900Ko1P05o`03
0?oo02Ko1P05o`030?oo02go00<0ool0<Ol00`3oo`0^o`P0;ol2037o00@0ool01?l000_o00@0ool0
<ol00`3oo`0Fo`T04Ol00`3oo`0ao`030?oo02go00<0ool0<Ol00`3oo`0^o`P0<Ol00`3oo`0^o`04
0?oo00Co000<o`030?l003?o00<0ool05_l:017o00<0ool0<?l00`3oo`0]o`030?oo037o00<0ool0
;_l9033o00<0ool0;ol00`3o0004o`003?l00`3o000_o`050?ooo`005ol<00co00D0oooo000`o`<0
;ol302oo0`0`o`T0;?l01@3oool0037o00<0o`001?l000go0P0`o`<05ol<00ko0`0co`030?oo02go
00<0ool0<Ol00`3oo`0^o`T0;Ol303?o0P04o`00F_l:07Go00<0ool0Hol806Wo001Ko`T0MOl00`3o
o`1So`P0JOl005_o2@1eo`030?oo06?o201Yo`00Fol807Ko00<0ool0Hol806Wo001Ko`T0MOl00`3o
o`1So`P0JOl005[o2P1eo`030?oo06?o201Yo`00FOl<07Co00<0ool0Hol806Wo001Jo``0Lol00`3o
o`1So`P0JOl000Woo`2S00Go0009o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01_l900;o00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
2?l00`3oo`07o`030?oo00Go2005o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00?o0009o`030?oo00Oo00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01_l900;o00<0ool0
2?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Go2005o`030?oo00So00<0ool0
1ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00?o0009o`030?oo037o00<0ool06ol900go00<0ool0<Ol00`3oo`0ao`030?oo037o00<0ool0
;ol802oo00<0ool0<Ol00`3oo`03o`00G?l807Go00<0ool0Hol806Wo001Lo`P0MOl00`3oo`1So`P0
JOl005co2@1do`030?oo06?o201Yo`00G?l907Co00<0ool0Hol806Wo001Lo`X0Lol00`3oo`1So`P0
JOl005co2P1co`030?oo06?o201Yo`00G_l807?o0`1So`P0JOl005ko2@1bo`030?oo06?o201Yo`00
Gol807;o00<0ool0Hol806Wo001Oo`T0LOl00`3oo`1So`P0JOl0063o201ao`030?oo06?o201Yo`00
H?l8077o00<0ool0Hol806Wo001Qo`P0L?l00`3oo`1So`P0JOl0067o201`o`030?oo06?o201Yo`00
HOl906oo00<0ool0Hol806Wo001Ro`P0Kol00`3oo`1So`P0JOl006;o2@1^o`030?oo06?o201Yo`00
Hol906go0`1So`P0JOl006Co201]o`030?oo06?o201Yo`00I?l906co00<0ool0Hol806Wo001Uo`P0
K?l00`3oo`1Ro`T0JOl006Ko201[o`030?oo06;o2@1Yo`00I_l806_o00<0ool0H_l906Wo001Wo`P0
J_l00`3oo`1Ro`P0J_l006Oo201Zo`030?oo06;o201Zo`00J?l806Wo00<0ool0H_l806[o001Xo`P0
JOl00`3oo`1Ro`P0J_l006Wo201Xo`<0H_l806[o001Yo`T0Iol00`3oo`1Ro`T0JOl006[o201Wo`03
0?oo06;o2@1Yo`00J_l906Ko00<0ool0H_l906Wo001[o`T0IOl00`3oo`1Ro`T0JOl006co201Uo`03
0?oo06;o2@1Yo`00K?l906Co00<0ool0H_l806[o001/o`X0Hol00`3oo`1Ro`P0J_l006go2P1Ro`03
0?oo06;o201Zo`00K_l:067o00<0ool0H_l806[o001^o`X0HOl00`3oo`1Ro`P0J_l006oo2P1Po`<0
H_l806[o001_o`/0Gol00`3oo`1Ro`P0J_l0077o2P1No`030?oo067o2@1Zo`00L_l905ko00<0ool0
HOl806_o001bo`X0GOl00`3oo`1Qo`P0Jol007?o2P1Lo`030?oo067o201[o`00M?l:05_o00<0ool0
H?l806co001eo`X0Col500Ko00<0ool0H?l806co001eo`X0DOl00`3oo`06o`030?oo063o201/o`00
M_l:053o00<0ool01_l00`3oo`1Po`P0K?l007Oo2P1?o`030?oo00Ko101No`T0K?l007So2P1>o`03
0?oo00Ko00<0ool0Gol806go001io`X0COl00`3oo`06o`030?oo05oo201]o`00NOl:04go00<0ool0
1_l00`3oo`1Oo`P0KOl007[o2P1:o`<02?l00`3oo`1Oo`P0KOl007_o2P1;o`030?oo00Ko00<0ool0
G_l906go001lo`X0Dol00`3oo`1No`T0KOl007go2@1Co`030?oo05ko201^o`00O?l;05;o00<0ool0
G_l806ko001mo`/0DOl00`3oo`1Mo`T0K_l007ko2`1@o`030?oo05go201_o`00Ool;04oo0`1Mo`P0
Kol0083o2`1>o`030?oo05go201_o`00POl;04go00<0ool0G?l8073o0022o`/0C?l00`3oo`1Lo`P0
L?l008?o2`1;o`030?oo05co201`o`00Q?l;04[o00<0ool0Fol8077o0025o`/0BOl00`3oo`1Ko`P0
LOl008Ko2`18o`030?oo05_o201ao`00Qol;04Oo00<0ool0F_l9077o0028o`/0A_l00`3oo`1Jo`P0
L_l008Wo3014o`<0FOl907;o002:o``0@ol00`3oo`1Io`P0Lol008_o3012o`030?oo05So2@1co`00
S?l<047o00<0ool0F?l807Co002=o``0@?l00`3oo`1Go`T0M?l008ko300oo`030?oo05Ko2@1eo`00
T?l;03ko00<0ool0EOl:07Go002Ao`/0?Ol00`3oo`1Do`X0M_l0097o3@0ko`030?oo05?o301eo`00
T_l=03[o00<0ool0D_l<07Ko002Do`d0>?l3057o301go`00UOl=03Oo00<0ool0D?l<07So002Fo`h0
=Ol00`3oo`1?o``0NOl009So3P0co`030?oo04ko301jo`00V_l=03;o00<0ool0COl<07_o002Ko`h0
<?l00`3oo`1<o``0O?l009go3@0_o`030?oo04[o3@1mo`00W_l>02go00<0ool0BOl=07ko002Po`l0
:_l00`3oo`17o`h0Ool00:;o4@0Vo`030?oo04Co4020o`00Xol@02Ko00<0ool0@_lA087o002Uoa00
9?l303oo4@24o`00Y_lA02;o00<0ool0?OlA08Ko002Xoa807ol00`3oo`0ioaD0Q_l00:Wo500Lo`03
0?oo03?o6@28o`00ZOlI01Oo00<0ool0;_lL08[o002Yob403ol00`3oo`0Wob00SOl00;3o9@04o`03
0?oo01oo9P2?o`00/_lS00Co00<0ool05?l^09;o002dofP0U?l00;SoH@2Go`00^_mL09[o002noe@0
W_l00<7oBP2Uo`00aOm20:Wo003=o`030?oo02l0/Ol00<ko:P2ho`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3oo`3Do`00
dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool01Ol00`3o
o`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`030?l00=ko
003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -6 -9 ]
[.125 .4875 6 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -3 -9 ]
[.875 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -12 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -6 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
0 .5 m
0 .50625 L
s
[(-4)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-3)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-2)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-1)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(1)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(2)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(3)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(4)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-3)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-2)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-1)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(1)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(2)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(3)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(4)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.02 w
.5 .75 m
.50194 .74999 L
.5037 .74997 L
.50574 .74993 L
.50766 .74988 L
.51109 .74975 L
.5148 .74956 L
.51889 .74929 L
.52323 .74892 L
.531 .74809 L
.54651 .74572 L
.56354 .74208 L
.58061 .7374 L
.59881 .73133 L
.6311 .71809 L
.69188 .6853 L
.71847 .66717 L
.7399 .64955 L
.75695 .63153 L
.76468 .62088 L
.77048 .61073 L
.77303 .60523 L
.77536 .59925 L
.77706 .59392 L
.77857 .58802 L
.77928 .58461 L
.77982 .58145 L
.78029 .57818 L
.78064 .5751 L
.78095 .57145 L
.78107 .56949 L
.78112 .56848 L
.78116 .56739 L
.78122 .56555 L
.78124 .56381 L
.78125 .5628 L
.78125 .56172 L
.78124 .5608 L
.78122 .55979 L
.78117 .55784 L
.7811 .55604 L
.781 .55404 L
.78087 .55189 L
.78057 .54824 L
.78015 .54415 L
.7791 .53638 L
.77781 .52885 L
.77386 .51108 L
.76801 .49055 L
.73212 .39981 L
Mistroke
.68165 .30115 L
.62424 .21213 L
.59283 .17491 L
.57511 .15806 L
.55871 .14538 L
.5418 .13541 L
.53289 .13146 L
.52834 .1298 L
.52347 .1283 L
.51917 .1272 L
.51526 .1264 L
.51132 .12577 L
.50955 .12555 L
.5076 .12535 L
.50549 .12518 L
.50434 .12511 L
.50326 .12506 L
.50133 .12501 L
.49925 .125 L
.49815 .12502 L
.49695 .12506 L
.49569 .12511 L
.49452 .12518 L
.49243 .12534 L
.49019 .12558 L
.48591 .12619 L
.48138 .12708 L
.47327 .12928 L
.46455 .1325 L
.45498 .13706 L
.4379 .14777 L
.42202 .16057 L
.3893 .19499 L
.36022 .23374 L
.30245 .33007 L
.25729 .42363 L
.24016 .4665 L
.23295 .48753 L
.22675 .50873 L
.22446 .51801 L
.22246 .52743 L
.22098 .53583 L
.21994 .54337 L
.21955 .54692 L
.21926 .55022 L
.21912 .55202 L
.219 .55395 L
.21891 .55569 L
.21884 .55729 L
.21879 .55905 L
Mistroke
.21876 .56098 L
.21875 .56283 L
.21876 .56386 L
.21877 .5648 L
.21881 .56646 L
.21887 .56826 L
.21896 .56994 L
.21905 .57148 L
.21936 .57509 L
.21973 .57834 L
.22024 .58185 L
.22089 .58549 L
.22226 .59144 L
.22413 .59775 L
.22861 .60887 L
.23395 .6187 L
.24993 .63946 L
.2687 .65708 L
.31956 .69228 L
.37726 .72181 L
.40883 .73401 L
.42523 .73911 L
.44302 .74361 L
.45831 .74655 L
.46502 .74757 L
.47237 .74848 L
.47934 .74915 L
.48583 .7496 L
.48942 .74978 L
.49268 .74989 L
.49449 .74994 L
.49645 .74997 L
.4983 .74999 L
.5 .75 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/0P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo/Ol00?oo/Ol00?oo/Ol00?oo/Ol00=3o
0`3Mo`00dOl00`3oo`3Lo`00dOl00`3oo`3Lo`00cOl600Ko103Co`00aOl600?o00@0ool01ol00`3o
o`3Do`00c_l0103oo`07o`030?oo0=Co003?o`030?l000Oo00<0ool0e?l00<oo00<0o`001ol00`3o
o`3Do`00d?l200Oo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co
003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo
00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3o
o`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`@0dol00<ko0`000ol0000=0<oo003=oaP0bol00<co
7@37o`00bOlP0<Oo0035obL0a?l00<7o;033o`00`Ol_0<3o0031oc00_ol00;oo<`2no`00__lA00[o
00@0o`000_lE0;co002loa403?l00`3oo`0:oa00^_l00;_o400>o`030?oo00co402ho`00^Ol?017o
00<0ool03_l@0;Ko002io`d04ol00`3oo`0Ao`h0]Ol00;So300Eo`<04_l>0;Co002go``05_l00`3o
o`0Do`d0/ol00;Go3@0Go`030?oo01Go3@2bo`00]?l<01Wo00<0ool05ol<0;7o002co``06_l00`3o
o`0Ho``0/?l00;?o2`0Ko`030?oo01Wo3@2^o`00/_l;01co00<0ool06_l=0:go002ao`/07Ol00`3o
o`0Ko``0[Ol00;3o2`0No`030?oo01co302/o`00[ol;01oo00<0ool07Ol<0:_o002^o`/08?l301ko
302Zo`00[Ol;027o00<0ool07ol;0:[o002/o`/08_l00`3oo`0Po`/0ZOl00:_o2`0So`030?oo027o
2`2Xo`00ZOl<02Co00<0ool08_l;0:Oo002Yo`/09Ol00`3oo`0So`/0Y_l00:So2`0Vo`030?oo02Co
2P2Vo`00Yol;02Oo00<0ool09Ol:0:Go002Vo`/0:?l00`3oo`0Vo`X0Y?l00:Go2`0Yo`030?oo02Oo
2P2So`00YOl:02[o00<0ool0:?l:0:;o002To`X0:ol302So2P2Ro`00Y?l902co00<0ool0:Ol:0:7o
002So`X0;?l00`3oo`0Zo`X0X?l00:;o2P0]o`030?oo02_o2P2Oo`00X_l902ko00<0ool0;?l909oo
002Qo`T0;ol00`3oo`0/o`X0W_l00:3o2P0_o`030?oo02go2P2Mo`00X?l9033o00<0ool0;_l909go
002Oo`T0<Ol00`3oo`0_o`P0WOl009ko2P0ao`030?oo02oo2@2Lo`00WOl:03;o0`0`o`T0Vol009go
2@0co`030?oo037o202Ko`00W?l:03?o00<0ool0<Ol909[o002Ko`X0=?l00`3oo`0bo`P0V_l009_o
2@0eo`030?oo03?o202Io`00V_l903Ko00<0ool0<ol909So002Jo`T0=_l00`3oo`0do`P0V?l009Wo
2@0[o`D01ol00`3oo`0do`T0Uol009Wo200/o`050?ooo`001ol00`3oo`0eo`T0U_l009So2@0]o`03
0?oo00So00<0ool0=_l809Ko002Go`T0;ol00`3oo`07o`030?oo03Ko2@2Eo`00Uol802Ko1P05o`03
0?oo00Ko100fo`T0U?l009Ko2@0ao`030?oo00Ko00<0ool0>?l809Co002Eo`T0<ol00`3oo`05o`03
0?oo03So2@2Co`00UOl8033o00D0oooo0007o`030?oo03Wo2@2Bo`00U?l9037o0`08o`030?oo03[o
202Bo`00U?l803go00<0ool0>_l9097o002Co`P0?_l00`3oo`0ko`T0T?l009;o2@0no`030?oo03co
202@o`00T_l803oo00<0ool0??l908oo002Ao`T0?ol00`3oo`0mo`T0S_l0097o2010o`<0?_l808ko
002@o`P0@Ol00`3oo`0no`T0SOl008oo2@11o`030?oo03oo202=o`00Sol804;o00<0ool0@?l808co
002>o`T0@_l00`3oo`10o`T0Rol008ko2013o`030?oo047o202;o`00SOl804Co00<0ool0@Ol908[o
002<o`T0A?l00`3oo`12o`T0ROl008co2015o`030?oo04?o2029o`00Rol904Go00<0ool0@ol908So
002;o`P0A_l304Co2@27o`00R_l804Oo00<0ool0AOl808Oo0029o`T0Aol00`3oo`15o`T0Q_l008Wo
2018o`030?oo04Ko2026o`00R?l904So00<0ool0Aol708Ko0027o`T0BOl00`3oo`17o`P0QOl008Oo
201:o`030?oo04So1`25o`00Q_l904[o00<0ool0B?l808Co0026o`P0Bol00`3oo`19o`L0Q?l008Go
201<o`030?oo04Wo2023o`00Q?l904co00<0ool0B_l708?o0024o`P0COl304[o2022o`00Pol904go
00<0ool0Bol708;o0023o`P0C_l00`3oo`1;o`P0POl008;o2@1>o`030?oo04co1`21o`00P_l804oo
00<0ool0C?l8083o0021o`T0Col00`3oo`1=o`L0P?l0087o201@o`030?oo04go201oo`00P?l9053o
00<0ool0C_l707oo0020o`P0DOl00`3oo`1>o`P0O_l007oo2@1Ao`030?oo04oo201mo`00Ool805;o
0`1?o`P0OOl007ko2@1Bo`030?oo053o201lo`00O_l805?o00<0ool0DOl707co001mo`T0Dol00`3o
o`1Ao`P0Nol007go201Do`030?oo05;o1`1ko`00O?l905Co00<0ool0D_l807[o001lo`P0EOl00`3o
o`1Co`L0N_l007_o2@1:o`D01_l00`3oo`1Co`P0NOl007_o201=o`030?oo00Ko00<0ool0E?l707Wo
001jo`T0COl00`3oo`06o`030?oo05Co201ho`00N_l804ko00<0ool01_l00`3oo`1Eo`L0N?l007[o
2013o`H01Ol00`3oo`06o`@0E?l807Oo001io`P0Col00`3oo`06o`030?oo05Ko1`1go`00NOl804oo
00<0ool01_l00`3oo`1Fo`P0M_l007So2@1=o`<02?l00`3oo`1Go`L0M_l007So201@o`030?oo00Ko
00<0ool0Eol807Go001go`T0FOl00`3oo`1Ho`L0MOl007Oo201Jo`030?oo05So201do`00M_l905[o
00<0ool0FOl807?o001fo`P0Fol00`3oo`1Io`P0Lol007Go2@1Ko`030?oo05Wo2@1bo`00MOl805co
0`1Jo`P0L_l007Co2@1Lo`030?oo05[o201bo`00M?l805go00<0ool0Fol8077o001co`T0GOl00`3o
o`1Ko`P0LOl007?o201No`030?oo05_o2@1`o`00L_l905ko00<0ool0G?l8073o001bo`P0Gol00`3o
o`1Lo`P0L?l0077o2@1Oo`030?oo05go201_o`00LOl8063o00<0ool0GOl806oo001`o`T0H?l00`3o
o`1Mo`T0K_l0073o201Qo`030?oo05ko201^o`00Kol9067o0`1No`P0K_l006oo201Ro`030?oo05oo
201]o`00Kol806;o00<0ool0Gol806go001^o`T0H_l00`3oo`1Oo`T0K?l006ko201So`030?oo063o
201/o`00K_l806?o00<0ool0H?l806co001]o`P0I?l00`3oo`1Qo`P0Jol006go201To`030?oo067o
201[o`00K?l906Co00<0ool0HOl906[o001/o`P0IOl00`3oo`1Ro`P0J_l006co201Uo`<0H_l806[o
001[o`P0I_l00`3oo`1So`P0JOl006_o201Vo`030?oo06?o201Yo`00J_l906Ko00<0ool0Hol906So
000=o`<0;ol302So3@0`o`D0;Ol00`3oo`0_o`D0;ol902co0`0co`<00ol000ko00<0ool0;Ol01@3o
ool002Oo2@03o`030?oo033o00<0ool0;Ol00`3oo`0ao`030?oo02oo2@0[o`050?ooo`00<ol00`3o
o`02o`003_l00`3oo`0ao`030?oo02Co2002o`030?oo03?o00<0ool0;Ol00`3oo`0ao`030?oo033o
2@0^o`030?oo037o00<0ool00_l000[o1P0bo`030?oo02Co2003o`030?oo03;o00<0ool0;Ol00`3o
o`0ao`030?oo037o200^o`030?oo02go1P03o`000_l600?o00@0ool09ol600Co0P0Vo`T01?l00`3o
o`0Vo`H01Ol00`3oo`0]o`030?oo037o00<0ool0<Ol902_o0P0ao`040?oo00Co000;o`040?oo03?o
00<0ool08ol800Go00<0ool0<Ol00`3oo`0]o`030?oo037o00<0ool0<_l802go00<0ool0;_l0103o
o`04o`003?l00`3o000co`030?oo02?o2006o`030?oo033o00<0ool0;Ol00`3oo`0ao`030?oo03;o
200]o`030?oo02oo00<0o`001?l000co00<0o`00;ol01@3oool002Go2002o`050?ooo`00<?l302oo
0`0_o`<0<Ol0103oool802So00D0oooo000ao`030?l000Co000=o`80<?l302Go2004o`<0<ol00`3o
o`0]o`030?oo037o00<0ool0<?l;02Wo0`0co`801?l006Oo201Zo`030?oo06Oo2@1To`00Iol806[o
00<0ool0J?l806Co001Vo`P0Jol00`3oo`1Xo`P0I?l006Ko201[o`030?oo06Wo201So`00I_l806_o
00<0ool0JOl806?o001Uo`P0K?l00`3oo`1Yo`T0H_l006Go201/o`030?oo06[o201Ro`00IOl806co
00<0ool0J_l806;o0009ool0X`05o`002Ol00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool01Ol800Go00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00So00<0ool01ol00`3oo`08o`030?oo00;o2008o`030?oo00Oo00<0ool01ol00`3oo`08o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`03o`002Ol00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool0
1Ol800Go00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`03
0?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool01ol00`3oo`08o`030?oo00;o2008o`03
0?oo00Oo00<0ool01ol00`3oo`08o`030?oo00Oo00<0ool02?l00`3oo`07o`030?oo00So00<0ool0
1ol00`3oo`03o`002Ol00`3oo`0ao`030?oo02?o2@05o`030?oo037o00<0ool0<Ol00`3oo`0ao`03
0?oo03;o00<0ool00_l802Oo00<0ool0<Ol00`3oo`03o`00Hol806ko00<0ool0Jol9063o001So`P0
K_l00`3oo`1/o`P0H?l006;o2@1^o`030?oo06co201Po`00H_l906ko00<0ool0K?l905oo001Qo`T0
Kol00`3oo`1/o`T0Gol0067o2@1_o`030?oo06co2@1Oo`00HOl906oo0`1/o`T0Gol0067o2@1_o`03
0?oo06go201Oo`00HOl906oo00<0ool0KOl905ko001Po`X0Kol00`3oo`1]o`T0G_l0063o2@1`o`03
0?oo06ko201No`00H?l9073o00<0ool0K_l805ko001Po`T0L?l00`3oo`1^o`P0G_l0063o2@1`o`03
0?oo06ko2@1Mo`00H?l9073o00<0ool0KOl:05go001Po`T0L?l00`3oo`1^o`T0GOl005oo2@1ao`03
0?oo06ko2@1Mo`00Gol9077o0`1^o`T0GOl0063o201ao`030?oo06ko2@1Mo`00H?l8077o00<0ool0
K_l905go001Po`P0LOl00`3oo`1^o`X0G?l0063o201ao`030?oo06oo201Mo`00H?l8077o00<0ool0
Kol805go001Po`P0LOl00`3oo`1_o`P0GOl0063o201ao`030?oo06ko2@1Mo`00H?l8077o00<0ool0
K_l:05co001Po`P0LOl00`3oo`1]o``0Fol0063o201ao`<0K?l<05co001Oo`T0LOl00`3oo`1]o`X0
GOl0063o2@1`o`030?oo06ko2@1Mo`00H?l9073o00<0ool0K_l905go001Po`T0L?l00`3oo`1^o`T0
GOl0063o2@1`o`030?oo06ko2@1Mo`00H?l9073o00<0ool0K_l805ko001Po`X0Kol00`3oo`1]o`T0
G_l0067o201`o`030?oo06go2@1No`00HOl906oo00<0ool0K?l:05ko001Qo`T0Kol00`3oo`1/o`X0
G_l0067o2P1^o`<0Jol9063o001So`P0K_l00`3oo`1[o`T0H?l006?o2@1]o`030?oo06_o201Qo`00
I?l806go00<0ool0J_l9067o001To`T0K?l00`3oo`1Zo`P0H_l006Go201/o`030?oo06Wo2@1Ro`00
IOl906_o00<0ool0JOl806?o001To`/0Gol500Ko00<0ool0J?l906?o001Uo`/0H?l00`3oo`06o`03
0?oo06So201To`00I_l;05oo00<0ool01_l00`3oo`1Wo`T0I?l006Oo2P1Oo`030?oo00Ko101Vo`P0
IOl006Oo2`1No`030?oo00Ko00<0ool0I_l906Go001Xo`/0GOl00`3oo`06o`030?oo06Go2@1Vo`00
J_l:05co00<0ool01_l00`3oo`1To`/0IOl006_o2P1Io`<02?l00`3oo`1Ro``0I_l006_o2`1Jo`03
0?oo00Ko00<0ool0HOl<06Oo001[o``0H_l00`3oo`1Po``0J?l006co301Qo`030?oo05oo301Yo`00
KOl<063o00<0ool0G_l<06[o001^o``0Gol00`3oo`1Mo``0Jol006oo301No`030?oo05co2`1]o`00
L?l<05go0`1Ko`/0K_l0077o301Lo`030?oo05Wo301_o`00L_l<05_o00<0ool0F?l<073o001co``0
F_l00`3oo`1Go``0LOl007Co3@1Ho`030?oo05Ko301bo`00MOl=05Oo00<0ool0EOl<07?o001fo`h0
EOl00`3oo`1Co`d0M?l007Oo3P1Do`030?oo05;o301fo`00N?l?05;o00<0ool0D?l=07Oo001ko`d0
DOl00`3oo`1>o`h0N?l007go3@1?o`<0COl>07Wo001no`d0C_l00`3oo`1;o`l0N_l0083o3@1<o`03
0?oo04[o3`1ko`00POl=04_o00<0ool0B?l>07ko0023o`d0BOl00`3oo`16o`h0P?l008Co3@18o`03
0?oo04Go3P21o`00Q_l=04Ko00<0ool0@ol?08;o0027o`h0A?l00`3oo`11o`l0Q?l008Wo3P12o`03
0?oo03oo3`26o`00R_l>047o00<0ool0?_l>08So002<o`h0?ol303co3P2:o`00SOl?03go00<0ool0
>_l?08_o002@o`h0>ol00`3oo`0ho`l0SOl009;o3P0io`030?oo03Ko3`2?o`00U?l=03So00<0ool0
=?l?097o002Eo`h0=_l00`3oo`0boa00T_l009Oo3P0do`030?oo033o402Do`00VOl>03;o00<0ool0
;_l@09Ko002Ko`l0;ol00`3oo`0[oa40V?l009go400/o`030?oo02Wo4@2Jo`00W_lA02[o00<0ool0
9olB09_o002Poa809ol302?o502Mo`00XOlD02Co00<0ool07olF09oo002SoaH08?l00`3oo`0JoaT0
XOl00:Go5`0Mo`030?oo01Wo602So`00Z?lI01So00<0ool05_lH0:Ko002[oa/00_l200oo00<0ool0
4OlK0:So002]ob802_l00`3oo`0<oah0Z_l00;3oE02/o`00/om;0;;o002fodD0]Ol00;Wo?`2ho`00
_Olh0;_o0030oc40_ol00<Co:P32o`00b_lP0<Ko003>o`<02?l00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl30=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003>o`<02?l00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00=7o00<0ool01Ol00`3o
o`3Do`00dOl00`3oo`05o`030?oo0=Co003?o`802?l40=?o003Ao`030?oo00Go00<0ool0e?l00=7o
00<0ool01Ol00`3oo`3Do`00cOl01@3oool000Oo00<0ool0e?l00<ko0`08o`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo0`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00fOl00`3oo`3Do`00
fOl30=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`03
0?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`030?oo0=Co003Io`<0
e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0e?l00=Wo00<0ool0
e?l00=Wo00<0ool0e?l00=3o0`06o`030?oo0=Co003Ao`030?oo00Go00<0ool0e?l00=7o00<0ool0
1Ol00`3oo`3Do`00cOl600Ko00<0ool0e?l00<ko00@0ool01ol40=?o003>o`040?oo0=ko003?o`03
0?l00=ko003?o`030?l00=ko003@o`80g_l00?oo/Ol00?oo/Ol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.1725, -4.12938, 0.0287428, 
  0.0287428}}]
}, Open  ]],

Cell["\<\
Here are the first four derivatives of the displacement function.\
\>", "Text",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["der = Table[D[ydisp, {theta, i}], {i, 0, 3}]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({1\/2\ \((1 - Cos[theta] + 1\/4\ \((\(-1\) + Cos[2\ theta])\))\), 
      1\/2\ \((Sin[theta] - 1\/2\ Sin[2\ theta])\), 
      1\/2\ \((Cos[theta] - Cos[2\ theta])\), 
      1\/2\ \((\(-Sin[theta]\) + 2\ Sin[2\ theta])\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[Release[der], {theta, 0, 2Pi}, PlotStyle->
\t{RGBColor[1,0,0], RGBColor[0,1,0], RGBColor[0,0,1],
\tRGBColor[0,.7,.2], RGBColor[0,.2,.7]}]\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 0.215148 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .09387 -12 -4.5 ]
[.01131 .09387 0 4.5 ]
[.01131 .20144 -24 -4.5 ]
[.01131 .20144 0 4.5 ]
[.01131 .41659 -18 -4.5 ]
[.01131 .41659 0 4.5 ]
[.01131 .52417 -6 -4.5 ]
[.01131 .52417 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .09387 m
.03006 .09387 L
s
[(-1)] .01131 .09387 1 0 Mshowa
.02381 .20144 m
.03006 .20144 L
s
[(-0.5)] .01131 .20144 1 0 Mshowa
.02381 .41659 m
.03006 .41659 L
s
[(0.5)] .01131 .41659 1 0 Mshowa
.02381 .52417 m
.03006 .52417 L
s
[(1)] .01131 .52417 1 0 Mshowa
.125 Mabswid
.02381 .11538 m
.02756 .11538 L
s
.02381 .1369 m
.02756 .1369 L
s
.02381 .15841 m
.02756 .15841 L
s
.02381 .17993 m
.02756 .17993 L
s
.02381 .22296 m
.02756 .22296 L
s
.02381 .24447 m
.02756 .24447 L
s
.02381 .26599 m
.02756 .26599 L
s
.02381 .2875 m
.02756 .2875 L
s
.02381 .33053 m
.02756 .33053 L
s
.02381 .35205 m
.02756 .35205 L
s
.02381 .37356 m
.02756 .37356 L
s
.02381 .39508 m
.02756 .39508 L
s
.02381 .43811 m
.02756 .43811 L
s
.02381 .45962 m
.02756 .45962 L
s
.02381 .48114 m
.02756 .48114 L
s
.02381 .50265 m
.02756 .50265 L
s
.02381 .07235 m
.02756 .07235 L
s
.02381 .05084 m
.02756 .05084 L
s
.02381 .02933 m
.02756 .02933 L
s
.02381 .00781 m
.02756 .00781 L
s
.02381 .54568 m
.02756 .54568 L
s
.02381 .56719 m
.02756 .56719 L
s
.02381 .58871 m
.02756 .58871 L
s
.02381 .61022 m
.02756 .61022 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.04011 .30902 L
.04141 .30902 L
.04262 .30902 L
.04386 .30902 L
.04521 .30902 L
.04765 .30903 L
.05003 .30903 L
.05221 .30903 L
.05459 .30904 L
.05719 .30905 L
.06244 .30907 L
.06527 .30909 L
.06795 .30911 L
.07296 .30916 L
.07836 .30924 L
.08424 .30935 L
.08936 .30947 L
.0948 .30964 L
.10458 .31005 L
.11395 .3106 L
.12405 .31141 L
.13359 .31241 L
.14233 .31355 L
.16125 .31694 L
.17198 .31947 L
.18195 .32229 L
.20241 .32953 L
.221 .33795 L
.26098 .36215 L
.29945 .39241 L
.34037 .42921 L
.37977 .46475 L
.41766 .49431 L
.4371 .5063 L
.458 .51604 L
.46813 .51945 L
Mistroke
.47348 .52089 L
.47917 .52214 L
.48465 .52306 L
.4896 .52366 L
.492 .52387 L
.49326 .52395 L
.49459 .52403 L
.49575 .52408 L
.49703 .52412 L
.49819 .52415 L
.49927 .52416 L
.50054 .52416 L
.50118 .52416 L
.50188 .52415 L
.50313 .52412 L
.5043 .52408 L
.50567 .52401 L
.50692 .52394 L
.50975 .52372 L
.51206 .52348 L
.51458 .52317 L
.51967 .52236 L
.52929 .52018 L
.53823 .51741 L
.55873 .50851 L
.57733 .49764 L
.61737 .4672 L
.65588 .43266 L
.69686 .3956 L
.73631 .36408 L
.77425 .34039 L
.79374 .33112 L
.81464 .32335 L
.8248 .32033 L
.83586 .31757 L
.84541 .31559 L
.85597 .31381 L
.86547 .31252 L
.87572 .31143 L
.88655 .31057 L
.89182 .31024 L
.89672 .30999 L
.90628 .3096 L
.91133 .30945 L
.91674 .30933 L
.92242 .30923 L
.92778 .30915 L
.9326 .30911 L
.93512 .30909 L
.93783 .30907 L
Mistroke
.94022 .30906 L
.94241 .30905 L
.94669 .30904 L
.94909 .30903 L
.9517 .30903 L
.95417 .30902 L
.95645 .30902 L
.9577 .30902 L
.95904 .30902 L
.96022 .30902 L
.96147 .30902 L
.9626 .30902 L
.96383 .30902 L
.96496 .30902 L
.96601 .30902 L
.96733 .30902 L
.96858 .30902 L
.9697 .30902 L
.97092 .30902 L
.97156 .30902 L
.97225 .30902 L
.97298 .30902 L
.97366 .30902 L
.97488 .30902 L
.97619 .30902 L
Mfstroke
0 1 0 r
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30903 L
.03395 .30903 L
.0352 .30904 L
.03746 .30906 L
.03884 .30907 L
.04016 .30908 L
.04262 .30912 L
.045 .30916 L
.04753 .30922 L
.0521 .30936 L
.05752 .3096 L
.06244 .30989 L
.06787 .31031 L
.07287 .31079 L
.08414 .31228 L
.09408 .31409 L
.10458 .31659 L
.12422 .32301 L
.14255 .33114 L
.18146 .35483 L
.22282 .38651 L
.26267 .41713 L
.28089 .42908 L
.29126 .4349 L
.301 .43956 L
.31131 .44356 L
.32077 .44628 L
.3257 .44732 L
.3282 .44774 L
.33088 .44811 L
.33358 .4484 L
.33478 .44851 L
.33608 .4486 L
.33688 .44864 L
.33762 .44868 L
.33831 .44871 L
.33907 .44873 L
.34038 .44876 L
.3411 .44876 L
.34178 .44876 L
.34303 .44874 L
.34373 .44872 L
Mistroke
.34436 .4487 L
.3456 .44865 L
.34676 .44858 L
.34937 .44836 L
.35219 .44803 L
.35469 .44765 L
.35733 .44716 L
.36207 .44607 L
.37091 .44327 L
.3806 .43905 L
.39083 .4333 L
.40015 .42694 L
.42108 .40895 L
.46098 .3629 L
.49936 .30993 L
.54019 .25362 L
.56048 .22871 L
.57951 .20851 L
.59794 .19253 L
.61731 .18005 L
.62698 .17558 L
.63209 .1737 L
.63754 .17207 L
.64257 .17089 L
.64713 .1701 L
.64934 .16982 L
.65173 .16958 L
.65282 .16949 L
.65398 .16941 L
.65497 .16936 L
.65605 .16932 L
.65735 .16929 L
.65856 .16927 L
.65988 .16928 L
.66055 .16929 L
.66128 .16931 L
.66251 .16936 L
.66384 .16943 L
.66624 .16961 L
.6686 .16986 L
.67109 .17019 L
.67554 .17095 L
.68071 .17212 L
.68552 .17346 L
.69645 .17739 L
.71688 .18763 L
.73546 .19959 L
.77541 .23011 L
.81384 .25984 L
.8333 .27312 L
Mistroke
.85473 .28551 L
.87506 .29474 L
.8941 .30108 L
.90449 .30364 L
.91436 .30552 L
.92322 .30679 L
.93289 .30779 L
.93821 .30818 L
.94322 .30847 L
.94772 .30866 L
.95258 .30882 L
.95511 .30887 L
.95789 .30892 L
.9593 .30894 L
.9608 .30896 L
.9621 .30897 L
.96351 .30899 L
.96491 .309 L
.96621 .309 L
.96745 .30901 L
.96876 .30901 L
.96994 .30901 L
.97104 .30902 L
.97225 .30902 L
.97356 .30902 L
.97484 .30902 L
.97549 .30902 L
.97619 .30902 L
Mfstroke
0 0 1 r
.02381 .30902 m
.02499 .30903 L
.02605 .30905 L
.02729 .3091 L
.02846 .30917 L
.03053 .30933 L
.03279 .30958 L
.03527 .30994 L
.0379 .31041 L
.04262 .31149 L
.05205 .31454 L
.06244 .31922 L
.0842 .33297 L
.10458 .34963 L
.14335 .38554 L
.16306 .40264 L
.17348 .41056 L
.18458 .41782 L
.19538 .42345 L
.20517 .42716 L
.2099 .42843 L
.21238 .42896 L
.21501 .4294 L
.21731 .42969 L
.21862 .42982 L
.21984 .42991 L
.22096 .42998 L
.22199 .43002 L
.22317 .43004 L
.22428 .43003 L
.22542 .43001 L
.22665 .42996 L
.22781 .42988 L
.22887 .42979 L
.23134 .42951 L
.23394 .42909 L
.23648 .42856 L
.23884 .42796 L
.24419 .42621 L
.2531 .42211 L
.26261 .41608 L
.27286 .4077 L
.28396 .39647 L
.30411 .37077 L
.34503 .30204 L
.38443 .22628 L
.42232 .15942 L
.44177 .13193 L
.45261 .11944 L
.46266 .10991 L
Mistroke
.47279 .10246 L
.47814 .09943 L
.48384 .09692 L
.48645 .09601 L
.48927 .09522 L
.49194 .09463 L
.4932 .09441 L
.49438 .09424 L
.49555 .0941 L
.4966 .094 L
.49778 .09393 L
.49903 .09388 L
.50024 .09387 L
.50155 .0939 L
.50279 .09396 L
.50394 .09405 L
.50512 .09418 L
.50636 .09434 L
.50859 .09473 L
.51098 .09528 L
.51359 .09603 L
.51828 .09777 L
.52264 .09983 L
.53261 .10616 L
.54326 .11527 L
.56464 .14032 L
.58481 .17088 L
.62332 .24119 L
.6643 .31916 L
.68469 .35385 L
.70375 .38157 L
.72205 .40283 L
.73225 .41212 L
.74169 .41902 L
.75185 .42457 L
.75721 .42672 L
.75995 .42761 L
.76291 .42841 L
.76547 .42897 L
.76783 .42939 L
.77009 .42969 L
.77122 .4298 L
.77246 .4299 L
.77317 .42995 L
.77385 .42998 L
.7751 .43002 L
.77581 .43004 L
.77646 .43004 L
.77717 .43003 L
.77793 .43002 L
Mistroke
.77918 .42997 L
.78035 .4299 L
.78164 .4298 L
.78302 .42966 L
.78556 .42931 L
.78827 .42883 L
.79313 .42766 L
.79892 .42578 L
.80417 .42366 L
.82426 .41215 L
.84352 .39718 L
.86435 .3784 L
.90537 .34113 L
.92581 .32604 L
.93579 .32015 L
.94488 .31578 L
.95264 .31287 L
.96 .31085 L
.96403 .31005 L
.96775 .30952 L
.9697 .30931 L
.97082 .30922 L
.97185 .30915 L
.97292 .30909 L
.97409 .30905 L
.97511 .30903 L
.97619 .30902 L
Mfstroke
0 .7 .2 r
.02381 .30902 m
.04262 .34855 L
.06244 .38688 L
.08255 .41892 L
.09396 .43289 L
.09905 .43798 L
.10458 .44266 L
.11004 .44636 L
.11243 .44769 L
.11508 .44894 L
.1174 .44986 L
.11989 .45065 L
.12127 .451 L
.12253 .45126 L
.12379 .45147 L
.125 .45162 L
.12617 .45172 L
.12723 .45177 L
.12845 .45179 L
.1296 .45175 L
.13067 .45168 L
.13166 .45158 L
.13274 .45143 L
.13388 .45123 L
.13627 .45066 L
.1385 .44996 L
.14357 .44773 L
.14858 .44467 L
.15402 .44038 L
.16392 .43003 L
.17356 .41693 L
.18248 .40228 L
.22175 .31394 L
.2595 .20829 L
.28047 .15007 L
.2997 .10187 L
.31974 .06047 L
.32951 .0445 L
.33839 .03275 L
.34754 .02359 L
.35257 .01989 L
.35731 .01729 L
.35982 .01628 L
.3612 .01583 L
.36248 .01548 L
.36367 .01521 L
.36475 .01502 L
.36595 .01486 L
.36725 .01475 L
.36791 .01473 L
Mistroke
.36862 .01472 L
.36989 .01475 L
.37067 .0148 L
.3714 .01487 L
.37206 .01495 L
.37277 .01506 L
.3741 .01532 L
.3755 .01567 L
.37801 .0165 L
.38057 .01761 L
.38299 .01891 L
.38752 .02197 L
.39239 .0262 L
.39769 .03188 L
.40723 .04486 L
.41604 .05993 L
.43474 .10092 L
.45536 .15826 L
.49561 .29345 L
.53435 .4274 L
.55404 .48729 L
.57554 .5411 L
.58549 .56093 L
.59611 .57812 L
.60127 .58491 L
.60613 .59036 L
.61083 .59473 L
.61522 .59801 L
.61986 .60063 L
.62233 .60166 L
.62497 .60249 L
.62629 .6028 L
.62699 .60293 L
.62773 .60305 L
.62838 .60314 L
.62909 .60321 L
.63036 .6033 L
.63157 .60332 L
.63289 .60327 L
.63413 .60317 L
.63527 .60301 L
.63635 .60282 L
.6375 .60256 L
.63956 .60196 L
.64203 .60103 L
.64426 .59998 L
.64913 .59701 L
.65374 .59336 L
.66344 .58308 L
.67373 .56858 L
Mistroke
.69217 .53423 L
.73003 .4393 L
.77033 .32538 L
.80913 .2316 L
.81924 .21274 L
.83028 .19553 L
.8407 .18277 L
.85037 .17412 L
.85545 .17083 L
.85813 .16946 L
.86095 .16827 L
.86342 .16746 L
.86473 .16711 L
.86614 .1668 L
.86743 .16658 L
.8686 .16643 L
.86979 .16632 L
.87091 .16626 L
.87198 .16625 L
.87315 .16628 L
.87439 .16635 L
.87554 .16647 L
.87662 .16663 L
.8776 .1668 L
.87982 .16731 L
.88208 .16799 L
.88455 .16893 L
.88952 .17142 L
.89481 .17492 L
.8998 .17901 L
.90915 .18861 L
.9301 .2183 L
.96859 .29286 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W00011@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3oooooooooZ?l00?ooZ?l00?ooZ?l00?ooZ?l00?oo
Z?l00?ooZ?l00?ooZ?l00?ooZ?l00?ooZ?l00?ooZ?l002So00<0ool0oommo`00:?l00`3oo`3ooggo
000Xo`030?oo0?ooOOl002So0`3ooggo000Xo`030?oo0?ooOOl002So00<0ool0oommo`00:?l00`3o
o`21o`P2lol002So00<0ool0P?l00`;oo`06o`82lOl002So00<0ool0O_l20P_o00<2ool0k_l002So
00<0ool0O?l20Pko00<2ool0kOl002So00<0ool0Nol00`;oo`0?o`030_oo0>co000Xo`<0N_l00`;o
o`0Ao`030_oo0>_o000Xo`030?oo07Wo00<2ool04ol00`;oo`3Zo`00:?l00`3oo`1ho`030_oo01Go
00<2ool0jOl002So00<0ool0Mol00`;oo`0Go`030_oo0>So000Xo`030?oo07Ko00<2ool06?l00`;o
o`3Xo`00:?l00`3oo`1fo`030_oo01Wo00<2ool0iol002So00<0ool0MOl00`;oo`0Ko`030_oo0>Ko
000Xo`030?oo07Co00<2ool07Ol00`;oo`3Uo`00:?l00`3oo`1do`030_oo01go00<2ool0iOl002So
0`1co`030_oo01oo00<2ool0i?l002So00<0ool0L_l00`;oo`0Qo`030_oo0>?o000Xo`030?oo07;o
00<2ool08Ol00`;oo`3So`00:?l00`3oo`1ao`030_oo02?o00<2ool0h_l002So00<0ool0LOl00`;o
o`0So`030_oo0>;o000Xo`030?oo073o00<2ool09Ol00`;oo`3Qo`00:?l00`3oo`1`o`030_oo02Go
00<2ool0hOl002So00<0ool0Kol00`;oo`0Wo`030_oo0>3o000Xo`<0Kol00`;oo`0Wo`030_oo0>3o
000Xo`030?oo06ko00<2ool0:Ol00`;oo`3Oo`00:?l00`3oo`1^o`030_oo02Wo00<2ool0gol002So
00<0ool0KOl00`;oo`0[o`030_oo0=ko000Xo`030?oo06go00<2ool0:ol00`;oo`3No`007_l500Go
00<0ool0K?l00`;oo`0/o`030_oo0=ko000Po`030?oo00Go00<0ool0K?l00`;oo`0]o`030_oo0=go
000Po`030?oo00Go00<0ool0Jol00`;oo`0^o`030_oo0=go000Po`030?oo00Go00<0ool0Jol00`;o
o`0_o`030_oo0=co000Eo`H01Ol00`3oo`05o`@0JOl00`;oo`0`o`030_oo01;o3?bno`008?l00`3o
o`05o`030?oo06[o00<2ool0<Ol00`;oo`0@o`03o?oo00[o00?lool0^ol0023o00<0ool01Ol00`3o
o`1Yo`030_oo03;o00<2ool03_l2o0ko0_bko`007_l300Oo00<0ool0JOl00`;oo`0bo`030_oo00co
0_`Bo`;l^Ol0023o00<0ool01Ol00`3oo`1Yo`030_oo03?o00<2ool02_l00ocoo`0Do`;l]ol002So
00<0ool0J?l00`;oo`0do`030_oo00So0_`Io`03o?oo0;Co000Xo`030?oo06So00<2ool0=?l00`;o
o`07o`03o?oo01[o00?lool0/ol002So00<0ool0Iol00`;oo`0fo`030_oo00Go00?lool07?l00oco
o`2bo`00:?l306Oo00<2ool0=_l00`;oo`03o`;l8?l00ocoo`2ao`00:?l00`3oo`1Wo`030_oo03Ko
00<2ool00_l00ocoo`0Qo`03o?oo0;3o000Xo`030?oo06Ko00<2ool0>?l010;ooo`Uo`03o?oo0:oo
000Xo`030?oo06Ko00<2ool0>?l00`;oo00Wo`03o?oo0:ko000Xo`030?oo06Go00<2ool0>Ol00`;o
o00Xo`03o?oo0:go000Xo`030?oo06Go00<2ool0>_l00`;oo`0Xo`03o?oo0:co000Xo`030?oo06Go
00<2ool0>Ol00o`2o`0Yo`03o?oo0:co000Xo`030?oo06Co00<2ool0>Ol01?coo`8Zo`03o?oo0:_o
000Xo`<0I?l00`;oo`0io`04o?oo0R_o00?lool0Z_l002So00<0ool0I?l00`;oo`0ho`05o?ooo`80
;?l00ocoo`2Yo`00:?l00`3oo`1So`030_oo03So00?lool00ol00`;oo`0Zo`03o?oo0:So000Xo`03
0?oo06?o00<2ool0=ol00ocoo`04o`030_oo02_o00?lool0Yol002So00<0ool0H_l00`;oo`0ho`03
o?oo00Co00<2ool0:ol00ocoo`2Wo`00:?l00`3oo`1Ro`030_oo03Oo00?lool01_l00`;oo`0[o`03
o?oo0:Ko000Xo`030?oo06;o00<2ool0=_l00ocoo`07o`030_oo02_o00?lool0Y_l002So00<0ool0
HOl00`;oo`0fo`03o?oo00So00<2ool0;?l00ocoo`2Uo`00:?l00`3oo`1Qo`030_oo03Ko00?lool0
2Ol00`;oo`0/o`03o?oo0:Co000Xo`<0H?l00`;oo`0fo`03o?oo00[o00<2ool0;?l00ocoo`2To`00
:?l00`3oo`1Po`030_oo03Go00?lool02ol00`;oo`0]o`03o?oo0:?o000Xo`030?oo063o00<2ool0
=Ol00ocoo`0<o`030_oo02co00?lool0Xol002So00<0ool0Gol00`;oo`0eo`03o?oo00go00<2ool0
;Ol00ocoo`1[o`P2;ol002So00<0ool0Gol00`;oo`0eo`03o?oo00go00<2ool0;Ol00ocoo`0Go`[j
B?l20PSo00<2ool0;?l002So00<0ool0G_l00`;oo`0eo`03o?oo00oo00<2ool0;Ol00ocoo`0Bo`Cj
2_l4nT?o00<2ool02Ol20Rco000Xo`030?oo05ko00<2ool0=Ol00ocoo`0?o`030_oo02ko00?lool0
3Ol4nQ;o0oXno`823_l20R[o000Xo`030?oo05ko00<2ool0=?l00ocoo`0@o`030_oo02ko00?lool0
2ol2nQWo0oXjo`030_oo013o00<2ool09ol002So0`1Mo`030_oo03Co00?lool04Ol00`;oo`0_o`03
o?oo00So0_XNo`;j=_l20QCo00<2ool09_l002So00<0ool0GOl00`;oo`0do`03o?oo01;o00<2ool0
;_l00ocoo`06o`;j8_l2nS?o00<2ool05Ol00`;oo`0Uo`00:?l00`3oo`1Mo`030_oo03?o00?lool0
4ol00`;oo`0_o`03o?oo00Co00?jool09?l2nS3o00<2ool05ol20RGo000Xo`030?oo05co00<2ool0
=?l00ocoo`0Co`030_oo02oo00?lool00ol00o[oo`0Wo`;j;Ol00`;oo`0Jo`030_oo02;o000Xo`03
0?oo05co00<2ool0<ol00ocoo`0Eo`030_oo02oo00?lool00_X/o`;j:ol00`;oo`0Ko`030_oo027o
000>o`@01Ol200Go1006o`030?oo05_o00<2ool0<ol00ocoo`0Fo`030_oo02oo00?looX0<?l00o[o
o`0Wo`030_oo01co00<2ool08Ol000go00<0ool00_l00`3oo`02o`801?l00`3oo`02o`030?oo00?o
00<0ool0Fol00`;oo`0co`03o?oo01Ko00<2ool0<?l00ocoo`0`o`03n_oo02Go00<2ool07_l00`;o
o`0Po`003Ol00`3oo`02o`030?oo00go00<0ool00ol00`3oo`1Ko`030_oo03;o00?lool06?l00`;o
o`0]o`;j00?oo?l0<Ol2nRCo00<2ool08?l00`;oo`0Oo`003Ol00`3oo`02o`030?oo00go00<0ool0
0ol405Wo00<2ool0<ol00ocoo`0Ho`030_oo02co00Gjooooo00do`03n_oo027o00<2ool08?l00`;o
o`0Oo`001Ol600;o00<0ool00_l00`3oo`0=o`030?oo00?o00<0ool0F_l00`;oo`0bo`03o?oo01Wo
00<2ool0:ol00o[oo`03o`03o?oo03;o00?jool07ol00`;oo`0Ro`030_oo01ko000=o`030?oo00;o
00<0ool02Ol400Ko00<0ool0FOl00`;oo`0co`03o?oo01[o00<2ool0:?l2nPKo00?lool0<ol2nQoo
00<2ool08ol00`;oo`0Mo`003Ol00`3oo`02o`030?oo00Wo00<0ool01ol00`3oo`1Io`030_oo03;o
00?lool06ol00`;oo`0Wo`03n_oo00Oo00?lool0=?l00o[oo`0Ko`030_oo02Co00<2ool07Ol000go
00<0ool00_l00`3oo`09o`030?oo00Oo00<0ool0FOl00`;oo`0ao`03o?oo01co00<2ool09_l00o[o
o`08o`03o?oo03Go00?jool06_l00`;oo`0Uo`030_oo01co000>o`@03?l500Go00<0ool0F?l00`;o
o`0bo`03o?oo01co00<2ool09Ol00o[oo`0:o`03o?oo03Go0_XIo`030_oo02Oo00<2ool06ol002So
00<0ool0F?l00`;oo`0ao`03o?oo01ko00<2ool08ol00o[oo`0;o`03o?oo03Oo00?jool05Ol00`;o
o`0Xo`030_oo01_o000Xo`030?oo05So00<2ool0<Ol00ocoo`0No`030_oo02;o00?jool03Ol00oco
o`0go`03n_oo01Co00<2ool0:Ol00`;oo`0Jo`00:?l00`3oo`1Go`030_oo037o00?lool07ol00`;o
o`0Ro`03n_oo00ko00?lool0=ol2nQ?o00<2ool0:ol00`;oo`0Io`00:?l305Oo00<2ool0<Ol00oco
o`0Po`030_oo023o00?jool03ol00ocoo`0io`03n_oo013o00<2ool0:ol00`;oo`0Io`00:?l00`3o
o`1Go`030_oo033o00?lool08Ol00`;oo`0Oo`03n_oo017o00?lool0>Ol00o[oo`0>o`030_oo02go
00<2ool06?l002So00<0ool0E_l00`;oo`0`o`03o?oo02;o00<2ool07_l00o[oo`0Bo`03o?oo03[o
0_X>o`030_oo02go00<2ool06?l002So00<0ool0E_l00`;oo`0`o`03o?oo02?o00<2ool07?l00o[o
o`0Do`03o?oo03_o00?jool02_l00`;oo`0_o`030_oo01Oo000Xo`030?oo05Ko00<2ool0;ol00oco
o`0To`030_oo01_o00?jool05Ol00ocoo`0lo`;j2_l00`;oo`0_o`030_oo01Oo000Xo`030?oo05Go
00<2ool0<?l00ocoo`0To`030_oo01_o00?jool05_l00ocoo`0mo`03n_oo00Ko00<2ool0<Ol00`;o
o`0Fo`00:?l00`3oo`1Eo`030_oo02oo00?lool09_l00`;oo`0Io`03n_oo01Oo00?lool0?_l00o[o
o`05o`030_oo037o00<2ool05_l002So00<0ool0EOl00`;oo`0_o`03o?oo02Ko00<2ool06?l00o[o
o`0Io`03o?oo03ko0_X4o`030_oo03?o00<2ool05Ol002So0`1Do`030_oo02oo00?lool09ol00`;o
o`0Go`03n_oo01_o00?lool0?ol01O[oool203Go00<2ool05Ol002So00<0ool0E?l00`;oo`0_o`03
o?oo02Oo00<2ool05_l00o[oo`0Lo`03o?oo043o00Cjool2=_l00`;oo`0Do`00:?l00`3oo`1Do`03
0_oo02ko00?lool0:Ol00`;oo`0Eo`03n_oo01go00?lool0@?l00oX2o`0fo`030_oo01Co000Xo`03
0?oo05?o00<2ool0;ol00ocoo`0Yo`030_oo01Co00?jool07_l00ocoo`11o`030_[o03Ko00<2ool0
4ol002So00<0ool0Dol00`;oo`0^o`03o?oo02[o00<2ool04ol00o[oo`0Po`03o?oo03oo00@2oooj
=_l00`;oo`0Co`00:?l00`3oo`1Co`030_oo02ko00?lool0:ol00`;oo`0Ao`03n_oo027o00?lool0
?ol010;oool2nSGo00<2ool04_l002So00<0ool0D_l00`;oo`0^o`03o?oo02co00<2ool04Ol00o[o
o`0Ro`03o?oo03ko00<2ool00ol00o[oo`0bo`030_oo01;o000Xo`030?oo05;o00<2ool0;_l00oco
o`0/o`030_oo013o00?jool08ol00ocoo`0mo`030_oo00Go0_Xco`030_oo017o000Xo`030?oo057o
00<2ool0;_l00ocoo`0^o`030_oo00ko00?jool09Ol00ocoo`0lo`030_oo00Oo00?jool0<?l00`;o
o`0Ao`00:?l303Oo1@0Eo`030_oo01go1@0<o`03o?oo02So0`03o`030_oo00go00?jool09?l20003
o?oo03Co1003o`030_oo00Wo00?jool09_l300Oo00<2ool04?l002So00<0ool0>Ol00`3oo`0Eo`03
0_oo01go00D0oooo000;o`03o?oo02So00D0oooo0002o`030_oo00go00?jool09Ol00`3oo00do`03
0?oo00;o00@0ool23?l2nRGo00D0oooo0006o`030_oo013o000Xo`030?oo03Wo00<0ool05?l00`;o
o`0Oo`030?oo00co00?lool0;?l01@3oool200go00?jool09_l00`3oo00io`040?oo0Pko00?jool0
8_l01@3oool000Oo00<2ool03ol002So00<0ool0>Ol00`3oo`0Do`030_oo023o00<0ool02_l00oco
o`0]o`050?ooo`803?l00o[oo`0So`H000?oo?l0=ol00`3o0P0@o`;j8_l01@3oool000Oo00<2ool0
3ol002So00<0ool0>Ol00`3oo`0Do`030_oo027o00<0ool02Ol00ocoo`0[o`801?l00`;oo`09o`03
n_oo02Go00@0ool00_l00ocoo`0fo`030?l201;o0_XPo`@02Ol00`;oo`0>o`00:?l00`3oo`0io`03
0?oo01?o00<2ool08_l00`3oo`08o`03o?oo02ko00D0oooo0P0;o`03n_oo02Go00@0ool00ol00oco
o`0ao`@000?o0_l05?l2nQko00<0ool02_l00`;oo`0>o`00:?l00`3oo`0io`030?oo01?o00<2ool0
8ol00`3oo`07o`03o?oo02ko00<0ool00_l00`;oo`07o`03n_oo02Oo00<0o`001?l00ocoo`0`o`03
0?oo00;o00<2ool05Ol2nQco00<0ool02ol00`;oo`0=o`00:?l00`3oo`0go`<05Ol00`;oo`0Oo`05
0?ooo`002?l00ocoo`0[o`050?ooo`001?l00`;oo`06o`03n_oo02So00<0o`001?l00ocoo`0`o`05
0?ooo`806_l00o[oo`0Jo`030?oo00[o00<2ool03Ol002So0`0io`030?oo01;o00<2ool08Ol300Wo
00?lool0;?l300Go00<2ool01_l00o[oo`0Yo`801Ol00ocoo`0_o`@000<2ool06Ol2nQ_o0`0:o`03
0_oo00co000Xo`030?oo04ko00<2ool0;?l00ocoo`0fo`030_oo00Co00?jool0<Ol00ocoo`0co`03
0_oo01_o0_XVo`030_oo00co000Xo`030?oo04ko00<2ool0;?l00ocoo`0fo`030_oo00?o00?jool0
<ol00ocoo`0ao`030_oo01ko0_XUo`030_oo00_o000Xo`030?oo04go00<2ool0;?l00ocoo`0go`03
0_oo00;o00?jool0=?l00ocoo`0ao`030_oo023o0oXSo`030_oo00[o000Xo`030?oo04go00<2ool0
;?l00ocoo`0ho`050_ooooX0=ol00ocoo`0_o`030_oo02Co1?XOo`030_oo00[o000Xo`030?oo04go
00<2ool0:ol00ocoo`0io`040_oonSSo00?lool0;ol00`;oo`0Xo`?j7Ol00`;oo`09o`00:?l00`3o
o`1<o`030_oo02co00?lool0>Ol00`;onP0jo`03o?oo02ko00<2ool0:ol4nQWo00<2ool02Ol002So
00<0ool0C?l00`;oo`0[o`03o?oo03[o00<2n_l0>_l00ocoo`0]o`030_oo033o1?XFo`030_oo00So
000Oo`T000@2n_[j1_U500030P0002/000?l0000>`000`80000j0003o00002`000<20000=00FnP03
0P0000P0000Xo`0300;l00Kl3OXDn@Ko00<0ool02Ol00`3oo`08o`030?oo00Co00<2ool00_l00`3o
o`09o`030?oo00Wo00<0ool02Ol00`3oo`02o`03o?oo00Co00<0ool02?l00`3oo`09o`030?oo00Wo
00<0ool02Ol00`3oo`05o`05nP;oo`002ol00`3oo`08o`030?oo00Wo00<0ool02Ol00`3oo`08o`03
o03o00[o00<0ool02Ol00`3oo`08o`030?oo00Oo00<2o`002ol00`3oo`09o`030?oo00Wo8?T00ool
o006o0Ko00<0ool00Ol002So00<00_l01_l2o003o`3o00So2?X6o`030?oo00?o1oT;o`030?oo00So
00<0ool01?l00`;oo`02o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00;o00?lool01?l00`3o
o`08o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Co00?jo`800_l00`3oo`09o`030?oo00So
00<0ool02Ol00`3oo`09o`030?oo00Wo00?lool02Ol00`3oo`09o`030?oo00So00<0ool01ol00`;o
000;o`030?oo00Wo00@0oooo2?T00`3oo`09o`030?oo00So00<0ool01?l3o0;o00<0ool02Ol00`3o
o`01o`00:?l00`3o0P08o`;l4Ol4nPoo1?T7o`030?oo00oo00<2ool09_l01@3ooool03Ko00<0ool0
1?l01?[oo`8`o`030?oo00Wo00?lool0:_l00`;o000Go`Ci7ol00`3oo`02o`;l5Ol002So00<0o`80
2_l3o1;o0_XAo`?i5Ol00`;oo`0Zo`03o?oo03_o00Gjoooo0P0mo`03o?oo02So00<2ool05?l4nBKo
0_`Go`00:?l0103oo`8<o`;l4_l3nQ7o1?TAo`030_oo02[o00?lool0>_l00o[oo`02o`030_oo03co
00?lool09ol00`;oo`0@o`Ci:?l2o1Wo000Xo`040?oo0Pko00?lool04_l3nQ;o1?T<o`030_oo02[o
00?lool0>_l00o[oo`03o`030_oo03co00?lool09_l00`;oo`0=o`Ci:_l2o1_o000Xo`050?ooo`80
3_l2o1Go0_XDo`;i2_l00`;oo`0Zo`03o?oo03[o00?jool01?l00`;oo`0lo`03o?oo02Go00<2ool0
2ol2nBgo00?lool06ol002So00D0oooo0P0@o`03o?oo01Co0_XDo`?i1_l00`;oo`0Zo`03o?oo03[o
00?jool01Ol00`;oo`0lo`03o?oo02Go00<2ool02?l3nBko00?lool07?l002So0`02o`030_oo00ko
0_`Fo`;j5Ol3n@?o00<2ool0:Ol00ocoo`0jo`03n_oo00Ko00<2ool0?Ol00ocoo`0So`030_oo00Oo
0_T_o`;l7ol002So00<0ool00_l00`;oo`0@o`03o?oo01Go0_XFo`;i00<2ool0:_l00ocoo`0jo`03
n_oo00Oo00<2ool0??l00ocoo`0So`030_oo00Go0_T`o`03o?oo01oo000Xo`030?oo00?o00<2ool0
4?l00ocoo`0Fo`;j5_l00`;io`0Yo`03o?oo03[o00?jool02?l00`;oo`0mo`03o?oo02;o00<2ool0
0ol2nC7o00?lool08?l002So00<0ool00ol00`;oo`0Ao`;l6?l00o[oo`0Bo`030_oo00;i:?l00oco
o`0io`03n_oo00Wo00<2ool0?_l00ocoo`0Po`030_oo00;o0_Tao`;l8ol002So00<0ool01?l00`;o
o`0Bo`03o?oo01Ko0_XBo`030_oo00;o0_TUo`03o?oo03Wo00?jool02_l00`;oo`0no`03o?oo023o
00<2ool00_Tbo`03o?oo02?o000Xo`030?oo00Co00<2ool04ol00ocoo`0Go`;j4?l00`;oo`04o`;i
8ol00ocoo`0io`03n_oo00_o00<2ool0?_l00ocoo`0No`040_oinC?o00?lool09?l002So00<0ool0
1Ol00`;oo`0Co`;l6Ol00o[oo`0<o`030_oo00Oo0_TPo`03o?oo03Wo00?jool03?l00`;oo`0no`03
o?oo01ko00<2nOl0<ol00ocoo`0Uo`00:?l00`3oo`05o`030_oo01Go00?lool05ol2nPco00<2ool0
2Ol00oWoo`0Lo`03o?oo03Wo00?jool03Ol00`;oo`0oo`03o?oo01co00?i0_l0<ol00ocoo`0Vo`00
:?l300Go00<2ool05_l00ocoo`0Ho`;j2Ol00`;oo`0;o`;i7?l00ocoo`0io`03n_oo00ko00<2ool0
?_l00ocoo`0Ko`03n@;o03?o00?lool09ol002So00<0ool01_l00`;oo`0Fo`03o?oo01Wo00?jool0
1_l00`;oo`0=o`;i6Ol00ocoo`0io`03n_oo00oo00<2ool0?ol00ocoo`0Ho`;i00?o0_l0<_l00oco
o`0Xo`00:?l00`3oo`06o`030_oo01Oo00?lool06Ol00o[oo`04o`030_oo013o0_TGo`03o?oo03So
00?jool04?l00`;oo`10o`03o?oo01Go0_T3o`030_oo033o00?lool0:Ol002So00<0ool01ol00`;o
o`0Go`03o?oo01Wo0_X4o`030_oo01;o0_TDo`03o?oo03So00?jool04Ol00`;oo`10o`03o?oo01Co
00?iool00_l00`;oo`0`o`03o?oo02[o000Xo`030?oo00Oo00<2ool06?l00ocoo`0Jo`04n_oo0QOo
00?iool04?l00ocoo`0io`03n_oo01;o00<2ool0@?l00ocoo`0Ao`;i1Ol00`;oo`0^o`;l;Ol002So
00<0ool02?l00`;oo`0Ho`03o?oo01[o00?jo`806?l00oWoo`0?o`03o?oo03So00?jool04ol00`;o
o`11o`03o?oo00oo00?iool01Ol00`;oo`0]o`03o?oo02go000Xo`030?oo00So00<2ool06Ol2o1_o
00<2ool06?l2n@ko00?lool0>?l00o[oo`0Do`030_oo04;o00?lool03Ol00oWoo`05o`030_oo02go
00?lool0;_l002So00<0ool02Ol00`;oo`0Jo`03o?oo01So00<2n_l06_l00oWoo`0;o`03o?oo03Oo
00?jool05Ol00`;oo`12o`03o?oo00_o0_T8o`030_oo02co00?lool0;ol002So00<0ool02Ol00`;o
o`0Ko`03o?oo01Ko00<2ool00_XJo`03nOoo00Wo00?lool0=ol00o[oo`0Go`030_oo04;o00?lool0
2Ol00oWoo`07o`030_oo02co00?lool0<?l002So0`0:o`030_oo01_o00?lool05Ol00`;oo`02o`03
n_oo01So00?iool01ol00ocoo`0go`03n_oo01So00<2ool0@ol00ocoo`07o`03nOoo00So00<2ool0
:ol00ocoo`0ao`00:?l00`3oo`0:o`030_oo01co00?lool05?l00`;oo`03o`03n_oo01So0_T6o`03
o?oo03So00?jool06?l00`;oo`14o`03o?oo00Co0_T;o`030_oo02[o00?lool0<_l002So00<0ool0
2ol00`;oo`0Lo`03o?oo01;o00<2ool01Ol00o[oo`0Io`03nOoo00?o00?lool0=ol00o[oo`0Jo`03
0_oo04?o00?lool00ol00oWoo`0:o`030_oo02[o00?lool0<ol002So00<0ool02ol00`;oo`0Mo`03
o?oo017o00<2ool01_l2nQ[o00Giooooo00io`03n_oo01_o00<2ool0A?l01Ocooooi00go00<2ool0
:Ol00ocoo`0do`00:?l00`3oo`0<o`030_oo01go00?lool03ol00`;oo`09o`03n_oo01So00?ioo`0
>Ol00o[oo`0Lo`030_oo04Go00?lnOT03_l00`;oo`0Wo`;l=ol002So00<0ool03?l00`;oo`0No`03
o?oo00ko00<2ool02_l00o[oo`0Ho`03o?Wo03Oo00?jool07Ol00`;oo`15o`03nOco00go00<2ool0
9ol00ocoo`0go`00:?l00`3oo`0=o`030_oo01ko00?lool03?l00`;oo`0<o`03n_oo01Ko00Cloooi
=_l00o[oo`0Oo`030_oo04?o00Cioool3Ol00`;oo`0Vo`03o?oo03So000Xo`030?oo00go00<2ool0
7ol00ocoo`0;o`030_oo00go0_XFo`05o?ooooT0=?l00o[oo`0Po`030_oo047o0_T4o`03o?oo00[o
00<2ool09?l2o3_o000Xo`<03_l00`;oo`0Oo`;l2_l00`;oo`0@o`03n_oo01;o00?lool00ol00oWo
o`0`o`03n_oo027o00<2ool0@?l00oWoo`04o`03o?oo00Wo00<2ool09?l00ocoo`0ko`00:?l00`3o
o`0?o`030_oo023o00?lool01ol00`;oo`0Ao`03n_oo013o00?lool01Ol00oWoo`0^o`03n_oo02?o
00<2ool0?_l00oWoo`06o`03o?oo00So00<2ool08ol00ocoo`0lo`00:?l00`3oo`0?o`030_oo027o
00?lool01Ol00`;oo`0Co`;j3ol00ocoo`07o`03nOoo02go00?jool08ol00`;oo`0mo`03nOoo00So
00?lool01_l00`;oo`0So`03o?oo03go000Xo`030?oo013o00<2ool08Ol00ocoo`04o`030_oo01Go
00?jool02ol00ocoo`09o`;i;?l00o[oo`0To`030_oo03co00?iool02_l00ocoo`05o`030_oo02;o
00?lool0?_l002So00<0ool04Ol00`;oo`0Qo`03o?oo00;o00<2ool05ol00o[oo`09o`03o?oo00co
00?iool0:?l00o[oo`0Uo`030_oo03_o00?iool03?l00ocoo`04o`030_oo023o0_a1o`003_l400Go
0P05o`@01_l00`3oo`0Ao`030_oo02;o0_`2o`030_oo01So0_X8o`03o?oo00ko00?iool09_l00o[o
o`0Wo`030_oo03Wo00?iool03_l00ocoo`02o`030_oo023o00?lool0@Ol000go00<0ool00_l00`3o
o`02o`801?l00`3oo`02o`030?oo00?o00<0ool04_l00`;oo`0So`03o0;o01co00?jool01?l00oco
o`0@o`03nOoo02Co00?jool0:?l00`;oo`0ho`03nOoo013o00Gloooo0P0Qo`03o?oo04;o000=o`03
0?oo00;o00<0ool03Ol00`3oo`03o`030?oo01?o00<2ool08ol00`;oo`0Lo`04n_ooo`;l5?l00oWo
o`0Ro`03n_oo02Wo00<2ool0=ol00oWoo`0Bo`04o?oo0R3o00?lool0@ol000go00<0ool00_l00`3o
o`0=o`030?oo00?o100Bo`030_oo02;o00@2oocl7Ol2nP03o?oo01Go00?iool08?l00o[oo`0[o`03
0_oo03Co0_TFo`03o0;o01ko0_a6o`003Ol00`3oo`02o`030?oo00go00<0ool00ol00`3oo`0Do`03
0_oo027o00D2ooooo00Mo`03o?[o01Oo00?iool07_l00o[oo`0/o`030_oo03?o00?iool05ol00`;l
o00Ko`;lB?l000go00<0ool00_l00`3oo`09o`@01_l00`3oo`0Eo`030_oo01oo00<2ool00ol2o1Wo
0_`2o`;j5ol2nAco0_X_o`030_oo03;o00?iool06?l010;ooo`Ho`;lB_l000go00<0ool00_l00`3o
o`09o`030?oo00Oo00<0ool05_l00`;oo`0Mo`030_oo00Ko0_`Eo`;l1_l2nQOo00?iool06?l00o[o
o`0_o`030_oo037o00?iool06?l00`;oo`02o`;l5?l2o4co000=o`030?oo00;o00<0ool02Ol00`3o
o`07o`030?oo01Oo00<2ool07?l00`;oo`08o`;l4?l3o0[o0_XFo`03nOoo01Ko00?jool0<Ol00`;o
o`0_o`03nOoo01Wo00<2ool01?l3o0oo0_a>o`003_l400co1@05o`030?oo01Oo00<2ool06ol00`;o
o`0;o`Kl1_l4o0oo00?jool05?l00oWoo`0Do`03n_oo03;o00<2ool0;_l00oWoo`0Io`030_oo00So
1?`6o`GlD?l002So00<0ool06?l00`;oo`0Io`030_oo01;o1_`Do`03n_oo01Co00?iool04Ol2nSGo
00<2ool0;Ol00oWoo`0Jo`030_oo00co1_aEo`00:?l00`3oo`0Io`030_oo01Oo00<2ool0;_l2nQGo
00?iool03ol00o[oo`0fo`030_oo02_o00?iool06ol00`;oo`1Wo`00:?l00`3oo`0Jo`030_oo01Go
00<2ool0<Ol2nQCo00?iool03?l2nSWo00<2ool0:_l00oWoo`0Ko`030_oo06So000Xo`<06ol00`;o
o`0Co`030_oo03Co0oXBo`03nOoo00Wo0_Xko`030_oo02Wo00?iool07?l00`;oo`1Xo`00:?l00`3o
o`0Lo`030_oo017o00<2ool0>?l2nQ7o00?iool01_l2nSko00<2ool09_l2nAoo00<2ool0J?l002So
00<0ool07Ol00`;oo`0>o`82?Ol3nPoo00?iool00_l3nT3o00<2ool09Ol00oWoo`0No`030_oo06Wo
000Xo`030?oo01ko0P8=o`030_oo043o1?X<o`Cj@ol00`;oo`0To`03nOoo01oo00<2ool0JOl002So
00<0ool08?l30PWo00<2ool0AOl<nP;o00?iool0@_l00`;oo`0So`03nOoo01oo00<2ool0J_l002So
00<0ool08ol90UOo00?iool0@_l00`;oo`0Qo`03nOoo023o00<2ool0J_l002So00<0ool0Q?l00oWo
o`11o`030_oo023o00?iool08Ol00`;oo`1Zo`00:?l00`3oo`25o`03nOoo043o00<2ool07ol00oWo
o`0Qo`030_oo06_o000Xo`<0Q_l00oWoo`10o`030_oo01co0_TTo`030_oo06_o000Xo`030?oo08Oo
00?iool0?ol00`;oo`0Ko`03nOoo02?o00<2ool0K?l002So00<0ool0R?l00oWoo`0no`030_oo01[o
00?iool09?l00`;oo`1/o`00:?l00`3oo`29o`03nOoo03ko00<2ool06?l00oWoo`0Uo`030_oo06co
000Xo`030?oo08[o0_Tno`030_oo01Oo00?iool09Ol00`;oo`1]o`00:?l00`3oo`2<o`03nOoo03_o
00<2ool05Ol2nBSo00<2ool0KOl002So00<0ool0SOl00oWoo`0jo`030_oo01Co00?iool09ol00`;o
o`1^o`00:?l00`3oo`2>o`03nOoo03[o00<2ool04_l00oWoo`0Xo`030_oo06ko000Xo`030?oo08oo
0_Tjo`030_oo013o0_T[o`030_oo06ko000Xo`<0TOl00oWoo`0go`030_oo00oo00?iool0:_l00`;o
o`1_o`00:?l00`3oo`2Bo`03nOoo03Oo00<2ool03Ol00oWoo`0[o`030_oo06oo000Xo`030?oo09?o
00?iool0=_l00`;oo`0;o`;i;Ol00`;oo`1`o`00:?l00`3oo`2Do`;i=_l00`;oo`0:o`03nOoo02go
00<2ool0L?l002So00<0ool0U_l00oWoo`0do`030_oo00So00?iool0;Ol00`;oo`1ao`00:?l00`3o
o`2Go`03nOoo03?o00<2ool01_l2nC3o00<2ool0LOl002So00<0ool0V?l2nCCo00<2ool01?l00oWo
o`0`o`030_oo077o000Xo`030?oo09[o00?iool0<Ol00`;oo`02o`;i<_l00`;oo`1bo`00:?l309_o
0_Tbo`040_oinCCo00<2ool0L_l002So00<0ool0WOl2nC3o00<2nOl0=?l00`;oo`1co`00:?l00`3o
o`2Oo`;i;Ol00oT2o`0eo`030_oo07?o000Xo`030?oo0:7o0_TYo`;i0_l00`;oo`0co`030_oo07?o
000Xo`030?oo0:?o0oTTo`;i1?l00`;oo`0bo`030_oo07Co000No`D01Ol00`3oo`2Vo`;i8?l2n@Oo
00<2ool0<Ol00`;oo`1do`008?l00`3oo`05o`030?oo0:So0_TKo`?i2Ol00`;oo`0`o`030_oo07Go
000Po`030?oo00Go00<0ool0Z_l4nACo0oT=o`030_oo02oo00<2ool0MOl0023o00<0ool01Ol40:go
5?T@o`030_oo02oo00<2ool0MOl0023o00<0ool01Ol00`3oo`3Bo`030_oo02ko00<2ool0M_l0023o
00<0ool01Ol00`3oo`3Co`030_oo02go00<2ool0M_l0023o00<0ool01Ol00`3oo`3Co`030_oo02co
00<2ool0Mol001ko0`07o`030?oo0=Co00<2ool0:ol00`;oo`1go`008?l00`3oo`05o`030?oo0=Co
00<2ool0:_l00`;oo`1ho`00:?l00`3oo`3Eo`030_oo02Wo00<2ool0N?l002So00<0ool0eOl00`;o
o`0Xo`030_oo07Wo000Xo`030?oo0=Ko00<2ool09ol00`;oo`1io`00:?l30=Ko00<2ool09_l00`;o
o`1jo`00:?l00`3oo`3Go`030_oo02Go00<2ool0N_l002So00<0ool0eol00`;oo`0To`030_oo07_o
000Xo`030?oo0=So00<2ool08ol00`;oo`1ko`00:?l00`3oo`3Ho`030_oo02;o00<2ool0O?l002So
00<0ool0fOl00`;oo`0Qo`030_oo07co000Xo`030?oo0=Wo00<2ool08?l00`;oo`1mo`00:?l00`3o
o`3Jo`030_oo01oo00<2ool0OOl002So0`3Jo`030_oo01ko00<2ool0O_l002So00<0ool0fol00`;o
o`0Mo`030_oo07ko000Xo`030?oo0=_o00<2ool07?l00`;oo`1oo`00:?l00`3oo`3Lo`030_oo01[o
00<2ool0P?l002So00<0ool0g?l00`;oo`0Jo`030_oo083o000Xo`030?oo0=go00<2ool06?l00`;o
o`21o`00:?l00`3oo`3No`030_oo01Ko00<2ool0P_l002So00<0ool0gol00`;oo`0Do`030_oo08?o
000Xo`030?oo0>3o00<2ool04_l00`;oo`24o`00:?l30>7o00<2ool04Ol00`;oo`24o`00:?l00`3o
o`3Ro`030_oo00oo00<2ool0QOl002So00<0ool0hol00`;oo`0=o`030_oo08Ko000Xo`030?oo0>Co
00<2ool02ol00`;oo`27o`00:?l00`3oo`3Uo`822Ol20X[o000Xo`030?oo0>Oo2@:<o`00:?l00`3o
o`3ooggo000Xo`030?oo0?ooOOl002So0`3ooggo000Xo`030?oo0?ooOOl002So00<0ool0oommo`00
:?l00`3oo`3ooggo003oojSo003oojSo003oojSo003oojSo003oojSo003oojSo003oojSo003oojSo
003oojSo0000\
\>"],
  ImageRangeCache->{{{0, 422}, {260, 0}} -> {-0.69084, -1.5477, 0.0253477, 
  0.0178579}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Section",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["BeginPackage[\"Cam`\"]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \("Cam`"\)], "Output"]
}, Open  ]],

Cell["\<\
SubCamPlot[r0_, y_, theta_, phi_] :=
\tBlock[{u, v, yp, cosphi = Cos[phi], sinphi = Sin[phi]},
\t\typ = D[y, theta] ;
\t\tu = (r0 + y) Sin[theta] + yp Cos[theta] ;
\t\tv = (r0 + y) Cos[theta] + yp Sin[theta] ;
\t\tParametricPlot[{u cosphi + v sinphi,
\t\t\t\t\t\tv cosphi - u sinphi},
\t\t\t\t\t   {theta, 0, 2Pi},
\t\t\t\t\t   PlotStyle->Thickness[.02],
\t\t\t\t\t   AspectRatio->Automatic,
\t\t\t\t\t   PlotRange -> { {-4,4}, {-4,4} }
\t\t\t\t\t  ]
\t\t ]\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["CamPlot[r0_, y_, theta_] := SubCamPlot[r0,y,theta,0]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SpinCam[r0_, y_, theta_, Nsteps_] :=
\tDo[ SubCamPlot[r0,y,theta,2Pi i/Nsteps], {i,Nsteps}]\
\>", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["EndPackage[ ]", "Input",
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{964, 614},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 87, 2, 155, "Title"],

Cell[CellGroupData[{
Cell[1843, 57, 90, 2, 79, "Section"],
Cell[1936, 61, 391, 7, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2364, 73, 100, 2, 79, "Section"],

Cell[CellGroupData[{
Cell[2489, 79, 98, 2, 68, "Subsection"],
Cell[2590, 83, 188, 5, 47, "Text"],
Cell[2781, 90, 460, 16, 74, "Text"],

Cell[CellGroupData[{
Cell[3266, 110, 112, 2, 41, "Input"],
Cell[3381, 114, 60, 1, 43, "Output"]
}, Closed]],
Cell[3456, 118, 162, 5, 47, "Text"],

Cell[CellGroupData[{
Cell[3643, 127, 120, 2, 41, "Input"],
Cell[3766, 131, 175, 3, 60, "Message"],
Cell[3944, 136, 101, 2, 61, "Output"]
}, Closed]],
Cell[4060, 141, 135, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[4220, 147, 107, 2, 41, "Input"],
Cell[4330, 151, 91, 1, 56, "Output"]
}, Closed]],
Cell[4436, 155, 192, 6, 73, "Text"],

Cell[CellGroupData[{
Cell[4653, 165, 167, 5, 64, "Input"],
Cell[4823, 172, 124, 2, 56, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4984, 179, 107, 2, 41, "Input"],
Cell[5094, 183, 127, 2, 56, "Output"]
}, Closed]],
Cell[5236, 188, 149, 4, 47, "Text"],
Cell[5388, 194, 134, 2, 41, "Input"],
Cell[5525, 198, 134, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[5684, 204, 136, 2, 41, "Input"],
Cell[5823, 208, 14016, 419, 273, 4199, 293, "GraphicsData", 
"PostScript", "Graphics"],
Cell[19842, 629, 130, 3, 41, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20021, 638, 100, 2, 42, "Subsection"],
Cell[20124, 642, 269, 7, 73, "Text"],
Cell[20396, 651, 85, 2, 41, "Input"],
Cell[20484, 655, 85, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[20594, 661, 94, 2, 41, "Input"],
Cell[20691, 665, 274, 7, 41, "Output"]
}, Closed]],
Cell[20980, 675, 89, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[21094, 681, 99, 2, 41, "Input"],
Cell[21196, 685, 621, 16, 43, "Output"]
}, Closed]],
Cell[21832, 704, 81, 2, 47, "Text"],

Cell[CellGroupData[{
Cell[21938, 710, 99, 2, 41, "Input"],
Cell[22040, 714, 1113, 30, 43, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23202, 750, 97, 2, 42, "Subsection"],
Cell[23302, 754, 85, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[23412, 760, 124, 2, 41, "Input"],
Cell[23539, 764, 196, 3, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[23772, 772, 169, 5, 64, "Input"],
Cell[23944, 779, 373, 6, 144, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[24354, 790, 104, 2, 41, "Input"],
Cell[24461, 794, 157, 2, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[24655, 801, 97, 2, 41, "Input"],
Cell[24755, 805, 130, 2, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24934, 813, 95, 2, 42, "Subsection"],
Cell[25032, 817, 155, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[25212, 825, 85, 2, 41, "Input"],
Cell[25300, 829, 175, 3, 60, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25512, 837, 174, 5, 64, "Input"],
Cell[25689, 844, 100, 2, 56, "Output"]
}, Open  ]],
Cell[25804, 849, 114, 5, 73, "Text"],

Cell[CellGroupData[{
Cell[25943, 858, 101, 2, 41, "Input"],
Cell[26047, 862, 18474, 635, 444, 5791, 474, "GraphicsData", 
"PostScript", "Graphics"],
Cell[44524, 1499, 130, 3, 41, "Output"]
}, Open  ]],
Cell[44669, 1505, 220, 7, 99, "Text"],

Cell[CellGroupData[{
Cell[44914, 1516, 210, 5, 41, "Input"],
Cell[45127, 1523, 18709, 647, 444, 6010, 486, "GraphicsData", 
"PostScript", "Graphics"],
Cell[63839, 2172, 18678, 646, 444, 5962, 484, "GraphicsData", 
"PostScript", "Graphics"],
Cell[82520, 2820, 18423, 642, 444, 5971, 484, "GraphicsData", 
"PostScript", "Graphics"],
Cell[100946, 3464, 18270, 633, 444, 5805, 474, "GraphicsData", 
"PostScript", "Graphics"],
Cell[119219, 4099, 18489, 647, 444, 6049, 489, "GraphicsData", 
"PostScript", "Graphics"],
Cell[137711, 4748, 18677, 650, 444, 6046, 489, "GraphicsData", 
"PostScript", "Graphics"],
Cell[156391, 5400, 18632, 637, 444, 5815, 474, "GraphicsData", 
"PostScript", "Graphics"],
Cell[175026, 6039, 18649, 640, 444, 5860, 477, "GraphicsData", 
"PostScript", "Graphics"],
Cell[193678, 6681, 18635, 649, 444, 6033, 489, "GraphicsData", 
"PostScript", "Graphics"],
Cell[212316, 7332, 18480, 647, 444, 6040, 489, "GraphicsData", 
"PostScript", "Graphics"],
Cell[230799, 7981, 18321, 630, 444, 5743, 470, "GraphicsData", 
"PostScript", "Graphics"],
Cell[249123, 8613, 18473, 644, 444, 5984, 485, "GraphicsData", 
"PostScript", "Graphics"],
Cell[267599, 9259, 18654, 647, 444, 6011, 486, "GraphicsData", 
"PostScript", "Graphics"],
Cell[286256, 9908, 18663, 646, 444, 5988, 485, "GraphicsData", 
"PostScript", "Graphics"],
Cell[304922, 10556, 18474, 635, 444, 5791, 474, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[323411, 11194, 149, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[323585, 11202, 121, 2, 41, "Input"],
Cell[323709, 11206, 254, 4, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[324000, 11215, 227, 6, 87, "Input"],
Cell[324230, 11223, 32286, 1047, 273, 11790, 789, "GraphicsData", 
"PostScript", "Graphics"],
Cell[356519, 12272, 130, 3, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[356710, 12282, 93, 2, 79, "Section"],

Cell[CellGroupData[{
Cell[356828, 12288, 99, 2, 41, "Input"],
Cell[356930, 12292, 40, 1, 70, "Output"]
}, Open  ]],
Cell[356985, 12296, 542, 16, 317, "Input"],
Cell[357530, 12314, 129, 2, 41, "Input"],
Cell[357662, 12318, 176, 5, 64, "Input"],
Cell[357841, 12325, 90, 2, 41, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

